/*
Theme Name: Zita
Theme URI: https://wpzita.com/
Author: WpZita Team
Description: Zita is a super fast and highly customizable theme. Best Suitable for creating any type of website such a shoppin, corporate, store, agency, blog, portfolio, restaurant, wedding, construction, hospital, school, interior, car workshop, life coach, wine shop, barber shop, furniture shop, yoga, resume, charity, digital marketing etc. Zita includes 8 unique header layout and 8 footer widget layout which makes it extremely powerful. Zita works with any of your favourite page builder like Elementor, Visual Composer, Beaver Builder, SiteOrigin, Divi, Brizy etc. Some more amazing feature are Woocommerce ready, RTL Ready, Full Responsive, Edit settings in tablet & mobile, Top header, Bottom header, Top footer, Bottom Footer, Transparent Header. Looking for perfect base theme? Looking for perfect multipurpose theme? No need to Look further! Just go with Zita demos:https://wpzita.com/. Zita is built with best SEO practice and best friend of Woocommerce and Elementor.
Version: 1.5.4
Requires at least: 5.0
Tested up to: 5.7.2
Requires PHP: 5.8.2
License: GPLv3 or later
License URI: https://www.gnu.org/licenses/gpl-3.0.en.html
Tags: two-columns, right-sidebar, custom-menu, custom-background, editor-style, translation-ready, full-width-template, flexible-header, sticky-post, theme-options, one-column, e-commerce, blog, photography, threaded-comments, custom-colors
Text Domain: zita

This theme, like WordPress, is licensed under the GPL.
Use it to make something cool, have fun, and share what you've learned with others.
*/
@font-face {
  font-family: 'Catamaran-Regular';
  src: url('third-party/fonts/Catamaran-Regular.ttf') format('truetype');
  font-weight: normal;
  font-style: normal;
}  
@font-face {
  font-family: 'Catamaran-Bold';
  src: url('third-party/fonts/Catamaran-Bold.ttf') format('truetype');
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: 'Catamaran-SemiBold';
  src: url('third-party/fonts/Catamaran-SemiBold.ttf') format('truetype');
  font-weight: normal;
  font-style: normal;
}
/*--------------------------------------------------------------
1.0 Normalize
Styles based on Normalize v5.0.0 @link https://github.com/necolas/normalize.css
--------------------------------------------------------------*/
html,
body,
div,
span,
applet,
object,
iframe,
h1,
h2,
h3,
h4,
h5,
h6,
p,
blockquote,
pre,
a,
abbr,
acronym,
address,
big,
cite,
code,
del,
dfn,
em,
font,
ins,
kbd,
q,
s,
samp,
small,
strike,
strong,
sub,
sup,
tt,
var,
dl,
dt,
dd,
ol,
ul,
li,
fieldset,
form,
label,
legend,
table,
caption,
tbody,
tfoot,
thead,
tr,
th,
td {
  border: 0;
  font-size: 100%;
  font-style: inherit;
  font-weight: inherit;
  margin: 0;
  outline: 0;
  padding: 0;
  vertical-align: baseline;
}
html {
  font-family: sans-serif;
   -webkit-text-size-adjust: 100%;
   -ms-text-size-adjust: 100%;
   text-rendering: optimizeLegibility !important;
   -webkit-font-smoothing: antialiased !important;
}
body{
    color: #808285;
    background: #fff;
    font-style: normal;
    font-size: 15px;
    font-size: 1rem;
    line-height:1.6;
    margin: 0;
    padding: 0;
    font-family:"Catamaran-Regular", sans-serif;
    font-weight: inherit;
    text-rendering: optimizeLegibility;
    -webkit-font-smoothing: antialiased; 
    -moz-osx-font-smoothing: grayscale; 
    text-rendering: optimizeLegibility; 
    -moz-font-feature-settings: "liga" on; 
}
article,
aside,
footer,
header,
nav,
section{
  display: block;
}
*, html, body, div, dl, dt, dd, ul, ol, li, h1, h2, h3, h4, h5, h6, pre, form, label, fieldset, input, blockquote, th, td {
    margin: 0;
    padding: 0;
}
h1, h2, h3, h4, h5, h6 {
    font-family:"Catamaran-Regular", sans-serif;
    color: #3a3a3a;
    line-height: 35px;
    font-weight:500;
    letter-spacing: 1px;
    
}
h1 {
  font-size: 30px;
  line-height: 1.2;
}
h2 {
  font-size: 28px;
  line-height: 1.3;
}
h3 {
  font-size: 26px;
  line-height: 1.4;
}
h4 {
  font-size: 24px;
  line-height: 1.5;
}
h5 {
  font-size: 22px;
  line-height: 1.6;
}
h6 {
  font-size: 20px;
  line-height: 1.2;
}
.entry-content h1, 
.entry-content h2, 
.entry-content h3, 
.entry-content h4, 
.entry-content h5, 
.entry-content h6 {
    margin-bottom: 20px;
}
.entry-content p {
    margin-bottom: 10px;
    line-height:1.8;
}

a {
    
    text-decoration: none!important;
    cursor: pointer;
}
figcaption,
main {
  display: block;
    max-width: 100%;
}
figure {
margin: 1em 0;
}
embed, iframe, object, video {
   margin-bottom: 1.5em;
   max-width: 100%;
   vertical-align: middle;
}

hr{
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  height: 0;
  overflow: visible;
}
pre {
  font-size: 1em;
}

a {
  background-color: transparent;
  -webkit-text-decoration-skip: objects;
}
a:focus,span:focus{
    outline: thin dotted;
    text-decoration: underline;
}
a:active,
a:hover {
  outline-width: 0;
}
a:hover {
  outline-width: 0;
}
a, a:hover,button {
    text-decoration: none;
    -webkit-transition: all 0.3s ease;
    -moz-transition: all 0.3s ease;
    -ms-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    transition: all 0.3s ease;
}
abbr[title] {
  border-bottom: 1px #767676 dotted;
  text-decoration: none;
}
code,
kbd,
samp{
  font-family: 'Catamaran-Regular';
  font-size: 1em;
}

dfn {
  font-style: italic;
}

mark {
  background-color: #eee;
  color: #222;
}
#content.site-content {
display: block;
}
.fullwidthcontained .site-content{
position:relative;
}
small {
  font-size: 80%;
}

sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline;
}
sub {
  bottom: -0.25em;
}
sup {
  top: -0.5em;
}
audio,
video {
  display: inline-block;
}
audio:not([controls]) {
  display: none;
  height: 0;
}
img {
  border-style: none;
    max-width: 100%;
    height: auto;
}
svg:not(:root) {
  overflow: hidden;
}
button,
input,
optgroup,
select,
textarea {
  font-family: sans-serif;
  font-size: 100%;
  line-height: 1.15;
  margin: 0;
}
button,
input {
  overflow: visible;
}
button,
select {
  text-transform: none;
}
button,
html [type="button"],
[type="reset"],
[type="submit"] {
  -webkit-appearance: button;
}
button::-moz-focus-inner,
[type="button"]::-moz-focus-inner,
[type="reset"]::-moz-focus-inner,
[type="submit"]::-moz-focus-inner {
  border-style: none;
  padding: 0;
}
button:-moz-focusring,
[type="button"]:-moz-focusring,
[type="reset"]:-moz-focusring,
[type="submit"]:-moz-focusring {
  outline: 1px dotted ButtonText;
}
select {
    text-transform: none;
    z-index: 1;
    border: none;
    height: 35px;
    width:100%;
    line-height: normal;
    margin-bottom: 0;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background: #f3f3f3;
    position: relative;
    border: 1px solid #ddd;
    padding: 0px 10px;
    font-size: 15px;
}
button{
  border:0;
}
button:hover{
  cursor: pointer;
}
fieldset {
  border: 1px solid #bbb;
  margin: 0 2px;
  padding: 0.35em 0.625em 0.75em;
}

legend {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  color: inherit;
  display: table;
  max-width: 100%;
  padding: 0;
  white-space: normal;
}

progress {
  display: inline-block;
  vertical-align: baseline;
}
.page-links {
    clear: both;
    padding: 15px 0px;
    width: 100%;
}
textarea {
  overflow: auto;
}

[type="checkbox"],
[type="radio"] {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  padding: 0;
}

[type="number"]::-webkit-inner-spin-button,
[type="number"]::-webkit-outer-spin-button {
  height: auto;
}

[type="search"] {
  -webkit-appearance: textfield;
  outline-offset: -2px;
}

[type="search"]::-webkit-search-cancel-button,
[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none;
}

::-webkit-file-upload-button {
  -webkit-appearance: button;
  font: inherit;
}

details,
menu {
  display: block;
}

summary {
  display: list-item;
}

canvas {
  display: inline-block;
}

template {
  display: none;
}
table {
    border-collapse: separate;
    border-spacing: 0;
    border-width: 1px 0 0 1px;
    margin: 0 0 1.5em;
    width: 100%;
}

table, td, th {
    border: 1px solid rgba(0,0,0,.1);
}
table {
    border-collapse: collapse;
    border-spacing: 0;
}
td, th {
    padding: 8px;
    text-align: left;
    border-width: 0 1px 1px 0;
}

th,th a,dt,b, strong{
    font-family: 'Catamaran-SemiBold',sans-serif;
}
table, td, th {
    border: 1px solid rgba(0,0,0,.1);
}
a{
 color:#9c9c9c;   
}
a:hover{
 color:#006799;
}
dd {
    margin: 0 1.5em 1.5em;
}
ul {
    list-style: disc;
}

ol, ul {
    margin: 0 0 1.5em 3em;
}
address {
    margin: 0 0 1.5em;
}
blockquote {
    border-color: rgba(2,116,190,0.05);
}
blockquote {
    margin: 1.5em 1em 1.5em 3em;
    padding: 1.2em;
    font-size: 1.1em;
    line-height: inherit;
    position: relative;
}
blockquote {
    border-left: 5px solid rgba(0,0,0,.05);
    padding: 20px;
    font-size: 1.2em;
    font-style: italic;
    margin: 0 0 1.5em;
    position: relative;
}
blockquote, q {
    quotes: "" "";
}
pre {
    background: #eee;
    margin-bottom: 1.6em;
    overflow: auto;
    max-width: 100%;
    padding: 1.6em;
}
code, kbd, pre, samp {
    font-size: 1em;
}
*, :after, :before {
    -webkit-box-sizing: inherit;
    -moz-box-sizing: inherit;
    box-sizing: inherit;
}
#content .content-area li {
   margin-bottom: 10px;
   line-height: 1.8;
}
#content .content-area .entry-content p {
   margin-bottom: 10px;
   line-height: 1.8;
}
/* Accessibility */
/* Text meant only for screen readers. */
.screen-reader-text {
  border: 0;
  clip: rect(1px, 1px, 1px, 1px);
  clip-path: inset(50%);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute !important;
  width: 1px;
  word-wrap: normal !important;
  /* Many screen reader and browser combinations announce broken words as they would appear visually. */
}
.screen-reader-text:focus {
  background-color:#006799;
  border-radius:0;
  box-shadow: none;
  clip: auto !important;
  clip-path: none;
  color: #fff;
  display: block;
  font-size: 14px;
  font-size: 0.875rem;
  font-weight: bold;
  height: auto;
  left: 5px;
  line-height: normal;
  padding: 8px 25px;
  text-decoration: none;
  top: 5px;
  width: auto;
  z-index: 100000;
  /* Above WP toolbar. */
}
/* Do not show the outline on the skip link target. */
#content[tabindex="-1"]:focus {
  outline: 0;
}
/************************/
/*elementor plugin*/
/************************/
#elementor {
    position:relative;
    z-index:99;
}
.elementor-editor-active header.zta-transparent-header{
   z-index:1;
}
.elementor-editor-active.mobile-menu-active header.zta-transparent-header, 
.elementor-editor-active.mobile-menu-active header .sider{
    z-index:999;
}
.elementor-editor-active #content .content-area li.elementor-editor-element-setting{
    margin-bottom:0;
    line-height:normal;
}
.elementor-widget-container section {
    margin-bottom: 20px;
}
/************************/
/*elementor plugin*/
/************************/
/*gallery style*/
.gallery:after {content:"";display:table;clear:both;}
.gallery figure img {max-width:100%; height:auto; margin:0 auto; display:block;}
.gallery figure {float:left; margin:0 2% 0.4em 0;}
.gallery.gallery-columns-1 figure {width:100%; margin:0 0 1em 0; float:none;}
.gallery.gallery-columns-3 figure {width:32%;}
.gallery.gallery-columns-3 figure:nth-of-type(3n+3) {margin-right:0;}
.gallery.gallery-columns-3 figure:nth-of-type(3n+4) {clear:left;}
.gallery.gallery-columns-2 figure {width:49%;}
.gallery.gallery-columns-2 figure:nth-of-type(even) {margin-right:0;}
.gallery.gallery-columns-2 figure:nth-of-type(odd) {clear:left;}
.gallery.gallery-columns-4 figure {width:23.25%;}
.gallery.gallery-columns-4 figure:nth-of-type(4n+4) {margin-right:0;}
.gallery.gallery-columns-4 figure:nth-of-type(4n+5) {clear:left;}
.gallery.gallery-columns-5 figure {width:18%;}
.gallery.gallery-columns-5 figure:nth-of-type(5n+5) {margin-right:0;}
.gallery.gallery-columns-5 figure:nth-of-type(5n+6) {clear:left;}
.gallery.gallery-columns-6 figure {width:14.2%;}
.gallery.gallery-columns-6 figure:nth-of-type(6n+6) {margin-right:0;}
.gallery.gallery-columns-6 figure:nth-of-type(6n+7) {clear:left;}
.gallery.gallery-columns-7 figure {width:12%;}
.gallery.gallery-columns-7 figure:nth-of-type(7n+7) {margin-right:0;}
.gallery.gallery-columns-7 figure:nth-of-type(7n+8) {clear:left;}
.gallery.gallery-columns-8 figure {width:10.2%;}
.gallery.gallery-columns-8 figure:nth-of-type(8n+8) {margin-right:0;}
.gallery.gallery-columns-8 figure:nth-of-type(8n+9) {clear:left;}
.gallery.gallery-columns-9 figure {width:8.85%;}
.gallery.gallery-columns-9 figure:nth-of-type(9n+9) {margin-right:0;}
.gallery.gallery-columns-9 figure:nth-of-type(9n+10) {clear:left;}
/*gallery style end*/

[hidden] {
  display: none;
}
#primary:after,.clear, 
header:before,
footer:before, 
#sidebar-primary,
  #page:before, #container:before{
    content: "";
    display: table;
}
#primary:after, #secondary:after, 
.site-container :after, 
 .clear:after, .sidebar-main:after, 
 .site-content:after, 
 .site-header:after,.site-main:after,
 footer::before{
    clear: both;
}
#page.zita-site {
    display: block;
    position: relative;
    margin-left: auto;
    margin-right: auto;
    max-width:100%;
}
.site-header {
    z-index: 10;
    position: relative;
}
.widget ul {
    margin: 0;
    list-style-type: none;
}
/*************/
/*Pre-loader*/
/*************/
.zita_overlayloader{
    position: fixed;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    background-color:#f5f5f5;
    z-index: 99999;
    height: 100%;
    width: 100%;
    overflow: hidden !important;
}

.zita-pre-loader img{
  text-indent: -9999em;
  position: absolute;
  top: 50%;
  left: 50%;
  /* bring your own prefixes */
  transform: translate(-50%, -50%);
  display: block;
  background-position: center;
  -webkit-animation-delay: -0.16s;
  animation-delay: -0.16s;
}
/* == WordPress WYSIWYG Editor Styles == */
.entry-content img {
  margin: 0 0 0 0;
  }
.alignleft, img.alignleft {
  margin-right: 1.5em;
  display: inline;
  float: left;
  }
.alignright, img.alignright {
  margin-left: 1.5em;
  display: inline;
  float: right;
  }
.aligncenter, img.aligncenter {
  margin-right: auto;
  margin-left: auto;
  display: block;
  clear: both;
  }
.alignnone, img.alignnone {
  /* not sure about this one */
  }
.wp-caption {
  margin-bottom: 1.5em;
  text-align: center;
  padding-top: 5px;
  }
.wp-caption img {
  border: 0 none;
  padding: 0;
  margin: 0;
  }
  .wp-caption, .gallery-caption {
   color: #666;
   font-size: 13px;
   font-size: 0.8125rem;
   font-style: italic;
   margin-bottom: 1.5em;
   max-width: 100%;
}
.wp-caption p.wp-caption-text {
  line-height: 1.5;
  font-size: 10px;
  margin: 0;
  }
.wp-smiley {
  margin: 0 !important;
  max-height: 1em;
  }
blockquote.left {
  margin-right: 20px;
  text-align: right;
  margin-left: 0;
  width: 33%;
  float: left;
  }
blockquote.right {
  margin-left: 20px;
  text-align: left;
  margin-right: 0;
  width: 33%;
  float: right;
  }
.gallery dl {}
.gallery dt {}
.gallery dd {}
.gallery dl a {}
.gallery dl img {}
.gallery-caption {}

.size-full {}
.size-large {}
.size-medium {}
.size-thumbnail {}
/* == WP CSS - post_class() == */
.post-id {}
.post {}
.page {}
.attachment {}
.sticky {}
.hentry {}
.category-misc {}
.category-example {}
.tag-news {}
.tag-wordpress {}
.tag-markup {}
.bypostauthor{}

/*loadmore*/
.load-more-posts-error{
display:none;
}
/*********************/
/*sticky header*/
/*********************/
header.shrink{
position:fixed;
width:100%;
z-index:999;
}
.zta-main-stick-hdr.shrink .main-header{
display:block;
display:block
}
.zta-above-stick-hdr.shrink .top-header{
display:block
}
.zta-bottom-stick-hdr.shrink .bottom-header{
display:block
}
.shrink .main-header,.shrink .top-header,.shrink .bottom-header{
display:none;
}
header.shrink.zta-slide{
   -webkit-transition: all 0.5s ease;
    transition: all 0.5s ease;
    -webkit-animation-duration: 0.5s;
    animation-duration: 0.5s;
    -webkit-animation-fill-mode: both;
    animation-fill-mode: both;
    -webkit-animation-name: fadeInDown;
    animation-name: fadeInDown;
}
header.shrink.zta-fade{
-webkit-animation: fadein 0.5s; /* Safari, Chrome and Opera > 12.1 */
       -moz-animation: fadein 0.5s; /* Firefox < 16 */
        -ms-animation: fadein 0.5s; /* Internet Explorer */
         -o-animation: fadein 0.5s; /* Opera < 12.1 */
            animation: fadein 0.5s;
}
@keyframes fadeInDown {
   0% {
      opacity: 0;
      transform: translateY(-50px);
   }
   100% {
      opacity: 1;
      transform: translateY(0);
   }
} 

@keyframes fadein {
    from { opacity: 0; }
    to   { opacity: 1; }
}
/* Firefox < 16 */
@-moz-keyframes fadein {
    from { opacity: 0; }
    to   { opacity: 1; }
}
/* Safari, Chrome and Opera > 12.1 */
@-webkit-keyframes fadein {
    from { opacity: 0; }
    to   { opacity: 1; }
}

/* Opera < 12.1 */
@-o-keyframes fadein {
    from { opacity: 0; }
    to   { opacity: 1; }
}
/*********************/
/*sticky header*/
/*********************/
/*********************/
/*Header Transparent*/
/*********************/
header.zta-transparent-header{
    position: absolute;
    width: 100%;
    z-index: 999;
}
header.zta-transparent-header.shrink{
    position: fixed;
}
.zita-site .mhdrleftpan .main-header-bar:before,
.zita-site .mhdrrightpan .main-header-bar:before{
background:transparent;
}
.zita-site .mhdrleftpan .main-header-bar,
.zita-site .mhdrrightpan .main-header-bar{
background:transparent;
}
.mhdrleftpan.shrink.zta-slide,
.mhdrrightpan.shrink.zta-slide,
.mhdrleftpan.shrink.zta-fade,
.mhdrrightpan.shrink.zta-fade{
    -webkit-animation-name:inherit;
    animation-name:inherit;
}
.pan-content ::-webkit-scrollbar-track{
  -webkit-box-shadow: inset 0 0 6px rgba(0,0,0,0.3);
  background-color: #F5F5F5;
  visibility: hidden;
}
.pan-content::-webkit-scrollbar{
width: 6px;
background-color: #F5F5F5;
visibility: hidden;
}
.pan-content::-webkit-scrollbar-thumb{
background-color:#aaa;
visibility: hidden;
}
.pan-content{
overflow: auto;
height:100%;
    padding: 2em 1.5em;
}
.pan-content:hover ::-webkit-scrollbar-track,
.pan-content:hover::-webkit-scrollbar-thumb,
.pan-content:hover::-webkit-scrollbar{
 visibility:visible;
}

/*********************/
/*Header Transparent*/
/*********************/
/**********************/
/*header custom menu text*/
/**********************/
.menu-custom-html > a button{
    display: block;
    position: relative;
    margin: 0;
    border: 0px;
    padding: 18PX 24px;
    text-decoration: none;
    font-size: 15px;
    font-weight:300;
    background:#006799;
    color:#fff;
}
.menu-custom-html > a button:hover{
  cursor:pointer;
}
.zita-menu .content-social .social-icon li a,
.zita-menu .menu-custom-search .searchfrom a{
color:#006799;
padding: 0;
}
.zita-menu .menu-custom-search .searchfrom a i{
  margin:0;
  padding:0;
}
.zita-menu .menu-custom-search{
 padding:0px; 
}
.menu-custom-widget{
text-align:right;
}
li.menu-item.zta-custom-item{
padding:14px;
}
.top-header-bar.abv-two .top-header-col1 .searchfrom,
.top-header-bar.abv-three .top-header-col1 .searchfrom,
.bottom-header-bar.btm-two .bottom-header-col1 .searchfrom,
.bottom-header-bar.btm-three .bottom-header-col1 .searchfrom{
float:left;
}
.top-header-bar.abv-two .top-header-col1 .searchfrom #searchform,
.top-header-bar.abv-three .top-header-col1 .searchfrom #searchform,
.bottom-header-bar.btm-two .bottom-header-col1 .searchfrom #searchform,
.bottom-header-bar.btm-three .bottom-header-col1 .searchfrom #searchform{
right: auto;
left: 0;
}
.top-footer-bar.ft-abv-two .top-footer-col1 .searchfrom,
.top-footer-bar.ft-abv-three .top-footer-col1 .searchfrom,
.bottom-footer-bar.ft-btm-two .bottom-footer-col1 .searchfrom,
.bottom-footer-bar.ft-btm-three .bottom-footer-col1 .searchfrom{
float:left;
}
.top-footer-bar.ft-abv-two .top-footer-col1 .searchfrom #searchform,
.top-footer-bar.ft-abv-three .top-footer-col1 .searchfrom #searchform,
.bottom-footer-bar.ft-btm-two .bottom-footer-col1 .searchfrom #searchform,
.bottom-footer-bar.ft-btm-three .bottom-footer-col1 .searchfrom #searchform{
right: auto;
left: 0;
}
.widget-area .content-widget #searchform .form-content{
line-height:normal;
}

.menu-custom-widget .widget_product_search .widget-title{
display:none;
}

.menu-custom-widget .widget_product_search #searchform {
    position: relative;
    display: block;
    width: 100%;
}
.menu-custom-widget .widget_product_search #searchform .form-content:before {
    content: "\f002";
    font-family: FontAwesome;
    position: absolute;
    color: #015782;
    right: 0;
    width: 40px;
    height: 40px;
    line-height: 40px;
    z-index: 2;
    font-size: 15px;
    text-align: center;
}
.menu-custom-widget .widget_product_search input#s {
    z-index: 1;
    border: none;
    height: 40px;
    line-height: normal;
    margin-bottom: 0;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background: #f3f3f3;
    position: relative;
    top: 100%;
    border: 1px solid #ddd;
    width: 100%;
    font-size: 13px;
}

.menu-custom-widget .widget_product_search #searchform input[type=submit] {
    display: block;
    width: 20px;
    position: absolute;
    font-size: 0;
    top: 0px;
    right: 0;
    height: 20px;
    line-height: 30px;
    z-index: 3;
    background: transparent;
    border: none;
    margin-top: 0px;
    height: 40px;
    width: 40px;
    padding: 0;
}
/*********************/
/*post navigation*/
/*********************/
.screen-reader-text {
    clip: rect(1px,1px,1px,1px);
    position: absolute!important;
    height: 1px;
    width: 1px;
    overflow: hidden;
}
.post-navigation,nav.pagination{
    border-top: 0;
    padding-left:0;
    padding-right:0;
   padding: 20px 0px;
}
.single .post-navigation .nav-links {
    -js-display: flex;
    display: -webkit-box;
    display: -webkit-flex;
    display: -moz-box;
    display: -ms-flexbox;
    display: flex;
}
.single .post-navigation .nav-next, 
.single .post-navigation .nav-previous {
    -webkit-box-flex: 1;
    -webkit-flex: auto;
    -moz-box-flex: 1;
    -ms-flex: auto;
    flex: auto;
}
.nav-next, 
.post-navigation .nav-previous, 
.posts-navigation .nav-next, 
.posts-navigation .nav-previous {
    width: 50%;
    display: inline-block;
    position: relative;
        color:#9c9c9c;
}
.single .nav-previous:hover:before,
.single .nav-next:hover:after{
-webkit-transition: all 0.3s ease;
    -moz-transition: all 0.3s ease;
    -ms-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    transition: all 0.3s ease;
}
.single .post-navigation a {
    margin: 2px;
    display: inline-block;
}
.post-navigation .nav-next, 
.posts-navigation .nav-next{
    text-align: right;
}
.single .nav-previous:before {
    content: "\f100";
    font-family: FontAwesome;
    position: absolute;
    font-size: 18px;
   
}
.single .nav-previous a{
padding-left:20px;
}
.single .nav-next:after {
    content: "\f101";
    font-family: FontAwesome;
    position: absolute;
    font-size: 18px;
    right: 0px;
   
}
.single .nav-next a{
padding-right:20px;
}
.page-numbers {
    width: 2.33333em;
    height: 2.33333em;
}
.page-numbers.dots,.page-numbers.dots:hover{
border:none;
}
.page-numbers{display: inline-block;
    margin: 0 5px;
    color:#bbb;
    text-align: center;
    padding: 10px 0;
    font-size: 16px;
    line-height: 16px;
    text-decoration: none;
    letter-spacing: 0;
    border: 1px solid #bbb;
}

.page-numbers.current,.page-numbers:hover,.prev.page-numbers:hover,
.next.page-numbers:hover{
    border-radius:0;
    background: none;
    opacity: 1;
    border: 1px solid #006799;
    color:#006799;
}

.next.page-numbers,.prev.page-numbers{
    display: inline-block;
    padding: 10px 30px;
    text-align: center;
     border-radius: 0px;
    border: 1px solid #bbb;
    color:#bbb;
}
.next.page-numbers{
margin-left:5px;
margin-right:0px;
}

.prev.page-numbers{
margin-left:0px;
margin-right:5px;
}
.next.page-numbers{
    float:right; 
    width:auto; 
}
.prev.page-numbers{
   float:left; 
   width:auto;   
}
.woocommerce nav.woocommerce-pagination ul li a,
 .woocommerce nav.woocommerce-pagination ul li span{
  line-height:2.33em;
  padding:0;
  width:2.33em;
}
/*post navigation*/
/*post & page title and meta style */
header.entry-header h1.entry-title{
font-size:30px;
line-height: 1.2;
margin-bottom:10px;
}
.widget-title {
    font-size: 21px;
    font-size: 1.4rem;
    margin-bottom: 10px;
}
article.zita-article h2.entry-title{
font-size:30px;
line-height:1.3;
}
.zita-site #content .entry-meta{
margin-bottom: 10px;
color:#9c9c9c;   
}
article.zita-article h2.entry-title a{
color:#3a3a3a;
}
.entry-header.archive h1.entry-title{
margin:30px 0px;
}
/*page title style*/
/****************************************/
/*section background image and background color*/
/****************************************/
#content article.zita-article .entry-header,#content article.zita-article .entery-header,
#content article.zita-article .entry-content,
.zita-site .top-header-bar,
.zita-site .main-header-bar,
.zita-site .bottom-header-bar,
#content.blog-single article.zita-article,
#sidebar-primary.widget-area section,
.boxed #content .zta-one-colm article.zita-article .entry-content-outer-wrapper,
.boxed #content .zta-two-colm article.zita-article .entry-content-outer-wrapper,
.boxed #content .zta-three-colm article.zita-article .entry-content-outer-wrapper,
.boxed #content .zta-four-colm article.zita-article .entry-content-outer-wrapper,
#content .zta-blog-layout-2 article.zita-article .entry-content-outer-wrapper,
#content .zta-blog-layout-3 article.zita-article .entry-content-outer-wrapper,
#content .zta-blog-layout-4 article.zita-article .entry-content-outer-wrapper,
.contentbox #content .zta-two-colm article.zita-article .entry-content-outer-wrapper,
.contentbox #content .zta-one-colm article.zita-article .entry-content-outer-wrapper,
.contentbox #content .zta-three-colm article.zita-article .entry-content-outer-wrapper,
.contentbox #content .zta-four-colm article.zita-article .entry-content-outer-wrapper,
.site-content .site-container #sidebar-primary .sidebar-main,
.top-footer .top-footer-bar,
.widget-footer .widget-footer-bar,
.bottom-footer .bottom-footer-bar,
.boxed #content.blog-single article.zita-article,
.contentbox #content.blog-single article.zita-article,
.boxed #comments,
.contentbox #comments,
.boxed .blog-single .authorbox,
.contentbox .blog-single .authorbox,
.zita-related-post,
.page.boxed #content.site-content article.zita-article, 
.page.contentbox #content.site-content article.zita-article,
.archive.boxed #content.site-content.archive-page article.zita-article, 
.archive.contentbox #content.site-content.archive-page article.zita-article,
body.fullwidthcontained.maxwidth #content,
body.fullwidthcontained.padding #content,
.single #content.site-content.blog-single.contentbox article.zita-article{
 position:relative;   
}
.zita-site .top-header-bar:before,
.zita-site .main-header-bar:before,
.zita-site .bottom-header-bar:before,
.boxed #content .zta-one-colm article.zita-article .entry-content-outer-wrapper:before,
.boxed #content .zta-two-colm article.zita-article .entry-content-outer-wrapper:before,
.boxed #content .zta-three-colm article.zita-article .entry-content-outer-wrapper:before,
.boxed #content .zta-four-colm article.zita-article .entry-content-outer-wrapper:before,
#content .zta-blog-layout-2 article.zita-article .entry-content-outer-wrapper:before,
#content .zta-blog-layout-3 article.zita-article .entry-content-outer-wrapper:before,
#content .zta-blog-layout-4 article.zita-article .entry-content-outer-wrapper:before,
.contentbox #content .zta-two-colm article.zita-article .entry-content-outer-wrapper:before,
.contentbox #content .zta-one-colm article.zita-article .entry-content-outer-wrapper:before,
.contentbox #content .zta-three-colm article.zita-article .entry-content-outer-wrapper:before,
.contentbox #content .zta-four-colm article.zita-article .entry-content-outer-wrapper:before,
.site-content .site-container #sidebar-primary .sidebar-main:before,
.top-footer .top-footer-bar:before,.widget-footer .widget-footer-bar:before,
.bottom-footer .bottom-footer-bar:before,
.boxed #content.blog-single article.zita-article:before,
.boxed #comments:before,
.boxed .blog-single .authorbox:before,
.contentbox .blog-single .authorbox:before,
.contentbox #content.blog-single article.zita-article:before,
.contentbox #comments:before,
.contentbox .blog-single .authorbox:before,
.page.boxed #content.site-content article.zita-article:before, 
.page.contentbox #content.site-content article.zita-article:before,
.archive.boxed #content.site-content.archive-page article.zita-article:before, 
.archive.contentbox #content.site-content.archive-page article.zita-article:before,
.mhdrleftpan header:before,.mhdrrightpan header:before,
#content.site-content.fullwidthstrechched .archive-page .entry-content-outer-wrapper.zta-blog-layout-1:before,
#content.site-content.fullwidthstrechched .archive-page .entry-content-outer-wrapper.zta-blog-layout-2:before,
#content.site-content.fullwidthstrechched .archive-page .entry-content-outer-wrapper.zta-blog-layout-3:before,
#content.site-content.fullwidthstrechched .archive-page .entry-content-outer-wrapper.zta-blog-layout-4:before,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-1:before,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-2:before,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-3:before,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-4:before,
.fullwidthcontained #content.site-content .zta-blog-layout-2 article.zita-article:before,
.fullwidthstrechched #content.site-content .zta-blog-layout-2 article.zita-article:before{
 content:'';
 background-color: rgba(0, 0, 0, 0);
 width: 100%;
 height: 100%;
 position: absolute;
 left: 0;
 top: 0;
 z-index:0;
 display: block;
}
#sidebar-primary.widget-area section:before,
.archive .site-content.boxed .archive-page #sidebar-primary.widget-area section:before ,
body.fullwidthcontained.maxwidth #content:before,
body.fullwidthcontained.padding #content:before,
.single #content.site-content.blog-single.boxed article.zita-article:before,
.single #content.site-content.blog-single.contentbox article.zita-article:before,
body.maxwidth #content.site-content.blog-single.fullwidthcontained:before,
body.padding #content.site-content.blog-single.fullwidthcontained:before,
body.archive.maxwidth #content.site-content.fullwidthcontained:before,
body.archive.padding #content.site-content.fullwidthcontained:before,
body.page.maxwidth #content.site-content.fullwidthcontained:before,
body.page.padding #content.site-content.fullwidthcontained:before{
 content: '';
 background-color:#fff;
 width: 100%;
 height: 100%;
 position: absolute;
 left: 0;
 top: 0;
 z-index:0;
 display: block;
}
.contentbox .site-content .site-container #sidebar-primary .sidebar-main,
.fullwidthcontained .site-content .site-container #sidebar-primary .sidebar-main,
.fullwidthstrechched .site-content .site-container #sidebar-primary .sidebar-main,
.contentbox #content #sidebar-primary.widget-area section:before,
.fullwidthcontained #content #sidebar-primary.widget-area section:before,
.fullwidthstrechched #content #sidebar-primary.widget-area section:before,
.fullwidthcontained #content .zta-blog-layout-2 article.zita-article .entry-content-outer-wrapper:before,
.fullwidthcontained #content .zta-blog-layout-3 article.zita-article .entry-content-outer-wrapper:before,
.fullwidthcontained #content .zta-blog-layout-4 article.zita-article .entry-content-outer-wrapper:before,
.fullwidthstrechched #content .zta-blog-layout-2 article.zita-article .entry-content-outer-wrapper:before,
.fullwidthstrechched #content .zta-blog-layout-3 article.zita-article .entry-content-outer-wrapper:before,
.fullwidthstrechched #content .zta-blog-layout-4 article.zita-article .entry-content-outer-wrapper:before,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-1:before,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-2:before,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-3:before,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-4:before,
.site-content.contentbox .archive-page #sidebar-primary.widget-area section:before,
.site-content.fullwidthcontained .archive-page #sidebar-primary.widget-area section:before,
.blog-single.contentbox #sidebar-primary.widget-area section:before
#content.site-content.fullwidthstrechched .archive-page .entry-content-outer-wrapper.zta-blog-layout-1:before,
#content.site-content.fullwidthstrechched .archive-page .entry-content-outer-wrapper.zta-blog-layout-2:before,
#content.site-content.fullwidthstrechched .archive-page .entry-content-outer-wrapper.zta-blog-layout-3:before,
#content.site-content.fullwidthstrechched .archive-page .entry-content-outer-wrapper.zta-blog-layout-4:before,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-1:before,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-2:before,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-3:before,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-4:before,
.fullwidthcontained .zta-blog-layout-2 article.zita-article:before,.fullwidthstrechched #content.site-content .zta-blog-layout-2 article.zita-article:before{
background:transparent;
}
.fullwidthcontained #content .archive-page article.zita-article,
.fullwidthstrechched #content .archive-page article.zita-article,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-1,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-2,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-3,
#content.site-content.fullwidthcontained .archive-page .entry-content-outer-wrapper.zta-blog-layout-4,
#content.site-content.fullwidthstrechched .archive-page .entry-content-outer-wrapper.zta-blog-layout-1,
#content.site-content.fullwidthstrechched .archive-page .entry-content-outer-wrapper.zta-blog-layout-2,
#content.site-content.fullwidthstrechched .archive-page .entry-content-outer-wrapper.zta-blog-layout-3,
#content.site-content.fullwidthstrechched .archive-page .entry-content-outer-wrapper.zta-blog-layout-4{
background:transparent!important;
}

#content.site-content.fullwidthcontained .archive-page.zta-blog-layout-2 article.zita-article .entry-content-outer-wrapper:before,
#content.site-content.fullwidthcontained .archive-page.zta-blog-layout-3 article.zita-article .entry-content-outer-wrapper:before,
#content.site-content.fullwidthcontained .archive-page.zta-blog-layout-4 article.zita-article .entry-content-outer-wrapper:before,
#content.site-content.fullwidthstrechched .archive-page.zta-blog-layout-2 article.zita-article .entry-content-outer-wrapper:before,
#content.site-content.fullwidthstrechched .archive-page.zta-blog-layout-3 article.zita-article .entry-content-outer-wrapper:before,
#content.site-content.fullwidthstrechched .archive-page.zta-blog-layout-4 article.zita-article .entry-content-outer-wrapper:before{
background:0 0;
}
body.fullwidthcontained.maxwidth #content.boxed:before, 
body.fullwidthcontained.padding #content.boxed:before,
body.fullwidthcontained.maxwidth #content.contentbox:before, 
body.fullwidthcontained.padding #content.contentbox:before,
body.fullwidthcontained.maxwidth #content.fullwidthstrechched:before, 
body.fullwidthcontained.padding #content.fullwidthstrechched:before,
body.archive.maxwidth #content.site-content.fullwidthcontained:before,
body.archive.padding #content.site-content.fullwidthcontained:before{
background:transparent;
}
body.fullwidthcontained.maxwidth #content.boxed,
body.fullwidthcontained.padding #content.boxed,
body.fullwidthcontained.maxwidth #content.contentbox,
body.fullwidthcontained.padding #content.contentbox,
body.fullwidthcontained.maxwidth #content.fullwidthstrechched, 
body.fullwidthcontained.padding #content.fullwidthstrechched{
background:transparent;
}
.single #content.site-content.blog-single.fullwidthcontained article.zita-article,
.single #content.site-content.blog-single.fullwidthcontained #comments,
.single.contentbox #content.site-content.blog-single.fullwidthstrechched #comments{
 background:0 0; 
}
#sidebar-primary.widget-area section:before, 
.boxed #content .zta-one-colm article.zita-article .entry-content-outer-wrapper:before,
 .boxed #content .zta-two-colm article.zita-article .entry-content-outer-wrapper:before,
  .boxed #content .zta-three-colm article.zita-article .entry-content-outer-wrapper:before,
   .boxed #content .zta-four-colm article.zita-article .entry-content-outer-wrapper:before,
    #content .zta-blog-layout-2 article.zita-article .entry-content-outer-wrapper:before, 
    #content .zta-blog-layout-3 article.zita-article .entry-content-outer-wrapper:before,
     #content .zta-blog-layout-4 article.zita-article .entry-content-outer-wrapper:before, 
     .contentbox #content .zta-two-colm article.zita-article .entry-content-outer-wrapper:before, 
     .contentbox #content .zta-one-colm article.zita-article .entry-content-outer-wrapper:before,
      .contentbox #content .zta-three-colm article.zita-article .entry-content-outer-wrapper:before,
      .contentbox #content .zta-four-colm article.zita-article .entry-content-outer-wrapper:before,
       .boxed #content.blog-single article.zita-article:before, 
       .boxed #comments:before, 
.boxed .blog-single .authorbox:before, 
.page.boxed #content.site-content article.zita-article:before, 
.page.contentbox #content.site-content article.zita-article:before, 
.contentbox .blog-single .authorbox:before, 
.contentbox #content.blog-single article.zita-article:before, 
.contentbox #comments:before, .contentbox .zita-related-post:before,
.boxed .zita-related-post:before, 
.contentbox .blog-single .authorbox:before, 
.archive.boxed #content.site-content.archive-page article.zita-article:before,
 .archive.contentbox #content.site-content.archive-page article.zita-article:before, 
 .archive .site-content.boxed .archive-page #sidebar-primary.widget-area section:before,
  .archive #content.boxed .archive-page.zta-blog-layout-1 article.zita-article .entry-content-outer-wrapper:before,
   .archive #content.boxed .archive-page.zta-blog-layout-1 article.zita-article .entry-content-outer-wrapper:before,
    .archive #content.contentbox .archive-page.zta-blog-layout-1 article.zita-article .entry-content-outer-wrapper:before,
    .archive #content.boxed .archive-page.zta-blog-layout-2 article.zita-article .entry-content-outer-wrapper:before,
    .archive #content.contentbox .archive-page.zta-blog-layout-2 article.zita-article .entry-content-outer-wrapper:before,
     .archive #content.boxed .archive-page.zta-blog-layout-3 article.zita-article .entry-content-outer-wrapper:before,
      .archive #content.contentbox .archive-page.zta-blog-layout-3 article.zita-article .entry-content-outer-wrapper:before, 
    .archive #content.boxed .archive-page.zta-blog-layout-4 article.zita-article .entry-content-outer-wrapper:before,
     .archive #content.contentbox .archive-page.zta-blog-layout-4 article.zita-article .entry-content-outer-wrapper:before, 
    .page #content.site-content.contentbox article.zita-article, .single #content.site-content.blog-single.contentbox article.zita-article,
     .archive #content.site-content.archive-page.contentbox article.zita-article, .page #content.site-content.boxed article.zita-article, 
     .archive #content.site-content.archive-page.boxed article.zita-article, 
     .page #content.site-content.boxed #sidebar-primary.widget-area section,
      .single #content.site-content.blog-single.boxed #sidebar-primary.widget-area section,
       .archive #content.site-content.archive-page.boxed #sidebar-primary.widget-area section,
       body.fullwidthcontained.maxwidth #content:before,
        body.fullwidthcontained.padding #content:before,
         .single #content.site-content.blog-single.boxed article.zita-article:before, 
         .single #content.site-content.blog-single.contentbox article.zita-article:before,
          body.maxwidth #content.site-content.blog-single.fullwidthcontained:before,
           body.padding #content.site-content.blog-single.fullwidthcontained:before,
            body.archive.maxwidth #content.site-content.fullwidthcontained:before,
             body.archive.padding #content.site-content.fullwidthcontained:before,
              body.page.maxwidth #content.site-content.fullwidthcontained:before, 
           body.page.padding #content.site-content.fullwidthcontained:before{
    background-color: #fff;
}
.contentbox .zita-related-post:before,
.boxed .zita-related-post:before{
  content: '';
 background-color:transparent;
 width: 100%;
 height: 100%;
 position: absolute;
 left: 0;
 top: 0;
 z-index:0;
 display: block;
}
/*********************/
/*container style start*/
/*********************/
body{background-color: #f5f5f5;}
#sidebar-primary.widget-area section{
padding: 20px;
margin-bottom: 20px;
}
.sidebar-main .zita-widget-content{
position:relative;
display:block
}
.boxed.maxwidth .site-content #container {
    padding: 0;
}
.contentbox #sidebar-primary.widget-area section{
background:transparent;
padding:0;
}
.fullwidthcontained .site-content article.zita-article .entry-content-outer-wrapper,
.fullwidthstrechched .site-content article.zita-article .entry-content-outer-wrapper{
padding-bottom:25px;
border-bottom:1px solid #eee;
}
.fullwidthcontained .site-content:before,
.site-content.fullwidthcontained:before{
    content: '';
    background-color: #fff;
    width: 100%;
    height: 100%;
    position: absolute;
    left: 0;
    top: 0;
    z-index: 0;
    display: block;
}
.fullwidthcontained #content article.zita-article{
    padding: 0px;
    margin-bottom:30px;
    background: transparent;
        position: relative;
}
.fullwidthcontained #sidebar-primary.widget-area section,
.fullwidthstrechched #sidebar-primary.widget-area section:before,
.fullwidthcontained #sidebar-primary.widget-area section:before,
.fullwidthcontained #sidebar-primary.widget-area section,
.contentbox #sidebar-primary.widget-area section:before{
padding:0;
background:transparent;
}
.fullwidthstrechched #content #container,
.fullwidthstrechched.fullwidth #content #container{
max-width:100%;
padding:0;
width:100%;
}
.fullwidthstrechched .site-content {
background:transparent;
}
.fullwidthstrechched #content article.zita-article {
    padding: 0px;
    margin-bottom: 50px;
    border: 0px;
    background: transparent;
}
.fullwidthstrechched #sidebar-primary.widget-area section{
padding:0;
background:transparent;
}
.fullwidthcontained #content.blog-single article.zita-article,
.fullwidthstrechched #content.blog-single article.zita-article{
padding:0;
}
/*For pages style*/
/*boxed layout*/
/*RIGHT-SIDEBAR*/
.site-content.blog-single.boxed .site-container.right #primary, 
.contentbox .site-content.blog-single.boxed .site-container.right #primary{
border: 0;
padding-right: 0;
}
.site-content.blog-single.boxed .site-container #sidebar-primary {
padding-left: 20px;
padding-right: 0;
}
/*LEFT-SIDEBAR*/
.site-content.blog-single.boxed .site-container.left #primary{
border: 0;
padding-right: 0;
padding-left: 0;
}
.site-content.blog-single.boxed .site-container.right #primary{
border: 0;
padding-left: 0;
}
.site-content.blog-single.boxed .site-container.left #sidebar-primary {
padding-right: 20px;
padding-left: 0;
}
.site-content.blog-single.boxed,.site-content.blog-single.contentbox{
background:transparent;
}
.site-content.blog-single.boxed #container,
.site-content.blog-single.contentbox #container,
.site-content.blog-single.fullwidthcontained #container{
margin-left: auto;
    margin-right: auto;
    padding-left: 20px;
    padding-right: 20px;
    max-width: 1200px;
    width: 100%;
    box-sizing: border-box;
}
/*boxed layout*/
/*default pages layout*/
.page.boxed #content.site-content article.zita-article,
.page.contentbox #content.site-content article.zita-article{
    background-color:transparent;
    border-bottom: 1px solid #eee;
    margin: 0;
    padding: 20px;
}
.page .site-content.boxed .site-container.left #primary{
border: 0;
padding-right: 0;
padding-left: 0;
}
.page .site-content.boxed .site-container.right #primary{
border: 0;
padding-right: 0;
}
.page .site-content.boxed .site-container.right #sidebar-primary {
    padding-left: 20px;
    padding-right: 0;
}
.page .site-content.boxed .site-container.right #sidebar-primary {
    padding-left: 20px;
    padding-right: 0;
}
.page .site-content.boxed .site-container.left #sidebar-primary {
    padding-left: 20px;
    padding-right: 0;
}
.page .site-content.boxed .site-container.left #sidebar-primary {
    padding-right: 20px;
    padding-left: 0;
}
.page .site-content.fullwidthcontained .site-container.right #primary,
.page .site-content.fullwidthstrechched .site-container.right #primary {
    border-right: 1px solid #eee;
    padding-right: 50px;
}
.page .site-content.fullwidthcontained .site-container.left #primary,
.page .site-content.fullwidthstrechched .site-container.left #primary {
    border-left: 1px solid #eee;
    padding-left: 50px;
}
.page .site-content.boxed,.page .site-content.contentbox{
background:transparent;
}
/*default pages layout*/
/*archive page layout*/
.archive .site-content.boxed .archive-page .site-container.left #primary,
.archive .site-content.contentbox .archive-page .site-container.left #primary{
border: 0;
padding-right: 0;
padding-left: 0;
}
.archive .site-content.boxed .archive-page #sidebar-primary.widget-area section{
    padding: 2em;
}
.archive .site-content.boxed .site-container.archive-page.right #primary,
.archive .site-content.contentbox  .site-container.archive-page.right #primary{
border: 0;
padding-right: 0;
}
.archive  .site-content.boxed  .site-container.archive-page.right #sidebar-primary {
    padding-left: 20px;
    padding-right: 0;
}
.archive .site-content.boxed  .site-container.archive-page.right #sidebar-primary {
    padding-left: 20px;
    padding-right: 0;
}
.archive .site-content.boxed  .site-container.archive-page.left #sidebar-primary {
    padding-left: 20px;
    padding-right: 0;
}
.archive .site-content.boxed  .site-container.archive-page.left #sidebar-primary {
    padding-right: 20px;
    padding-left: 0;
}
.archive .site-content.contentbox  .site-container.archive-page.right #sidebar-primary {
    padding-left: 50px;
    padding-right: 0;
}
.archive .site-content.contentbox   .site-container.archive-page.right #sidebar-primary {
    padding-left: 50px;
    padding-right: 0;
}
.site-content.fullwidthcontained  .site-container.archive-page.right #primary,
.site-content.fullwidthstrechched  .site-container.archive-page.right #primary {
    border-right: 1px solid #eee;
    padding-right: 50px;
}
.site-content.fullwidthcontained  .site-container.archive-page.left #primary,
.site-content.fullwidthstrechched  .site-container.archive-page.left #primary {
    border-left: 1px solid #eee;
    padding-left: 50px;
}
.site-content.fullwidthcontained  .site-container.archive-page #sidebar-primary,
.site-content.fullwidthstrechched  .site-container.archive-page #sidebar-primary{
    padding-left: 50px;
    padding-right: 0;
}
.site-content.fullwidthcontained  .site-container.archive-page.left #sidebar-primary,
.site-content.fullwidthstrechched  .site-container.archive-page.left #sidebar-primary {
    padding-right: 50px;
    padding-left: 0;
}
.site-content.boxed .archive-page,.site-content.contentbox .archive-page{
background:transparent;
}
.site-content.boxed .archive-page #container,
.site-content.contentbox .archive-page #container,
.site-content.fullwidthcontained .archive-page #container{
margin-left: auto;
    margin-right: auto;
    padding-left: 20px;
    padding-right: 20px;
    max-width: 1200px;
    width: 100%;
    box-sizing: border-box;
}
.fullwidthcontained .site-content .archive-page article.zita-article .entry-content-outer-wrapper{
    padding-bottom:0px;
    border-bottom:none;
}
.site-content.fullwidthcontained .archive-page article.zita-article .entry-content-outer-wrapper{
      padding-bottom: 25px;
    border-bottom: 1px solid #eee;
}
.archive #content.boxed .archive-page.zta-blog-layout-1 article.zita-article,
.archive #content.contentbox .archive-page.zta-blog-layout-1 article.zita-article{
-js-display: flex;
    display: -webkit-box;
    display: -webkit-flex;
    display: -moz-box;
    display: -ms-flexbox;
    display: flex;
    margin-bottom: 20px;
    background: 0 0;
    border: none;
    padding:0 10px;
}
.archive #content.boxed .archive-page.zta-blog-layout-2 article.zita-article,
.archive #content.contentbox .archive-page.zta-blog-layout-2 article.zita-article,
.archive #content.boxed .archive-page.zta-blog-layout-3 article.zita-article,
.archive #content.contentbox .archive-page.zta-blog-layout-3 article.zita-article,
.archive #content.boxed .archive-page.zta-blog-layout-4 article.zita-article,
.archive #content.contentbox .archive-page.zta-blog-layout-4 article.zita-article{
  padding:0;
}
.archive #content.boxed .archive-page.zta-blog-layout-1 article.zita-article .entry-content-outer-wrapper,
.archive #content.contentbox .archive-page.zta-blog-layout-1 article.zita-article  .entry-content-outer-wrapper,
.archive #content.boxed .archive-page.zta-blog-layout-2 article.zita-article .entry-content-outer-wrapper,
.archive #content.contentbox .archive-page.zta-blog-layout-2 article.zita-article  .entry-content-outer-wrapper,
.archive #content.boxed .archive-page.zta-blog-layout-3 article.zita-article .entry-content-outer-wrapper,
.archive #content.contentbox .archive-page.zta-blog-layout-3 article.zita-article  .entry-content-outer-wrapper,
.archive #content.boxed .archive-page.zta-blog-layout-4 article.zita-article .entry-content-outer-wrapper,
.archive #content.contentbox .archive-page.zta-blog-layout-4 article.zita-article  .entry-content-outer-wrapper{
    padding: 20px;
    background: #fff;
    width: 100%;
    border: none;
}
.archive #content.boxed .archive-page.zta-blog-layout-1 article.zita-article .entry-content-outer-wrapper:before,
.archive #content.contentbox .archive-page.zta-blog-layout-1 article.zita-article  .entry-content-outer-wrapper:before,
.archive #content.boxed .archive-page.zta-blog-layout-2 article.zita-article .entry-content-outer-wrapper:before,
.archive #content.contentbox .archive-page.zta-blog-layout-2 article.zita-article  .entry-content-outer-wrapper:before,
.archive #content.boxed .archive-page.zta-blog-layout-3 article.zita-article .entry-content-outer-wrapper:before,
.archive #content.contentbox .archive-page.zta-blog-layout-3 article.zita-article  .entry-content-outer-wrapper:before,
.archive #content.boxed .archive-page.zta-blog-layout-4 article.zita-article .entry-content-outer-wrapper:before,
.archive #content.contentbox .archive-page.zta-blog-layout-4 article.zita-article  .entry-content-outer-wrapper:before{
    content: '';
    background: rgba(0, 0, 0, 0);
    width: 100%;
    height: 100%;
    position: absolute;
    left: 0;
    top: 0;
    z-index: 0;
    display: block;
}
/*archive page layout*/
/*content boxed layout*/
#content.site-content.contentbox .site-container.left #primary{
border: 0;
padding-right: 0;
padding-left: 0;
}
#content.site-content.contentbox .site-container.right #primary{
border: 0;
padding-right: 0;
}
#content.site-content.contentbox .site-container #sidebar-primary{
 padding-left:50px;
 padding-right: 0;   
}
#content.site-content.contentbox .site-container.left #sidebar-primary{
 padding-right:50px;
 padding-left: 0;   
}
/*content boxed layout*/
/*full width*/
#content.site-content.fullwidthcontained .site-container.right #primary,
#content.site-content.fullwidthstrechched .site-container.right #primary {
    border-right: 1px solid #eee;
    padding-right: 50px;
}
#content.site-content.fullwidthcontained .site-container.left #primary,
#content.site-content.fullwidthstrechched .site-container.left #primary {
    border-left: 1px solid #eee;
    padding-left: 50px;
}

#content.site-content.fullwidthcontained .site-container #sidebar-primary,
#content.site-content.fullwidthstrechched .site-container #sidebar-primary{
    padding-left: 50px;
    padding-right: 0;
}
#content.site-content.fullwidthcontained .site-container.left #sidebar-primary,
#content.site-content.fullwidthstrechched .site-container.left #sidebar-primary {
    padding-right: 50px;
    padding-left: 0;
}
/*full width*/
.page #content.site-content.boxed article.zita-article,
.single #content.site-content.blog-single.boxed article.zita-article,
.archive #content.site-content.archive-page.boxed article.zita-article{
    background-color: #fff;
    border-bottom:none;
    margin: 0;
    padding: 20px;
}
.page #content.site-content.boxed #sidebar-primary.widget-area section,
.single #content.site-content.blog-single.boxed #sidebar-primary.widget-area section,
.archive #content.site-content.archive-page.boxed #sidebar-primary.widget-area section {
    background-color: #fff;
    padding: 2em;
}
.page #content.site-content.contentbox article.zita-article,
.single #content.site-content.blog-single.contentbox article.zita-article,
.archive #content.site-content.archive-page.contentbox article.zita-article{
    background-color: #fff;
    border-bottom:none;
    margin: 0;
    padding: 20px;
}

.page #content.site-content.fullwidthcontained article.zita-article,
.single #content.site-content.blog-single.fullwidthcontained article.zita-article,
.archive #content.site-content.archive-page.fullwidthcontained article.zita-article{
    background-color:transparent;
    padding: 0px;
    margin-bottom:0px;
    border: 0px;
}

.page #content.site-content.fullwidthstrechched #container,
.single #content.site-content.blog-single.fullwidthstrechched #container,
.archive #content.site-content.archive-page.fullwidthstrechched #container{
    max-width: 100%;
    width: 100%;
    padding: 0;
}
.single #content.site-content.blog-single.fullwidthstrechched article.zita-article,
.archive #content.site-content.archive-page.fullwidthstrechched article.zita-article{
    padding: 0px;
    margin-bottom:30px;
    border: 0px;
    background: transparent;
}
.page #content.site-content.fullwidthstrechched article.zita-article{
   padding:0;
   margin:0;
}
.single #content.site-content.blog-single.fullwidthcontained article.zita-article:before,
.single #content.site-content.blog-single.fullwidthcontained #comments:before,
.single #content.site-content.blog-single.fullwidthstrechched article.zita-article:before,
.single #content.site-content.blog-single.fullwidthstrechched #comments:before{
   background:transparent!important;
}

/*********************/
/*container style end*/
/*********************/
/********************************/
/*header style*/
/********************************/
header{
width:100%;
display:block;  
}
.main-header-bar {
    z-index: 4;
    position: relative;
    padding: 1em 0;
    border-bottom: solid;
    border-bottom-color: #eee;
    border-bottom-width: 1px;
    background:#fff;
}
.bottom-header-bar{
    position: relative;
    border-bottom: solid;
    border-bottom-color: #eee;
    border-bottom-width: 1px;
    background:#fff;
}
.container,#container {
    margin-left: auto;
    margin-right: auto;
    padding-left: 20px;
    padding-right: 20px;
    max-width:1200px;
    width: 100%;
    box-sizing: border-box;
    position: relative;
}
 .site-title span{
font-size: 32px;
line-height: 40px;
}
/******************************/
/*top header style*/
/******************************/
/*menu*/
.top-header-bar  .zita-menu > li > a,
.bottom-header-bar  .zita-menu > li > a{
padding:5px 8px;  
}
/*top search*/
.searchfrom{
float:right;
position:relative;
}
.searchfrom .search-btn{
text-align: center;
background:transparent;
display: block;
width:2.1em;
height:2.1em;
line-height:2.1em;
border:1px solid transparent;
}
.searchfrom #searchform{
position:absolute;
right: 0;
display:none;
z-index:999;
width:230px;
}
 .searchfrom #searchform input[type=submit]{
    display: block;
    width: 20px;
    position: absolute;
    font-size: 0;
    right: 0px;
    top: 0px;
    height: 20px;
    line-height: 30px;
    z-index:3;
    background: transparent;
    border: none;
    margin-top: 0px;
    height: 40px;
    width: 40px;
    padding:0;

}
.searchfrom input#s{
    z-index: 1;
    border: none;
    height: 40px;
    line-height: normal;
    margin-bottom: 0;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background: #f3f3f3;
    position: relative;
    width: 50px;
    top: 100%;
    border: 1px solid #ddd;
    width:100%;
    padding: 0px 10px;
    font-size: 13px;
}
.searchfrom #searchform .form-content:before{
content: "\f002";
font-family: FontAwesome;
position: absolute;
color:#015782;
right: 0;
width: 40px;
height: 40px;
line-height: 40px;
z-index: 2;
font-size: 15px;
text-align: center;
}
.searchfrom{
box-shadow:none;
}
.searchfrom #searchform .form-content{
 float:right; 
     line-height: normal;
}
/*widget area*/
.widget-area .searchfrom #searchform {
    position: absolute;
    right: 0;
    display: none;
    z-index: 999;
    width: 230px;
}
.widget-area #searchform{
    position: relative;
    display: block;
    width:100%;
}
.widget-area input#s{
    z-index: 1;
    border: none;
    height:40px;
    line-height: normal;
    margin-bottom: 0;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background: #f3f3f3;
    position: relative;
    top: 100%;
    border: 1px solid #ddd;
    width:100%;
    font-size: 13px;
}

.widget-area #searchform input[type=submit] {
    display: block;
    width: 20px;
    position: absolute;
    font-size: 0;
    top: 0px;
    right:0;
    height: 20px;
    line-height: 30px;
    z-index: 3;
    background: transparent;
    border: none;
    margin-top: 0px;
    height: 40px;
    width: 40px;
    padding:0;
}
.widget-area #searchform .form-content:before{
content: "\f002";
font-family: FontAwesome;
position: absolute;
color:#015782;
right: 0;
width: 40px;
height: 40px;
line-height: 40px;
z-index: 2;
font-size: 15px;
text-align: center;
}
.widget-area #searchform input[type=submit]:hover{
cursor: pointer;    
}
.widget-area input#s::-webkit-input-placeholder{
color: #bbb;
}
#searchform .form-content{
width:100%;
position: relative;
}
.search-no-results .page-content .form-content input#s{
margin:20px 0;
}
/*leftpan style*/
.mhdrleftpan header{
  box-sizing: border-box;
  overflow:visible;
border-right: 1px solid rgba(0,0,0,.1);
display: block;
    position: fixed;
    top: 0;
    left: 0;
    height: 100%;
    z-index: 999;
    width: 270px;
    max-width: 100%;
    font-size: 15px;
    background-color: #fff;
    color: #555; 
}
.mhdrleftpan #page.zita-site{
margin-left:280px;
}
.mhdrleftpan .zita-menu {
    float: left;
    width: 100%;
}
.mhdrleftpan nav{
 width:100%;
}

.mhdrleftpan .main-header-bar.two .main-header-col1,
.mhdrrightpan .main-header-bar.two .main-header-col1{
width:100%;
}
/*left pan*/
.zita-site .mhdrrightpan .top-header-bar,
.zita-site .mhdrleftpan .top-header-bar,
.zita-site .mhdrrightpan .top-header-bar:before,
.zita-site .mhdrleftpan .top-header-bar:before,
.zita-site .mhdrrightpan .bottom-header-bar,
.zita-site .mhdrleftpan .bottom-header-bar,
.zita-site .mhdrrightpan .bottom-header-bar:before,
.zita-site .mhdrleftpan .bottom-header-bar:before,
.zita-site .mhdrleftpan .sider-inner ul#zita-menu,
.zita-site .mhdrrightpan .sider-inner ul#zita-menu,
.zita-site .mhdrrightpan .sider-inner ul#zita-menu.zita-menu > li > a:hover,
.zita-site .mhdrleftpan .sider-inner ul#zita-menu.zita-menu > li > a:hover,
.zita-site .mhdrrightpan .zita-menu li ul.sub-menu,
.zita-site .mhdrleftpan .zita-menu li ul.sub-menu,
.zita-site .mhdrleftpan #zita-above-menu.zita-menu li ul.sub-menu,
.zita-site .mhdrrightpan #zita-above-menu.zita-menu li ul.sub-menu,
.zita-site .mhdrrightpan #zita-above-menu.zita-menu li ul.sub-menu li:hover,
.zita-site .mhdrleftpan #zita-above-menu.zita-menu li ul.sub-menu li:hover,
.zita-site .mhdrleftpan .main-header .sider-inner ul.zita-menu li ul.sub-menu,
.zita-site .mhdrrightpan .main-header .sider-inner ul.zita-menu li ul.sub-menu,
.zita-site .mhdrrightpan .main-header #zita-menu.zita-menu li ul.sub-menu li:hover,
.zita-site .mhdrleftpan .main-header #zita-menu.zita-menu li ul.sub-menu li:hover,
.main-header.mhdrleftpan nav,
.main-header.mhdrrightpan nav,
.main-header.mhdminbarright nav,
.main-header.mhdminbarleft nav{
background:transparent;
}
.zita-site .mhdrleftpan .menu-custom-widget{
text-align:left;
}
/*rightpan style*/
.mhdrrightpan header{
    box-sizing: border-box;
   overflow:visible;
    border-left: 1px solid rgba(0,0,0,.1);
    display: block;
    position: fixed;
    top: 0;
    left:auto;
    right:0;
    height: 100%;
    z-index: 999;
    width: 270px;
    max-width: 100%;
    font-size: 15px;
    background-color:#fff;
    color: #555; 
}
.mhdrrightpan #page.zita-site{
margin-right:280px;
}
.mhdrrightpan .zita-menu {
    float: right;
    width: 100%;
}
.mhdrrightpan nav{
 width:100%;
}
.mhdrrightpan .menu-toggle .menu-btn{
display:none;
}
.mhdrrightpan .hide-menu{
display:block;
}
.mhdrrightpan .zita-menu li a,
.mhdrleftpan .zita-menu li a{
padding:10px 0px!important;
}
.mhdrleftpan .content-social .social-icon a,
.mhdrrightpan .content-social .social-icon a{
display: initial;
}
.mhdrleftpan .content-social .social-icon a, 
.mhdrrightpan .content-social .social-icon a{
    display: initial;
    margin-right: 5px;
}
/*right pan*/
header.mhdrrightpan .container,
header.mhdrleftpan .container{
    max-width: 100%;
    padding: 0;

}
header.mhdrrightpan .top-header-col1,
header.mhdrrightpan .top-header-col2,
header.mhdrrightpan .top-header-col3,
header.mhdrleftpan .top-header-col1,
header.mhdrleftpan .top-header-col2,
header.mhdrleftpan .top-header-col3,
header.mhdrrightpan .bottom-header-col1,
header.mhdrrightpan .bottom-header-col2,
header.mhdrrightpan .bottom-header-col3,
header.mhdrleftpan .bottom-header-col1,
header.mhdrleftpan .bottom-header-col2,
header.mhdrleftpan .bottom-header-col3,
header.mhdrleftpan .content-html,
header.mhdrrightpan .content-html{
width: 100%!important;
text-align: left!important;
line-height: normal;
}
header.mhdrrightpan .content-social,header.mhdrleftpan .content-social{
width:100%;
}
header.mhdrrightpan .top-header-bar,
header.mhdrleftpan .top-header-bar,
header.mhdrrightpan .main-header-bar,
header.mhdrleftpan .main-header-bar,
header.mhdrrightpan .bottom-header-bar,
header.mhdrleftpan .bottom-header-bar{
border:none;
padding:0;
}
header.mhdrrightpan .searchfrom .search-btn,
header.mhdrleftpan .searchfrom .search-btn{
display:none;
}
header.mhdrrightpan .searchfrom #searchform,
header.mhdrleftpan .searchfrom #searchform{
display:block;
}
header.mhdrrightpan .searchfrom,
header.mhdrleftpan .searchfrom{
display: flex;   
padding:10px 0px;
    float: none;
}
header.mhdrrightpan .searchfrom #searchform,
header.mhdrleftpan .searchfrom #searchform{
    position:relative;
}
header.mhdrleftpan .top-header-col1,
header.mhdrleftpan .top-header-col2,
header.mhdrleftpan .top-header-col3,
header.mhdrleftpan .bottom-header-col1,
header.mhdrleftpan .bottom-header-col2,
header.mhdrleftpan .bottom-header-col3,
header.mhdrleftpan .main-header-col2,
header.mhdrrightpan .top-header-col1,
header.mhdrrightpan .top-header-col2,
header.mhdrrightpan .top-header-col3,
header.mhdrrightpan .bottom-header-col1,
header.mhdrrightpan .bottom-header-col2,
header.mhdrrightpan .bottom-header-col3,
header.mhdrrightpan .main-header-col2{
margin-top:10px;
width: 100%!important;
-webkit-flex:auto!important;
-moz-box-flex: auto!important;
-ms-flex: auto!important;
flex: auto!important;
justify-content: flex-start;
}
header.mhdrrightpan .zita-menu.collapse span.arrow,
header.mhdrleftpan .zita-menu.collapse span.arrow{
    position: absolute;
    right: 0px;
    height: 100%;
    width: 30px;
    top:0;
}
header.mhdrrightpan .zita-menu.collapse li a .arrow:before,
header.mhdrleftpan .zita-menu.collapse li a .arrow:before{
line-height: 45px;
 margin-right: 10px;
}
header.mhdrrightpan .zita-menu.collapse > li > ul.sub-menu li > a > .arrow:before,
header.mhdrleftpan .zita-menu.collapse > li > ul.sub-menu li > a > .arrow:before{
    margin-right: 10px;

}
header.mhdrrightpan .sider-inner ul#zita-menu.zita-menu > li > a,
header.mhdrleftpan .sider-inner ul#zita-menu.zita-menu > li > a {
    padding: 10px 0px!important;
}
header.mhdrrightpan .main-header .menu-custom-html,
header.mhdrleftpan .main-header .menu-custom-html{
padding: 10px 0px!important;  
}
.mhdrleftpan .site-content #primary,.mhdrrightpan .site-content #primary{
margin:20px 0px;
}
.mhdrleftpan .site-container #sidebar-primary,.mhdrrightpan .site-container #sidebar-primary{
margin:20px 0px;
}
.mhdrleftpan li.menu-item.zta-custom-item,
.mhdrrightpan li.menu-item.zta-custom-item{
padding:10px 0px;
}
header.mhdrleftpan .content-social ul.social-icon, 
header.mhdrrightpan .content-social ul.social-icon{
margin: 0;
display: block;
}
.mhdrleftpan .zita-menu .content-social .social-icon li,
.mhdrrightpan .zita-menu .content-social .social-icon li {
    padding: 0px 0px;
    display: -webkit-inline-box;
}
header.mhdrleftpan .content-social ul.social-icon li,
header.mhdrrightpan .content-social ul.social-icon li{
    padding: 0px;
    display: -webkit-inline-box;
}
.mhdrleftpan li.menu-item:last-child,
.mhdrrightpan li.menu-item:last-child{
border:0;
}
/***********************/
/*Min Bar Left*/
/***********************/
.min-bar-header.leftminbar{
    float: left;
    width:auto;
    position: fixed !important;
    height: 100%;
    transition: left .2s ease-in-out;
    z-index: 9999;
    width: 80px;
}
.min-bar-header{
    background-color: #fafafa;
    border-bottom: 1px solid rgba(0,0,0,.1);
    position: relative;
    width: 100%;
    padding: 10px 0px;
    z-index: 999;
    left: 0;
    -webkit-transition: all .3s ease-in-out;
    -moz-transition: all .3s ease-in-out;
    transition: all .3s ease-in-out;
}
.min-bar-col2{
    -webkit-transform: rotate(-90deg);
    -moz-transform: rotate(-90deg);
    transform: rotate(-90deg);
    -webkit-transform-origin: 0 0;
    -moz-transform-origin: 0 0;
    transform-origin: 0 0;
    position: fixed;
    bottom: 0px;
    left: 14px;
}
.min-bar-header.leftminbar .site-title,
.min-bar-header.leftminbar .site-description{
display:inline-block;
}
.min-bar-header .site-title span{
font-size: 42px;
padding-top: 0;
letter-spacing: .08em;
margin: 0 .1em 0 0;
display: inline-block;
vertical-align: middle;
}
.min-bar-container{
text-align:center;
}
header.mhdminbarleft{
    box-sizing: border-box;
    overflow: visible;
    border-right: 1px solid rgba(0,0,0,.1);
    display: block;
    position: fixed;
    left:100px;
    height: 100%;
    z-index: 999;
    width: 270px;
    max-width: 100%;
    font-size: 15px;
    background-color: #fff;
    color: #555;
}
header.mhdminbarleft .container{
    max-width: 100%;
    padding: 0;
}
header.mhdminbarleft nav {
    width: 100%;
}
header.mhdminbarleft .sider-inner ul#zita-menu.zita-menu > li > a,
.mhdminbarleft .zita-menu li a{
    padding: 10px 0px!important;
line-height:normal;
}
.mhdminbarleft li.menu-item:last-child{
    border: 0;
}
header.mhdminbarleft .top-header-bar,
header.mhdminbarleft .main-header-bar,
header.mhdminbarleft .bottom-header-bar{
    border: none;
    padding: 0;
}
header.mhdminbarleft .zita-menu li ul.sub-menu{
background:none;
}
header.mhdminbarleft{
    left: -270px!important;
    right: auto;
    -webkit-transition: left .2s ease-in-out;
    -moz-transition: left .2s ease-in-out;
    transition: left .2s ease-in-out;
}
.mobile-pan-active header.mhdminbarleft{
    left:80px!important;
    right: auto;
    -webkit-transition: left .2s ease-in-out;
    -moz-transition: left .2s ease-in-out;
    transition: left .2s ease-in-out;
}
.mobile-pan-active.mhdminbarleft #page.zita-site,
.cart-pan-active.mhdminbarleft #page.zita-site {
    left: 270px!important;
    -webkit-transition: left .2s ease-in-out;
    -moz-transition: left .2s ease-in-out;
    transition: left .2s ease-in-out;
}
.mhdminbarleft #page.zita-site {
    margin-left:80px!important;
    left:0;
    -webkit-transition: left .2s ease-in-out;
    -moz-transition: left .2s ease-in-out;
    transition: left .2s ease-in-out;
}
body.mobile-pan-active{
    overflow-x: hidden;
}
.mhdminbarleft .menu-close{
    display: none;
}
.mhdminbarleft .menu-toggle{
    display: none!important;
}
.mhdminbarleft .sider .hide-menu{
    display: block;
}
.zita-site .mhdminbarleft .sider.left{
    background: transparent;
    padding: 0;
    overflow-x: inherit;
    overflow-y: inherit;
}
.mhdminbarleft .sider {
    left: 0;
    position: inherit;
}
.mhdminbarleft .sider{
    width: 100%;
    max-width: 100%;
    padding-bottom: 0;
    height: auto;
    display:block;
}
header.mhdminbarleft .zita-cart {
    display: block;
    position: fixed;
    top: 0;
    height: 100vh;
    z-index: 999999;
    left: -270px;
    width: 270px;
    padding: 2em 1.5em;
    max-width: 100%;
    border-right: 1px solid rgba(0,0,0,.1);
    overflow-x: hidden;
    overflow-y: auto;
    font-size: 15px;
    background-color: #fff;
    color: #555;
    -webkit-touch-callout: none;
    user-select: none;
    -webkit-overflow-scrolling: touch;
    visibility: visible;
    -moz-opacity: 1;
    -webkit-opacity: 1;
    opacity: 1;
}
.cart-pan-active header.mhdminbarleft .zita-cart {
    left:80px;
    right: auto;
    transition: left 0.2s ease;
}
header.mhdminbarleft .main-header-col2{
-webkit-justify-content: flex-start;
justify-content: flex-start;
}
header.mhdminbarleft .top-header-col1, 
header.mhdminbarleft .top-header-col2, 
header.mhdminbarleft .top-header-col3, 
header.mhdminbarleft .bottom-header-col1, 
header.mhdminbarleft .bottom-header-col2, 
header.mhdminbarleft .bottom-header-col3{
    margin-top: 10px;
    width: 100%!important;
    -webkit-flex: auto!important;
    -moz-box-flex: auto!important;
    -ms-flex: auto!important;
    flex: auto!important;
    justify-content: flex-start;
}
header.mhdminbarleft .searchfrom .search-btn {
    display: none;
}
header.mhdminbarleft .searchfrom {
   display:flex;
   padding: 10px 0px;
}
header.mhdminbarleft .searchfrom #searchform {
    display: block;
    position:relative;
}
header.mhdminbarleft li.menu-item.zta-custom-item{
padding: 10px 0px;
}
header.mhdminbarleft .zita-quickcart-dropdown{
width: 234px;
padding:0;
padding-top:20px;
max-width: 100%;
max-height:100%;
text-align: left;
}
header.mhdminbarleft .zita-cart a.remove{
margin-right:40px;
}
.zita-site .mhdminbarleft  .top-header-bar,
.zita-site .mhdminbarright .top-header-bar,
.zita-site .mhdminbarleft .top-header-bar:before,
.zita-site .mhdminbarright .top-header-bar:before,
.zita-site .mhdminbarright .bottom-header-bar,
.zita-site .mhdminbarleft .bottom-header-bar,
.zita-site .mhdminbarright .bottom-header-bar:before,
.zita-site .mhdminbarleft .bottom-header-bar:before,
.zita-site .mhdminbarleft .sider-inner ul#zita-menu,
.zita-site .mhdminbarright .sider-inner ul#zita-menu,
.zita-site .mhdminbarright .sider-inner ul#zita-menu.zita-menu > li > a:hover,
.zita-site .mhdminbarleft .sider-inner ul#zita-menu.zita-menu > li > a:hover,
.zita-site .mhdminbarright .zita-menu li ul.sub-menu,
.zita-site .mhdminbarleft .zita-menu li ul.sub-menu,
.zita-site .mhdminbarleft #zita-above-menu.zita-menu li ul.sub-menu,
.zita-site .mhdminbarright #zita-above-menu.zita-menu li ul.sub-menu,
.zita-site .mhdminbarright #zita-above-menu.zita-menu li ul.sub-menu li:hover,
.zita-site .mhdminbarleft #zita-above-menu.zita-menu li ul.sub-menu li:hover,
.zita-site .mhdminbarleft .main-header .sider-inner ul.zita-menu li ul.sub-menu,
.zita-site .mhdminbarright .main-header .sider-inner ul.zita-menu li ul.sub-menu,
.zita-site .mhdminbarright .main-header #zita-menu.zita-menu li ul.sub-menu li:hover,
.zita-site .mhdminbarleft .main-header #zita-menu.zita-menu li ul.sub-menu li:hover{
background:transparent;
}
/***********************/
/*Min Bar Right*/
/***********************/
.min-bar-header.rightminbar .min-bar-col2{
    right: auto;
    left: auto;
    width:fit-content;
    padding-top: 14px;
}
.min-bar-header.rightminbar{
    float: right;
    width:auto;
    position: fixed !important;
    height: 100%;
    transition: right .2s ease-in-out;
    z-index: 9999;
    width: 80px;
}
.min-bar-header.rightminbar{
    background-color: #fafafa;
    border-bottom: 1px solid rgba(0,0,0,.1);
    min-height: 55px;
    z-index: 999;
    left:auto;
    right:0;
    -webkit-transition: all .3s ease-in-out;
    -moz-transition: all .3s ease-in-out;
    transition: all .3s ease-in-out;
}
.min-bar-header.rightminbar .site-title,
.min-bar-header.rightminbar .site-description{
display:inline-block;
}

header.mhdminbarright{
    box-sizing: border-box;
    overflow: visible;
    border-right: 1px solid rgba(0,0,0,.1);
    display: block;
    position: fixed;
    left:100px;
    height: 100%;
    z-index: 999;
    width: 270px;
    max-width: 100%;
    font-size: 15px;
    background-color: #fff;
    color: #555;
}
header.mhdminbarright .container{
    max-width: 100%;
    padding: 0;
}
header.mhdminbarright nav {
    width: 100%;
}
header.mhdminbarright .sider-inner ul#zita-menu.zita-menu > li > a,
.mhdminbarright .zita-menu li a{
padding: 10px 0px!important;
line-height:normal;
}
.mhdminbarright li.menu-item:last-child{
    border: 0;
}
header.mhdminbarright .top-header-bar,
header.mhdminbarright .main-header-bar,
header.mhdminbarright .bottom-header-bar{
    border: none;
    padding: 0;
}
header.mhdminbarright .zita-menu li ul.sub-menu{
background:none;
}
header.mhdminbarright{
    right:-270px!important;
    left: auto;
    -webkit-transition: right .2s ease-in-out;
    -moz-transition: right .2s ease-in-out;
    transition: right .2s ease-in-out;
}
.mobile-pan-active header.mhdminbarright{
    right:80px!important;
    left: auto;
    -webkit-transition:right .2s ease-in-out;
    -moz-transition:right .2s ease-in-out;
    transition:right .2s ease-in-out;
}
.mobile-pan-active.mhdminbarright #page.zita-site,
.cart-pan-active.mhdminbarright #page.zita-site {
    right: 270px!important;
    -webkit-transition: right .2s ease-in-out;
    -moz-transition:right .2s ease-in-out;
    transition:right .2s ease-in-out;
}
.mhdminbarright #page.zita-site {
    right: 0px!important;
    margin-right:80px;
    -webkit-transition:right .2s ease-in-out;
    -moz-transition:right .2s ease-in-out;
    transition:right .2s ease-in-out;
}
body.mobile-pan-active{
    overflow-x: hidden;
}
.mhdminbarright .menu-close{
    display: none;
}
.mhdminbarright .menu-toggle{
    display: none!important;
}
.mhdminbarright .sider .hide-menu{
    display: block;
}
.zita-site .mhdminbarright .sider{
    background: transparent;
    padding: 0;
    overflow-x: inherit;
    overflow-y: inherit;
}
.mhdminbarright .sider {
    right: 0;
    position: inherit;
}
.mhdminbarright .sider{
    width: 100%;
    max-width: 100%;
    padding-bottom: 0;
    height: auto;
}
header.mhdminbarright .zita-cart {
    display: block;
    position: fixed;
    top: 0;
    height: 100vh;
    z-index: 999999;
    right: -270px;
    width: 270px;
    padding: 2em 1.5em;
    max-width: 100%;
    border-right: 1px solid rgba(0,0,0,.1);
    overflow-x: hidden;
    overflow-y: auto;
    font-size: 15px;
    background-color: #fff;
    color: #555;
    -webkit-touch-callout: none;
    user-select: none;
    -webkit-overflow-scrolling: touch;
    visibility: visible;
    -moz-opacity: 1;
    -webkit-opacity: 1;
    opacity: 1;
}
.cart-pan-active header.mhdminbarright .zita-cart {
    right:80px;
    left: auto;
    transition:right 0.2s ease;
}
header.mhdminbarright .main-header-col2{
-webkit-justify-content: flex-start;
justify-content: flex-start;
}
header.mhdminbarright .top-header-col1, 
header.mhdminbarright .top-header-col2, 
header.mhdminbarright .top-header-col3, 
header.mhdminbarright .bottom-header-col1, 
header.mhdminbarright .bottom-header-col2, 
header.mhdminbarright .bottom-header-col3{
    margin-top: 10px;
    width: 100%!important;
    -webkit-flex: auto!important;
    -moz-box-flex: auto!important;
    -ms-flex: auto!important;
    flex: auto!important;
    justify-content: flex-start;
}
header.mhdminbarright .searchfrom .search-btn {
    display: none;
}
header.mhdminbarright .searchfrom {
        display: flex;
       padding: 10px 0px;
  }
header.mhdminbarright .searchfrom #searchform {
    display: block;
    position:relative;
}
header.mhdminbarright li.menu-item.zta-custom-item{
padding: 10px 0px;
}
header.mhdminbarright .zita-quickcart-dropdown{
width: 234px;
padding:0;
padding-top:20px;
max-width: 100%;
max-height:100%;
text-align: left;
}
header.mhdminbarright .zita-cart a.remove{
margin-right:40px;
}
header.mhdminbarright .top-header-col1,
 header.mhdminbarright .top-header-col2,
  header.mhdminbarright .top-header-col3,
   header.mhdminbarleft .top-header-col1,
    header.mhdminbarleft .top-header-col2,
     header.mhdminbarleft .top-header-col3,
      header.mhdminbarright .bottom-header-col1,
       header.mhdminbarright .bottom-header-col2,
        header.mhdminbarright .bottom-header-col3,
         header.mhdminbarleft .bottom-header-col1,
          header.mhdminbarleft .bottom-header-col2,
           header.mhdminbarleft .bottom-header-col3,
            header.mhdminbarleft .content-html,
             header.mhdminbarright .content-html{
    width: 100%!important;
    text-align: left!important;
    line-height: normal;
}

header.mhdminbarright .content-social, header.mhdminbarleft .content-social {
    width: 100%;
}
header.mhdminbarleft .content-social ul.social-icon,
header.mhdminbarright .content-social ul.social-icon {
    margin: 0;
    display: block;
}
.mhdminbarright .content-social .social-icon a, 
.mhdminbarleft .content-social .social-icon a{
    display: initial;
}
.mhdminbarright .content-social .social-icon a,
.mhdminbarleft .content-social .social-icon a{
    padding-right: 10px!important;
}
header.mhdminbarleft .content-social ul.social-icon li, 
header.mhdminbarright .content-social ul.social-icon li{
    padding: 0px;
    display: -webkit-inline-box;
}
/**********************/
/*woo cart pan style*/
/**********************/
.main-header.mhdrleftpan .zita_woo_cart,
.main-header.mhdrrightpan .zita_woo_cart{
padding-top:20px;
}
.main-header.mhdrleftpan .cart-contents,.main-header.mhdrrightpan .cart-contents{
width:100%;
text-align:left;
}
header.mhdrleftpan .zita-cart{
    display: block;
    position: fixed;
    top: 0;
    height: 100vh;
    z-index: 999999;
    left:-270px;
    width: 270px;
    padding: 2em 1.5em;
    max-width: 100%;
    border-right: 1px solid rgba(0,0,0,.1);
    overflow-x: hidden;
    overflow-y: auto;
    font-size: 15px;
    background-color: #fff;
    color: #555;
    -webkit-touch-callout: none;
    user-select: none;
    -webkit-overflow-scrolling: touch;
    visibility: visible;
    -moz-opacity: 1;
    -webkit-opacity: 1;
    opacity: 1;
}
header.mhdrrightpan .zita-cart{
    display: block;
    position: fixed;
    top: 0;
    height: 100vh;
    z-index: 999999;
    right:-270px;
    width: 270px;
    padding: 2em 1.5em;
    max-width: 100%;
    border-right: 1px solid rgba(0,0,0,.1);
    overflow-x: hidden;
    overflow-y: auto;
    font-size: 15px;
    background-color: #fff;
    color: #555;
    -webkit-touch-callout: none;
    user-select: none;
    -webkit-overflow-scrolling: touch;
    visibility: visible;
    -moz-opacity: 1;
    -webkit-opacity: 1;
    opacity: 1;
}
.cart-pan-active header.mhdrleftpan .zita-cart{
    left: 0;
    right: auto;
    transition: left 0.2s ease;
}
.cart-pan-active header.mhdrrightpan .zita-cart{
    left: auto;
    right: 0;
    transition: right 0.2s ease;
}
.cart-close .cart-close-btn {
    width: 20px;
    height: 20px;
    top: 40px;
    position: absolute;
    background: #fff;
    right: 10px;
}
.cart-close-btn{
       margin-top: 10px;
    margin-left: 10px;
    width: 14px;
    display: block;
    text-decoration: none;
    top: .75em;
    right: 1em;
    min-width: 1em;
    min-height: 1em;
    transform-origin: center;
    transition: all .3s linear;
    transition-property: transform;
    -webkit-backface-visibility: hidden;
    font-size: 20px;
    color: #555;
    z-index:1;
}
.cart-close-btn:before, .cart-close-btn:after {
    content: '';
    display: block;
    border-top: 1px solid;
    position: absolute;
    left: 0;
    top: 50%;
    width: 100%;
}

.cart-close-btn:before {
    -webkit-transform: rotateZ(-45deg);
    -moz-transform: rotateZ(-45deg);
    transform: rotateZ(-45deg);
}
.cart-close-btn:after {
    -webkit-transform: rotateZ(45deg);
    -moz-transform: rotateZ(45deg);
    transform: rotateZ(45deg);
}
.cart-close-btn:hover {
    -webkit-transform: rotateZ(90deg);
    -moz-transform: rotateZ(90deg);
    transform: rotateZ(90deg);
}
.main-header.mhdrleftpan .zita-quickcart-dropdown,
.main-header.mhdrrightpan .zita-quickcart-dropdown{
width: 234px;
padding:0;
padding-top:20px;
max-width: 100%;
max-height:100%;
}
.main-header.mhdrleftpan .zita-cart a.remove,
.main-header.mhdrrightpan .zita-cart a.remove{
margin-right:40px;
}
/*social icon*/
.content-social ul.social-icon{
list-style: none;
    margin: 0;
    padding: 0;
    display: inline-flex;
}
.content-social ul.social-icon li{
padding:5px;
}   
.content-social ul.social-icon li i{
  padding:0;
  font-family: fontawesome;
  font-weight: normal;
}
.social-icon.original-social-icon i.fa-facebook{
color:#4867AA;
}
.social-icon.original-social-icon i.fa-google-plus{
color:#DE564A;
}
.social-icon.original-social-icon i.fa-linkedin{
color:#007BB6;
}
.social-icon.original-social-icon i.fa-twitter{
color:#00ACED;
}
.social-icon.original-social-icon i.fa-instagram{
color:#C50067;
}
.social-icon.original-social-icon i.fa-pinterest{
color:#BD081B;
}
.social-icon.original-social-icon i.fa-youtube-play{
color:#FF0000;
}
.social-icon.original-social-icon i.fa-tumblr{
color:#36465D;
}
.social-icon.original-social-icon i.fa-stumbleupon{
color:#EB4823;
}
.social-icon.original-social-icon i.fa-dribbble{
color:#EA4C89;
}
.content-social .social-icon a{
font-size:15px;  
width: 2em;
height: 2em;
line-height:2em;
display:block;
text-align:center;
border:1px solid transparent;
}
.social-icon.original-social-icon a{
background-color:transparent!important;
border:none;
width:1.5em;
height:1.5em;
line-height:1.5em;
display:block;
}
/*social icon*/
/********************************/
/*header and footer common style*/
/********************************/
.abv-one .top-header-container,.abv-one .top-header-col1,
.abv-two .top-header-container,.abv-two .top-header-col2,
.abv-three .top-header-container,.abv-three .top-header-col3,
.one .main-header-container,
.two .main-header-container,
.three .main-header-container,
.one .main-header-col1,
.two .main-header-col2,
.three .main-header-col3,
.btm-one .bottom-header-container,
.btm-two .bottom-header-container,
.btm-three .bottom-header-container,
.btm-one .bottom-header-col1,
.btm-two .bottom-header-col2,
.btm-three .bottom-header-col3,
.ft-abv-one .top-footer-container,.ft-abv-one .top-footer-col1,
.ft-abv-two .top-footer-container,.ft-abv-two .top-footer-col2,
.ft-abv-three .top-footer-container,.ft-abv-three .top-footer-col3,
.four .top-footer-container,.four .top-footer-col4,
.ft-wgt-one .widget-footer-container,.ft-wgt-one .widget-footer-col1,
.ft-wgt-two .widget-footer-container,.ft-wgt-two .widget-footer-col2,
.ft-wgt-three .widget-footer-container,.ft-wgt-three .widget-footer-col3,
.ft-wgt-four .widget-footer-container,.ft-wgt-four .widget-footer-col4,
.ft-btm-one .bottom-footer-container,.ft-btm-one .bottom-footer-col1,
.ft-btm-two .bottom-footer-container,.ft-btm-two .bottom-footer-col2,
.ft-btm-three .bottom-footer-container,.ft-btm-three .bottom-footer-col3,
.four .bottom-footer-container,.four .bottom-footer-col4{
 -js-display: flex;
    display: -webkit-box;
    display: -webkit-flex;
    display: -moz-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -webkit-align-items: center;
    -moz-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    -webkit-flex-wrap: wrap;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -webkit-align-content: center;
    -ms-flex-line-pack: center;
    align-content: center;
}
.abv-one .top-header-col1,
.abv-two .top-header-col1,
.abv-two .top-header-col2,
.abv-three .top-header-col2,
.abv-three .top-header-col3,
.one .main-header-col1,
.two .main-header-col1,
.two .main-header-col2,
.three .main-header-col2,
.three .main-header-col3,
.btm-one .bottom-header-col1,
.btm-two .bottom-header-col1,
.btm-two .bottom-header-col2,
.btm-three .bottom-header-col2,
.btm-three .bottom-header-col3,
.ft-abv-one .top-footer-col1,
.ft-abv-two .top-footer-col1,
.ft-abv-two .top-footer-col2,
.ft-abv-three .top-footer-col2,
.ft-abv-three .top-footer-col3,
.four .top-footer-col1,
.four .top-footer-col2,
.four .top-footer-col2,
.four .top-footer-col3,
.four .top-footer-col4,
.ft-wgt-one .widget-footer-col1,
.ft-wgt-two .widget-footer-col1,
.ft-wgt-two .widget-footer-col2,
.ft-wgt-three .widget-footer-col2,
.ft-wgt-three .widget-footer-col3,
.ft-wgt-four .widget-footer-col1,
.ft-wgt-four .widget-footer-col2,
.ft-wgt-four .widget-footer-col2,
.ft-wgt-four .widget-footer-col3,
.ft-wgt-four .widget-footer-col4,
.ft-btm-one .bottom-footer-col1,
.ft-btm-two .bottom-footer-col1,
.ft-btm-two .bottom-footer-col2,
.ft-btm-three .bottom-footer-col2,
.ft-btm-three .bottom-footer-col3,
.four .bottom-footer-col1,
.four .bottom-footer-col2,
.four .bottom-footer-col2,
.four .bottom-footer-col3,
.four .bottom-footer-col4{
    -webkit-box-flex: 1;
    -webkit-flex: auto;
    -moz-box-flex: 1;
    -ms-flex: auto;
    flex: auto;
}
.top-header-col1,.main-header-col1,.bottom-header-col1,
.top-footer-col1,.widget-footer-col1,.bottom-footer-col1{
    -webkit-box-flex: 1;
    -webkit-flex: auto;
    -moz-box-flex: 1;
    -ms-flex: auto;
    flex: auto;
    -webkit-box-pack: center;
    -webkit-justify-content: center;
    -moz-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center;
}
.abv-two .top-header-col1,.two .main-header-col1,.btm-two .bottom-header-col1,
.ft-abv-two .top-footer-col1,.ft-wgt-two .widget-footer-col1,.ft-btm-two .bottom-footer-col1{
    -webkit-box-pack: start;
    -webkit-justify-content: flex-start;
    -moz-box-pack: start;
    -ms-flex-pack: start;
    justify-content: flex-start;
    -webkit-box-flex: 1;
    -webkit-flex: 1;
    -moz-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
}
.abv-two .top-header-col2,.two .main-header-col2,.btm-two .bottom-header-col2,
.ft-abv-two .top-footer-col2,.ft-wgt-two .widget-footer-col2,.ft-btm-two .bottom-footer-col2{
    -webkit-box-pack: end;
    -webkit-justify-content: flex-end;
    -moz-box-pack: end;
    -ms-flex-pack: end;
    justify-content: flex-end;
}
.abv-three .top-header-col2,.three .main-header-col2,.btm-three .bottom-header-col2,
.ft-abv-three .top-footer-col2,.ft-wgt-three .widget-footer-col2,.ft-btm-three .bottom-footer-col2{
    -webkit-box-pack: center;
    -webkit-justify-content: flex-center;
    -moz-box-pack: center;
    -ms-flex-pack: center;
    justify-content: flex-center;
}
.abv-three .top-header-col2,.three .main-header-col2,.btm-three .bottom-header-col2,
.ft-abv-three .top-footer-col2,.ft-wgt-three .widget-footer-col2,.ft-btm-three .bottom-footer-col2{
    text-align: center;
}
.abv-three .top-header-col3,.three .main-header-col3,.btm-three .bottom-header-col3,
.ft-abv-three .top-footer-col3,.ft-wgt-three .widget-footer-col3,.ft-btm-three .bottom-footer-col3{
    -webkit-box-pack: end;
    -webkit-justify-content: flex-end;
    -moz-box-pack: end;
    -ms-flex-pack: end;
    justify-content: flex-end;
}
.top-header-bar{
    border-bottom: solid;
    border-bottom-color:#eee;
    border-bottom-width:1px;
    background:#fff;
}
/*footer coloum not fixable css */
.widget-footer .gallery figure img {
    max-width: 100%;
    height: auto;
    margin: inherit;
    display: block;
}
.widget-footer .widget-footer-col1,
.widget-footer .widget-footer-col2,
.widget-footer .widget-footer-col3,
.widget-footer .widget-footer-col4{
 align-self: flex-start;
}
/*/two-col*/
.ft-wgt-two .widget-footer-col1,.ft-wgt-two .widget-footer-col2{
width: 50%;
justify-content:flex-start;
flex: auto;
}
/*/three-col*/
.ft-wgt-three .widget-footer-col1,
.ft-wgt-three .widget-footer-col2,
.ft-wgt-three .widget-footer-col3{
width: 33.33%;
justify-content:flex-start;
text-align:left;
}
/*/four-col*/
.ft-wgt-four .widget-footer-col1,
.ft-wgt-four .widget-footer-col2,
.ft-wgt-four .widget-footer-col3,
.ft-wgt-four .widget-footer-col4{
width: 25%;
justify-content:flex-start;
text-align:left;
}
/*one-col-2*/
.ft-wgt-five .widget-footer-container{
    display: flex;
    flex-direction:row;
    align-items: center;
}
.ft-wgt-five .widget-footer-container .widget-footer-col1{
    width: 50%;
    order: 1;

}
.ft-wgt-five .widget-footer-container .widget-footer-col2{
    width: 20%;
    order: 2;
}
.ft-wgt-five .widget-footer-container .widget-footer-col3{
    width: 25%;
    order: 3;
}
/*two-col-2*/
.ft-wgt-six .widget-footer-container{
    display: flex;
    flex-direction:row;
    align-items: center;
}
.ft-wgt-six .widget-footer-container .widget-footer-col2{
    width: 50%;
    order: 2;
}
.ft-wgt-six .widget-footer-container .widget-footer-col1{
    width: 20%;
    order: 1;
}
.ft-wgt-six .widget-footer-container .widget-footer-col3{
    width: 25%;
    order: 3;
}
/*two-col-2-onelarge and second small*/
.ft-wgt-seven .widget-footer-container{
    display: flex;
    flex-direction:row;
    align-items: center;
}
.ft-wgt-seven .widget-footer-container .widget-footer-col1{
    width: 70%;
    order: 1;

}
.ft-wgt-seven .widget-footer-container .widget-footer-col2{
    width: 30%;
    order: 2;

}
.ft-wgt-eight .widget-footer-container{
    display: flex;
    flex-direction:row;
    align-items: center;
}
.ft-wgt-eight .widget-footer-container .widget-footer-col1{
    width: 30%;
    order: 1;

}
.ft-wgt-eight .widget-footer-container .widget-footer-col2{
    width: 70%;
    order: 2;

}
.top-footer .top-footer-bar,
.widget-footer .widget-footer-bar,
.bottom-footer .bottom-footer-bar{
background:#fff;
}
.widget-footer .widget-footer-bar{
  padding:30px 0px;
}
.ft-wgt-two .widget-footer-col1 .widget{
padding-right:30px;
}

.ft-wgt-three .widget-footer-col1 .widget,.ft-wgt-three .widget-footer-col2 .widget{
padding-right:30px;
}

.ft-wgt-four .widget-footer-col1 .widget,.ft-wgt-four .widget-footer-col2 .widget,.ft-wgt-four .widget-footer-col3 .widget{
padding-right:30px;
}
.ft-wgt-five .widget-footer-col1 .widget,.ft-wgt-five .widget-footer-col2 .widget{
padding-right:30px;
}
.ft-wgt-six .widget-footer-col1 .widget,.ft-wgt-six .widget-footer-col2 .widget{
padding-right:30px;
}

.ft-wgt-seven .widget-footer-col1 .widget,
.ft-wgt-eight .widget-footer-col1 .widget{
padding-right:30px;
}
.widget-footer-container .widget{
width:100%;
margin-bottom:30px;
}
.ft-abv-three .top-footer-col2{
-webkit-box-flex: 1;
    -webkit-flex: 1;
    -moz-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
}
.widget-footer .widget-footer-bar .woocommerce  ul.cart_list li,
 .widget-footer .widget-footer-bar .woocommerce  ul.product_list_widget li {
 
    width: 270px;
}
/*main header layout*/
.main-header-bar.two .main-header-col2{
    -webkit-box-flex: 1;
    -webkit-flex: 1;
    -moz-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
}
.main-header-bar.two .main-header-col1{
    -webkit-box-flex: 1;
    -webkit-flex: unset;
    -moz-box-flex: 1;
    -ms-flex: unset;
    flex:unset;
}
.main-header.mhdrcenter .main-header-col1{
width: 100%;
text-align: center;
}
.main-header.mhdrcenter .main-header-col2{
-webkit-box-pack: center;
    -webkit-justify-content:center;
    -moz-box-pack: center;
    -ms-flex-pack:center;
    justify-content: center;
}
.main-header.mhdrright .main-header-container{
-webkit-box-orient: horizontal;
    -webkit-box-direction: reverse;
    -webkit-flex-direction: row-reverse;
    -moz-box-orient: horizontal;
    -moz-box-direction: reverse;
    -ms-flex-direction: row-reverse;
    flex-direction: row-reverse;
}
.main-header.mhdrright .two .main-header-col2{
    -webkit-box-pack: start;
    -webkit-justify-content: flex-start;
    -moz-box-pack: start;
    -ms-flex-pack: start;
    justify-content: flex-start;
}
.main-header.mhdrright .two .main-header-col1{
   text-align: right;
}
.mhdrleft .zita-menu{padding-left: 20px;}
.mhdrright .zita-menu{padding-right: 20px;}
.menu-custom-html button{
margin:0;
}
.main-header .cart-contents{
margin-left:10px;
}
.mhdrleftpan .main-header .cart-contents,
.mhdrrightpan .main-header .cart-contents{
margin-left:0;
}
/**********************/
/*header col css*/
/**********************/
.top-header .abv-two .top-header-col2,
.top-header .abv-three .top-header-col2,
.top-header .abv-three .top-header-col3,
.top-header .abv-three .top-header-col1,
.bottom-header .btm-two .bottom-header-col2,
.bottom-header .btm-three .bottom-header-col2,
.bottom-header .btm-three .bottom-header-col3,
.bottom-header .btm-three .bottom-header-col1{
    -webkit-box-flex: 1;
    -webkit-flex: 1;
    -moz-box-flex: 1;
    -ms-flex: 1;
    flex: 1;

}
/**********************/
/*Footer col css*/
/**********************/
.top-footer .abv-two .top-footer-col2,
.top-footer .abv-three .top-footer-col2,
.top-footer .abv-three .top-footer-col3,
.top-footer .abv-three .top-footer-col1,
.bottom-footer .btm-two .bottom-footer-col2,
.bottom-footer .btm-three .bottom-footer-col2,
.bottom-footer .btm-three .bottom-footer-col3,
.bottom-footer .btm-three .bottom-footer-col1{
    -webkit-box-flex: 1;
    -webkit-flex: 1;
    -moz-box-flex: 1;
    -ms-flex: 1;
    flex: 1;

}
/***********************************/
/*page content css*/
/***********************************/
#content.site-content.boxed #container,
#content.site-content.contentbox #container,
#content.site-content.fullwidthcontained #container{
max-width:1200px;
}
.site-content
#primary {
margin: 4em 0;
padding: 0;
}
.site-content #primary{
width: 65%;
float:left;
box-sizing: border-box;
}
.site-content .site-container.left #primary{
float:right;
}
.site-content .site-container.right #primary{
 border-right:1px solid #eee;  
 padding-right:50px 
}
.site-content .site-container.left #primary{
 border-left:1px solid #eee;  
 padding-left:50px 
}
.site-content .site-container.no-sidebar #primary{
width:100%;
margin-right:0;
margin-left:0;
float: left;
}
.site-content #sidebar-primary{
width:35%;
float:right;
box-sizing: border-box;
}
.site-content #sidebar-primary{
margin: 4em 0 2.5em;
word-break: break-word;
line-height: 2;
}
.site-content .site-container.left #sidebar-primary{
float:left;
}
.site-content .site-container #sidebar-primary{
padding-left:50px;
padding-right:0;
}
.site-content .site-container.left #sidebar-primary{
padding-left:0;
padding-right:50px;
}
.page .site-content.contentbox .site-container.right #sidebar-primary,
.page .site-content.fullwidthcontained .site-container.right #sidebar-primary,
.page .site-content.fullwidthstrechched .site-container.right #sidebar-primary {
    padding-left: 50px;
    padding-right: 0;
}
.page .site-content.contentbox .site-container.left #sidebar-primary,
.page .site-content.fullwidthcontained .site-container.left #sidebar-primary,
.page .site-content.fullwidthstrechched .site-container.left #sidebar-primary {
    padding-left:0px;
    padding-right: 50px;
}
.page #content.site-content.fullwidthcontained .site-container.right #primary {
    border-right: 1px solid #eee;
    padding-right: 50px;
}
.page #content.site-content.fullwidthcontained .site-container.left #primary {
    border-left: 1px solid #eee;
    padding-left: 50px;
}
.page #content.site-content.fullwidthcontained article.zita-article,
.page #content.site-content.fullwidthcontained article.zita-article:before,
.page #content.site-content.fullwidthstrechched article.zita-article,
.page #content.site-content.fullwidthstrechched article.zita-article:before{
background:transparent!important;
}
/*Sidebar Only boxed layout*/
.boxed .site-content .site-container.left #primary,
.contentbox .site-content .site-container.left #primary{
 border:0; 
 padding-left:0;  
}
.boxed .site-content .site-container.right #primary,
.contentbox .site-content .site-container.right #primary{
 border:0; 
 padding-right:0;  
}
.boxed .site-content .site-container #sidebar-primary{
padding-left:20px;
padding-right:0;
}
.boxed .site-content .site-container.left #sidebar-primary{
padding-left:0;
padding-right:20px
}
/**********************************/
/*page-builder-css fullwidthstrech*/
/**********************************/
.page-template-default.zta-page-builder-template .site-content #primary,
.page-template-default .site-content.fullwidthstrechched #primary{
margin:0!important;
padding:0!important;
}
.page-template-default.zta-page-builder-template .entry-header .entry-title,
.page-template-default .site-content.fullwidthstrechched .entry-header .entry-title {
   margin-top: 2em;
   margin-left: auto;
   margin-right: auto;
 padding-left: 20px;
 padding-right: 20px;
}
/*****************************************/
/*footer styel*/
/*****************************************/
footer{
width:100%;
display:block;  
}
.top-footer-bar{
border-bottom: solid;
border-bottom-color: #eee;
border-bottom-width: 1px;   
}
.bottom-footer-bar{
border-top: solid;
border-top-color: #eee;
border-top-width: 1px;   
}
ul.zita-bottom-menu{
margin:0;
list-style: none;
}
ul.zita-bottom-menu li{
display: inline-block;
    padding-right: 20px;
margin:0;
}

ul.zita-bottom-menu .sub-menu{
display:none;
}
ul.zita-bottom-menu li a{
color:#555;  
}
/*****************************************/
/*blog-page*/
/******************************************/
.entry-content-wrapper .post-img{
margin:20px 0px;
}
p.read-more{
margin-bottom:0;
}
.read-more .zta-button,button,.main-header .main-header-bar a.main-header-btn{
    padding: 8px 25px; 
    color: #ffffff;
    border-color: #006799;
    background-color:#006799;
    margin:10px 0px;
    display:inline-block;
}
.read-more .zta-button:hover,.main-header .main-header-bar a.main-header-btn:hover{
color:#fff;
}

.post-navigation, nav.pagination {
    float:right;
}
#content article.zita-article{
width:100%;
display:block;
float:left;
background-color:transparent;
}
.entry-content-wrapper.no-thumb{
width:100%;
padding:0;
}
#content article.zita-article .zta-blog-layout-2 .entry-content-wrapper
,#content article.zita-article .zta-blog-layout-3 .entry-content-wrapper,
#content article.zita-article .zta-blog-layout-4 .entry-content-wrapper{
  position:relative;
}

/*blog-layout-2*/
.fullwidthcontained #content .entry-content-outer-wrapper.zta-blog-layout-2,
.fullwidthstrechched #content .entry-content-outer-wrapper.zta-blog-layout-2{
padding-bottom:30px;
padding-top:0;
padding-left:0;
padding-right:0;
}
#content .entry-content-outer-wrapper.zta-blog-layout-2 {
display:flex;
background:transparent;
padding: 20px;
}
.zta-blog-layout-2 .entry-content-wrapper.no-thumb{
width:100%;
padding: 0;
}
.zta-blog-layout-2 .entry-content-wrapper{
width:50%;
float:left;
padding-left:30px;
}
.zta-blog-layout-2 .post-img-wrapper{
width:50%;
float:left;
margin-bottom:0;
}
.zta-blog-layout-2 .post-img-wrapper .post-img{
    margin-bottom:0;
    line-height: 0;
    position: relative;
}

/*blog-layout-3*/
.fullwidthcontained #content .entry-content-outer-wrapper.zta-blog-layout-3,
.fullwidthstrechched #content .entry-content-outer-wrapper.zta-blog-layout-3{
padding-bottom:30px;
padding-top:0;
padding-left:0;
padding-right:0;
}
#content .entry-content-outer-wrapper.zta-blog-layout-3 {
    display:flex;
    background:transparent;
    padding: 20px;
}
.zta-blog-layout-3 .entry-content-wrapper{
width:50%;
float:right;
padding-right:30px;
}
.zta-blog-layout-3 .post-img-wrapper{
width:50%;
float:right;
order: 2;
}
.zta-blog-layout-3 .entry-content-wrapper.no-thumb{
width:100%;
padding:0;
}
.zta-blog-layout-3 .post-img-wrapper .post-img{
    margin-bottom:0;
    line-height: 0;
    position: relative;
}
.zta-blog-layout-3 .zta-date-meta .posted-on{
left:auto;
right:0;
}
/*blog-layout-4*/
.fullwidthcontained #content .entry-content-outer-wrapper.zta-blog-layout-4,
.fullwidthstrechched #content .entry-content-outer-wrapper.zta-blog-layout-4{
padding-bottom:30px;
padding-top:0;
padding-left:0;
padding-right:0;
}
#content .entry-content-outer-wrapper.zta-blog-layout-4 {
    display:flex;
    background:transparent;
    padding: 20px;
}
#content .entry-content-outer-wrapper.zta-blog-layout-4 .post-img-wrapper .post-img{
   position: relative; 
}
article.zita-article:nth-child(odd) .zta-blog-layout-4 .post-img-wrapper {
    width: 50%;
    float: right;
    margin:0;
    order: 2;
}
article.zita-article:nth-child(odd) .zta-blog-layout-4 .entry-content-wrapper {
    width: 50%;
    float: right;
    padding-right: 30px;
    order: 1;
}
article.zita-article:nth-child(even) .zta-blog-layout-4 .post-img-wrapper {
    width: 50%;
    float: left;
    margin:0;
     order:1;
}
article.zita-article:nth-child(even) .zta-blog-layout-4 .entry-content-wrapper {
    width: 50%;
    float: left;
    padding-left: 30px;
     order:2;
}
article.zita-article:nth-child(even) .zta-blog-layout-4 .entry-content-wrapper.no-thumb{
   width:100%;
   padding: 0;

}
article.zita-article:nth-child(odd) .zta-blog-layout-4 .entry-content-wrapper.no-thumb{
   width:100%;
   padding:0;
}

article.zita-article:nth-child(even) .zta-blog-layout-4 .post-img-wrapper .post-img,
article.zita-article:nth-child(odd) .zta-blog-layout-4 .post-img-wrapper .post-img{
 margin:0;   
}
article.zita-article:nth-child(odd) .zta-blog-layout-4 .zta-date-meta .posted-on{
left:auto;
right:0;
}
.fullwidthcontained article.zita-article:nth-child(even) .zta-blog-layout-4 .post-img-wrapper .post-img,
.fullwidthstrechched article.zita-article:nth-child(even) .zta-blog-layout-4 .post-img-wrapper .post-img,
.fullwidthcontained article.zita-article:nth-child(odd) .zta-blog-layout-4 .post-img-wrapper .post-img,
.fullwidthstrechched article.zita-article:nth-child(odd) .zta-blog-layout-4 .post-img-wrapper .post-img{
margin:0;
}
/*blog-grid-layout*/
#content .zta-one-colm article.zita-article,
#content .zta-two-colm article.zita-article,
#content .zta-three-colm article.zita-article,
#content .zta-four-colm article.zita-article{ 
    -js-display: flex;
    display: -webkit-box;
    display: -webkit-flex;
    display: -moz-box;
    display: -ms-flexbox;
    display: flex;
}
.boxed #content .zta-one-colm article.zita-article,
.boxed #content .zta-two-colm article.zita-article,
.boxed #content .zta-three-colm article.zita-article,
.boxed #content .zta-four-colm article.zita-article,
.contentbox #content .zta-one-colm article.zita-article,
.contentbox #content .zta-two-colm article.zita-article,
.contentbox #content .zta-three-colm article.zita-article,
.contentbox #content .zta-four-colm article.zita-article{
 padding:0px 10px;

}
.boxed #content .zta-one-colm article.zita-article,
.boxed #content .zta-two-colm article.zita-article,
.boxed #content .zta-three-colm article.zita-article,
.boxed #content .zta-four-colm article.zita-article,
.contentbox #content .zta-one-colm article.zita-article,
.contentbox #content .zta-two-colm article.zita-article,
.contentbox #content .zta-three-colm article.zita-article,
.contentbox #content .zta-four-colm article.zita-article{
    -js-display: flex;
    display: -webkit-box;
    display: -webkit-flex;
    display: -moz-box;
    display: -ms-flexbox;
    display: flex;
    margin-bottom:20px;
    background:0 0;
    border: none;
}
.boxed #content .zta-one-colm article.zita-article .entry-content-outer-wrapper,
.boxed #content .zta-two-colm article.zita-article .entry-content-outer-wrapper,
.boxed #content .zta-three-colm article.zita-article .entry-content-outer-wrapper,
.boxed #content .zta-four-colm article.zita-article .entry-content-outer-wrapper,
.contentbox #content .zta-one-colm article.zita-article .entry-content-outer-wrapper,
.contentbox #content .zta-two-colm article.zita-article .entry-content-outer-wrapper,
.contentbox #content .zta-three-colm article.zita-article .entry-content-outer-wrapper,
.contentbox #content .zta-four-colm article.zita-article .entry-content-outer-wrapper{
   padding:20px;
   background:#fff;
   width: 100%;
}
#content .zta-two-colm article.zita-article{
    width:50%;
}
#content .zta-three-colm article.zita-article{
    width:33.33%;
}
#content .zta-four-colm article.zita-article{
    width:25%;
}
.boxed .zta-one-colm .main-content-row,
.boxed .zta-two-colm .main-content-row,
.boxed .zta-three-colm .main-content-row,
.boxed .zta-four-colm .main-content-row,
.contentbox .zta-one-colm .main-content-row,
.contentbox .zta-two-colm .main-content-row,
.contentbox .zta-three-colm .main-content-row,
.contentbox .zta-four-colm .main-content-row{
margin-left:-10px;
margin-right:-10px;
    display: flex;
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
    -webkit-box-align: flex-start;
   align-items: flex-start;
    flex-flow: row wrap;
}
.boxed .zta-one-colm.zta-no-space .main-content-row,
.boxed .zta-two-colm.zta-no-space .main-content-row,
.boxed .zta-three-colm.zta-no-space .main-content-row,
.boxed .zta-four-colm.zta-no-space .main-content-row,
.contentbox .zta-one-colm.zta-no-space .main-content-row,
.contentbox .zta-two-colm.zta-no-space .main-content-row,
.contentbox .zta-three-colm.zta-no-space .main-content-row,
.contentbox .zta-four-colm.zta-no-space .main-content-row{
margin-left:-10px;
margin-right:-10px;
    display: flex;
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
    -webkit-box-align: flex-start;
       -webkit-box-align: stretch;
    align-items: stretch;
    flex-flow: row wrap;
}
#content .zta-blog-layout-2 article.zita-article .entry-content-outer-wrapper,
#content .zta-blog-layout-3 article.zita-article .entry-content-outer-wrapper,
#content .zta-blog-layout-4 article.zita-article .entry-content-outer-wrapper{
align-items:center;
}
.boxed .main-content-row::before,
.contentbox .main-content-row::before,
.fullwidthcontained .main-content-row::before,
.fullwidthstrechched .main-content-row::before{
    -webkit-flex-basis: 0;
    -ms-flex-preferred-size: 0;
    flex-basis: 0;
    width: 0;
    content:'';
    display: table;
}
.fullwidthcontained #content .zta-two-colm article.zita-article,
.fullwidthcontained #content .zta-three-colm article.zita-article,
.fullwidthcontained #content .zta-four-colm article.zita-article,
.fullwidthstrechched #content .zta-two-colm article.zita-article,
.fullwidthstrechched #content .zta-three-colm article.zita-article,
.fullwidthstrechched #content .zta-four-colm article.zita-article{
padding:0 20px;
}
.fullwidthcontained .zta-two-colm .main-content-row,
.fullwidthcontained .zta-three-colm .main-content-row,
.fullwidthcontained .zta-four-colm .main-content-row,
.fullwidthstrechched .zta-two-colm .main-content-row,
.fullwidthstrechched .zta-three-colm .main-content-row,
.fullwidthstrechched .zta-four-colm .main-content-row{
margin-left:-10px;
margin-right:-10px;
display: flex;
-webkit-box-orient: horizontal;
-webkit-box-direction: normal;
-webkit-box-align: stretch;
align-items: stretch;
flex-flow: row wrap;
}
/*highlighted post*/
#content .zta-blog-highlight.zta-two-colm article.zita-article:first-child {
width:100%;
margin-right:0;
}
#content .zta-blog-highlight.zta-three-colm article.zita-article:first-child {
width:66.66%;
margin-right:0;
}
#content .zta-blog-highlight.zta-four-colm article.zita-article:first-child {
width:50%;
margin-right:0;
}
/*fifth-post-highlighted*/
#content .zta-six-blog-highlight.zta-two-colm article.zita-article:first-child{
width: 100%;
margin-right: 0;
}
#content .zta-six-blog-highlight.zta-two-colm article.zita-article:nth-child(5n+6){
width: 100%;
margin-right: 0;
}
#content .zta-six-blog-highlight.zta-three-colm article.zita-article:first-child{
width:66.66%;
margin-right: 0;
}
#content .zta-six-blog-highlight.zta-three-colm article.zita-article:nth-child(5n+6){
width: 66.6%;
margin-right: 0;
}
#content .zta-six-blog-highlight.zta-four-colm article.zita-article:first-child{
width:50%;
margin-right: 0;
}
#content .zta-six-blog-highlight.zta-four-colm article.zita-article:nth-child(5n+6){
width: 50%;
margin-right: 0;
}
/*Add space in post*/
.boxed  #content .zta-one-colm.zta-no-space article.zita-article,
.boxed  #content .zta-no-space.zta-two-colm article.zita-article,
.boxed  #content .zta-no-space.zta-three-colm article.zita-article,
.boxed  #content .zta-no-space.zta-four-colm article.zita-article,
.contentbox #content .zta-one-colm.zta-no-space article.zita-article,
.contentbox #content .zta-no-space.zta-two-colm article.zita-article,
.contentbox #content .zta-no-space.zta-three-colm article.zita-article,
.contentbox #content .zta-no-space.zta-four-colm article.zita-article{
margin-bottom:0;
padding:0
}
.boxed .zta-one-colm.zta-no-space .main-content-row, 
.boxed .zta-two-colm.zta-no-space .main-content-row, 
.boxed .zta-three-colm.zta-no-space .main-content-row, 
.boxed .zta-four-colm.zta-no-space .main-content-row, 
.contentbox .zta-one-colm.zta-no-space .main-content-row, 
.contentbox .zta-two-colm.zta-no-space .main-content-row, 
.contentbox .zta-three-colm.zta-no-space .main-content-row, 
.contentbox .zta-four-colm.zta-no-space .main-content-row{
 margin-left:0;
 margin-right:0;   
}
#content .zta-one-colm.zta-no-space article.zita-article .entry-content-outer-wrapper{
border-bottom: 1px solid #eee;
}
.boxed #content .zta-no-space article.zita-article,
.contentbox #content .zta-no-space article.zita-article{
margin-bottom:0px!important;
margin-top:0px!important;
}
#content article.zita-article{
margin-bottom:20px;
}
.post-img-wrapper .post-img{
line-height:0;  
margin-bottom: 20px;  
}
#content article.zita-article .post-img-wrapper{
position: relative;
}
#content article.zita-article .entery-header{
margin-bottom:20px;   
}
/*Remove space fetured image*/
.boxed .zta-two-colm.zta-img-no-space .post-img-wrapper .post-img,
.boxed .zta-one-colm.zta-img-no-space .post-img-wrapper .post-img,
.boxed .zta-three-colm.zta-img-no-space .post-img-wrapper .post-img,
.boxed .zta-four-colm.zta-img-no-space .post-img-wrapper .post-img,
.contentbox .zta-two-colm.zta-img-no-space .post-img-wrapper .post-img,
.contentbox .zta-one-colm.zta-img-no-space .post-img-wrapper .post-img,
.contentbox .zta-three-colm.zta-img-no-space .post-img-wrapper .post-img,
.contentbox .zta-four-colm.zta-img-no-space .post-img-wrapper .post-img{
margin-left: -20px;
margin-right: -20px;
position: relative;
}
.boxed .zta-two-colm.zta-img-no-space .post-img-wrapper .post-img, 
.boxed .zta-one-colm.zta-img-no-space .post-img-wrapper .post-img, 
.boxed .zta-three-colm.zta-img-no-space .post-img-wrapper .post-img, 
.boxed .zta-four-colm.zta-img-no-space .post-img-wrapper .post-img,
.contentbox .zta-two-colm.zta-img-no-space .post-img-wrapper .post-img, 
.contentbox .zta-one-colm.zta-img-no-space .post-img-wrapper .post-img, 
.contentbox .zta-three-colm.zta-img-no-space .post-img-wrapper .post-img, 
.contentbox .zta-four-colm.zta-img-no-space .post-img-wrapper .post-img{
margin-top:0px;
}
.boxed .zta-two-colm.zta-img-no-space .post-img-wrapper:first-child .post-img, 
.boxed .zta-one-colm.zta-img-no-space .post-img-wrapper:first-child .post-img, 
.boxed .zta-four-colm.zta-img-no-space .post-img-wrapper:first-child .post-img, 
.boxed .zta-three-colm.zta-img-no-space .post-img-wrapper:first-child .post-img,
.contentbox .zta-two-colm.zta-img-no-space .post-img-wrapper:first-child .post-img, 
.contentbox .zta-one-colm.zta-img-no-space .post-img-wrapper:first-child .post-img, 
.contentbox .zta-four-colm.zta-img-no-space .post-img-wrapper:first-child .post-img, 
.contentbox .zta-three-colm.zta-img-no-space .post-img-wrapper:first-child .post-img{
margin-top:-20px;
}
.boxed .zita-site #content .zta-img-no-space .entry-meta,
.contentbox .zita-site #content .zta-img-no-space .entry-meta{
margin:0
}
/*date-box-style*/
.entry-content-outer-wrapper{
position:relative;
}
.zta-date-meta .posted-on span{
color:#fff;
width:100%;
text-align:center;
display:block;
line-height: inherit;
}
.zta-date-meta{
z-index:1;
position:relative;
line-height:normal;
}
.zta-date-meta .posted-on .date-day{
font-size: 32px;
    font-family: 'Catamaran-Bold';
    line-height: 0;
    margin: 11px 0px;
}
.zta-date-meta .posted-on{
position:absolute;
top:0;
left:0;
width: 90px;
height: 90px;
padding: 8px;
margin:15px;
background:#006799;
font-size: 15px;
}
.zta-date-meta.circle  .posted-on{
border-radius:50%;
}
.zta-date-meta.no-thumb .posted-on{
position:relative;
display: inline-block;
font-size: 15px!important;
}
.zta-date-meta.diamond .posted-on{
height:100px;
text-align: center;
transform: rotate(45deg);
width: 100px;
}
.zta-date-meta.diamond .posted-on time{
display: table-cell;
transform: rotate(-45deg);
width: 100px;
}
/*load-more style*/
.zita-load-more{
display:table;
margin:0 auto;
position:relative;
}
.zita-load-more #load-more-posts{
background:none;
border:1px solid #bbb;
color:#bbb;
padding:15px 30px;
    margin: 20px 0px;
display: block;
cursor: pointer;
    -webkit-transition: all 0.3s ease;
    -moz-transition: all 0.3s ease;
    -ms-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    transition: all 0.3s ease;
}
.zita-load-more #load-more-posts:focus{
outline:none;
}

.zita-load-more #load-more-posts:hover{
color:#006799;
border-color:#006799;
}

.inifiniteLoader,
.inifiniteLoader:before,
.inifiniteLoader:after{
  border-radius: 50%;
  width: 1.5em;
  height: 1.5em;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both;
  -webkit-animation: load7 1.8s infinite ease-in-out;
  animation: load7 1.8s infinite ease-in-out;
}

.inifiniteLoader{
  display:none;
  color: #006799;
  font-size: 10px;
  margin:0 auto;
  left:0;
  right:0;
  top:80%;
  position: absolute;
  text-indent: -9999em;
  -webkit-transform: translateZ(0);
  -ms-transform: translateZ(0);
  transform: translateZ(0);
  -webkit-animation-delay: -0.16s;
  animation-delay: -0.16s;
}

.inifiniteLoader:before,
.inifiniteLoader:after {
  content: '';
  position: absolute;
  top: 0;
}
.inifiniteLoader:before {
  left: -2.5em;
  -webkit-animation-delay: -0.32s;
  animation-delay: -0.32s;
}
.loader:after {
  left: 2.5em;
}
@-webkit-keyframes load7 {
  0%,
  80%,
  100% {
    box-shadow: 0 2.5em 0 -1.3em;
  }
  40% {
    box-shadow: 0 2.5em 0 0;
  }
}
@keyframes load7 {
  0%,
  80%,
  100% {
    box-shadow: 0 2.5em 0 -1.3em;
  }
  40% {
    box-shadow: 0 2.5em 0 0;
  }
}
.infinite-loader{ 
float: left;
width: 100%;
text-align: center;
position: relative;
}
/***********************/
/*BLOG SINGLE PAGE*/
/***********************/
#content.blog-single article.zita-article{
background:transparent;
}
#content.blog-single article.zita-article{
margin-bottom:0px;
padding: 20px;
}
#content.blog-single .post-img{
line-height:0;
margin-bottom:20px;
}
#content.blog-single .post-navigation{
float: left;
width: 100%;
}
.blog-single article.zita-article.no-single-img-space .single-post-img-wrapper .post-img{
margin-left:-20px;
margin-right:-20px;
}
.blog-single article.zita-article.no-single-img-space .single-post-img-wrapper:first-child .post-img{
margin-top:-20px;
}
.zita-single-content,.zita-author-bio{
position:relative;
}
/*******************/
/*Related post*/
/*******************/
#content.blog-single .zita-related-post{
    float: left;
    width: 100%;
    padding:0px 0px;
    background: #fff;
}
#content.blog-single .zita-related-post ul{
padding:20px 10px;
background:transparent;
position:relative;
float:left;
margin:0;
list-style: none;
width: 100%;}
/*author*/
#content.blog-single .zita-related-post ul li{
width:33.33%;
float:left;
padding:0px 10px;
}
#content.blog-single .zita-related-post ul li h3{
font-size:22px;
line-height:1.2;
}
.blog-single .authorbox{
float:left;
width:100%;
display:block;
background:#fff;
margin-top: 20px;
padding:20px;
}
.blog-single .authorbox .author-avatar{
width:auto;
float:left;
margin-right:2%;
}
.blog-single .authorbox .author-info{
width:76%;
float:left;
}
.blog-single .authorbox h4{
font-size: 24px;
line-height: 1.5;
}
/*social share icon*/
.zita-post-share{
float:left;
width:100%;
text-align:center;
margin-top:20px;
}
.zita-post-share .single-social-icon{
margin:0px;
list-style:none;
}
.zita-post-share .single-social-icon li{
display:inline-block;
padding:0px 5px;
}
/*comment-box*/
.boxed #comments,.contentbox #comments{
  padding:20px;
}
#content.site-content.fullwidthcontained #comments,
#content.site-content.fullwidthstrechched #comments{
  padding:0;
}
#content.site-content.fullwidthcontained #comments:before,
#content.site-content.fullwidthstrechched #comments:before{
  background:transparent;
}
#comments{
width:100%;
float:left;
background:transparent;
}
#comments h2.comments-title,#respond h3{
font-size: 22px;
line-height: 1.2;
position: relative;
margin-bottom: 10px;
}
#comments ol.comment-list{
margin:0;
padding:0;
list-style:none;
position: relative;
}
#content.blog-single #comments .comment-body{
padding:0;
position: relative;
background: transparent;
}
#content.blog-single #comments .comment-body:before{
background:transparent;
}
footer.comment-meta{
position: relative;
}
.comment-navigation{
position:relative;
}
.comment-navigation a{
line-height:normal;
}
.comment-navigation .nav-next{
width:auto;
}
#comments ol{
list-style: none;
display: inline-block;
}
#comments ol.comment-list {
    display: inline-block;
    margin: 10px 0px;
}
.comment-author{
float: left;
clear: right;
position: relative;
}
.comment-meta .says{
display:none;
position: relative;
}
#comments .comment-list li{
display: flow-root;
}
.comment-metadata,.comment-content,.reply,.comment-meta .fn{
width:100%;
float:left;
position: relative;
}
.comment-author img{
    width: 50px;
    height: auto;
    position: relative;
}
#respond.comment-respond{
width:100%;
display:block;
float:left;
padding:20px 0px;
position: relative;
}
#respond.comment-respond #commentform .logged-in-as{
margin-bottom:10px;
}
#respond.comment-respond .comment-form-comment label{
width:100%;
float: left;
position: relative;
}
#respond.comment-respond .comment-form-comment textarea{
width:100%;
border: 1px solid #eee;
position: relative;
margin: 10px 0px;
}
#respond.comment-respond #submit{
    padding:12px 25px;
    color: #ffffff;
    border-color: #006799;
    background-color: #006799;
    margin: 10px 0px;
    display: inline-block;
    border:none;
    font-size: 15px;
    text-decoration: none;
    -webkit-transition: all 0.3s ease;
    -moz-transition: all 0.3s ease;
    -ms-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    transition: all 0.3s ease;
    position: relative;
}
#respond.comment-respond #submit:hover{
cursor:pointer;
position: relative;
}
#respond.comment-respond #submit:focus{
    outline:none;
    position: relative;
}
/*Back to top Start*/
#move-to-top {
position: fixed;
text-align: center;
cursor: pointer;
z-index: 9999;
width: 2.1em;
height: 2.1em;
line-height: 2.1;
color: #fff;
-webkit-border-radius: 2px;
-moz-border-radius: 2px;
border-radius: 2px;   
}
#move-to-top{
    background-color:#006799;
    font-size:18px;
}
#move-to-top{
    right: 30px;
    bottom: 30px;
}
#move-to-top:not(.filling){
    opacity: 0;
    visibility: hidden;
}
#move-to-top i{
 font-family: fontawesome;
  font-weight: normal;
}
/* Back to top end */
/***********************/
/*error 404 page*/
/***********************/
.error404 .page-content #searchform {
    position: relative;
    margin:30px 0px;
}
.error404 .page-content input#s {
    z-index: 1;
    border: none;
    height: 40px;
    line-height: normal;
    margin-bottom: 0;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background: #f3f3f3;
    position: relative;
    width: 50px;
    margin-right: 40px;
    top: 100%;
    border: 1px solid #ddd;
    width: 180px;
    padding: 0px 10px;
    font-size: 13px;
}
.error404 .page-content #searchform:before {
    content: "\f002";
    font-family: FontAwesome;
    position: absolute;
    color: #fff;
    left: 180px;
    width: 40px;
    height: 40px;
    line-height: 40px;
    z-index: 0;
    font-size: 14px;
    text-align: center;
    background: #006799;
}
.error404 .page-content #searchform input[type=submit] {
    display: block;
    width: 20px;
    position: absolute;
    font-size: 0;
    top: 0px;
    left: 180px;
    height: 20px;
    line-height: 30px;
    z-index: 1;
    background: transparent;
    border: none;
    margin-top: 0px;
    height: 40px;
    width: 40px;
}
.error404 #searchform input[type=submit]:hover {
    cursor: pointer;
}
/*form css*/
label{
font-size:18px;
}
input[type=text], 
input[type=email], 
input[type=number],
input[type=url],
input[type=tel],
input[type=password],textarea{
padding: .6180469716em;
    background-color: #f2f2f2;
    color: #43454b;
    -webkit-appearance: none;
    box-sizing: border-box;
    font-weight: 400;

}
[type="submit"]{
padding:15px 30px;
cursor: pointer;
border:0;
}
[type="submit"]:focus,[type="submit"]:active{
 outline:0; 
}
textarea{
border:1px solid #e0e0e0;
width:100%;
height:245px;
margin-bottom:0px;
text-indent: 15px;
padding-top:15px;
}
.wpcf7 input[type="text"], 
.wpcf7 input[type="email"], 
.wpcf7 textarea{
margin-bottom:15px;
}
.wpcf7 textarea{
text-indent: 0px;
}
/*form css*/
/*****************************************/
/*woocommerce style start*/
/*****************************************/
/*cart-css*/
.zita_woo_cart{position:relative;}
.cart-contents .cart-crl{
    color: #fff;
    font-size: 10px;
    line-height: 1;
    font-weight: 600;
    padding: 1px 7px;
    background-color:#006799;
}
.cart-contents .cart-crl{
position:relative;
margin-left:5px;
}
.cart-crl:before{
    content: '';
    position: absolute;
    top: 0;
    left: -3px;
    width: 0;
    height: 0;
    margin-top: 4px;
    border-style: solid solid solid none;
    border-width: 5px 5px 5px medium;
    border-top-color: transparent !important;
    border-bottom-color: transparent !important;
    border-color:#006799;
}
.cart-contents .cart-total{
margin-left:5px;
}
.zita-cart{
    height: auto;
    width: 260px;
    right: -20px;
    position: absolute;
    top: 100%;
    z-index: 99;
    background-color: #fff;
    padding-top: 0px;
    -webkit-box-shadow: 0 1px 3px -2px rgba(0,0,0,.12), 0 1px 2px rgba(0,0,0,.1);
    box-shadow: 0 1px 3px -2px rgba(0,0,0,.12), 0 1px 2px rgba(0,0,0,.1);
    visibility: hidden;
    -moz-opacity: 0;
    -webkit-opacity: 0;
    opacity: 0;
    -webkit-transition: all 0.25s ease-in-out;
    -moz-transition: all 0.25s ease-in-out;
    -ms-transition: all 0.25s ease-in-out;
    -o-transition: all 0.25s ease-in-out;
    transition: all 0.25s ease-in-out;
}

.zita-quickcart-dropdown{
    padding: 20px;
    max-height: 550px;
    overflow-y: auto;
    overflow-x: hidden;
}
.zita-cart ul {
    padding: 0;
    margin: 0;
    list-style: none;
}

.zita-cart li {
    -ms-user-select: none;
    -mos-user-select: none;
    -webkit-user-select: none;
    -o-user-select: none;
    user-select: none;
}
.woocommerce-js .zita-cart  li.woocommerce-mini-cart-item {
margin-bottom: 20px;
overflow: hidden;
position: relative;
}
.zita-cart a.remove {
    display: block;
    float:right;
    font-size: 1.2em;
    height: 1.2em;
    width: 1.2em;
    text-align: center;
    line-height: 1.35;
    border-radius: 0%;
    text-decoration: none;
    font-weight: 700;
    border: 0;
    opacity: 0.8;
    background: transparent;
    webkit-transition: all 0.6s ease;
    transition: all 0.6s ease;
}
.zita-cart ul.cart_list li a{
    display: block;
    font-weight: 300;
    font-size: 16px;
}
.woocommerce-js .zita-cart ul.cart_list li img{
    float: left;
    margin-left: 0px;
    margin-right: 10px;
    width: 50px;
    height: auto;
    box-shadow: none;
}
.zita-cart p.total, .widget p.total {
    margin: 0px;
    border-top: 1px solid rgba(187, 187, 187, 0.32);
    padding-top: 20px;
    padding-bottom: 10px;
}

.zita-cart p.buttons a{
    padding: 7px 20px;
    color: #ffffff;
    background-color: #006799;
    margin-top: 10px;
    display: inline-block;
    font-size:12px;
    border:1px solid;
    border-color:#006799;
}
.zita-cart p.buttons .checkout{
   margin-left:10px;
}
.zita-cart p.buttons a:hover{
color:#fff;
}
.cart-contents:hover + .zita-cart,.zita-cart:hover{
    visibility: visible;
    -moz-opacity: 1;
    -webkit-opacity: 1;
    opacity: 1;
}

/*boxed-layout & contentbox*/
.woocommerce .site-content.boxed, .woocommerce .site-content.contentbox {
    background: transparent;
}

.woocommerce #content.site-content.boxed article.zita-article,
.woocommerce #content.site-content.contentbox article.zita-article {
    background-color: #fff;
    border-bottom: none;
    margin: 0;
    padding: 20px;
    position: relative;
}

.woocommerce #content.site-content.boxed  article.zita-article:before, .woocommerce #content.site-content.contentbox  article.zita-article:before {
    content: '';
    background-color: #fff;
    width: 100%;
    height: 100%;
    position: absolute;
    left: 0;
    top: 0;
    z-index: 0;
    display: block;
}

.woocommerce #content.site-content.boxed #sidebar-primary.widget-area section,.woocommerce #content.site-content.contentbox  #sidebar-primary.widget-area section{
    background-color: #fff;
    padding: 2em;
}
.widget-footer ul li {
   line-height: 2;
}
.widget.widget_nav_menu .zta-custom-item{
display:none;
}
.woocommerce .site-content.boxed .site-container.right #primary {
    border: 0;
    padding-right: 0;
}

.woocommerce .site-content.boxed .site-container.right #sidebar-primary {
    padding-left: 20px;
    padding-right: 0;
}
.woocommerce #content.site-content.contentbox .site-container.left #sidebar-primary {
    padding-right: 50px;
    padding-left: 0;
}
.woocommerce #content.site-content.contentbox .site-container #sidebar-primary {
    padding-left: 50px;
    padding-right: 0;
}
.woocommerce #content.site-content.contentbox #sidebar-primary.widget-area section {
    background: transparent;
    padding: 0;
}
/*boxed-layout & contentbox*/
/*fullwidth and steched*/
.woocommerce  #content.site-content.fullwidthcontained article.zita-article, .woocommerce  #content.site-content.fullwidthcontained article.zita-article:before, .woocommerce #content.site-content.fullwidthstrechched article.zita-article, .woocommerce  #content.site-content.fullwidthstrechched article.zita-article:before {
    background: transparent!important;
}
.woocommerce #content.site-content.fullwidthstrechched #container{
    max-width: 100%;
    width: 100%;
    padding: 0;
}
.woocommerce #content.site-content.fullwidthcontained article.zita-article,.woocommerce #content.site-content.fullwidthstrechched article.zita-article{
background-color: transparent;
padding: 0px;
    margin-bottom: 0px;
    border: 0px;
}
/*fullwidth and steched*/
.woocommerce.boxed #content.site-content article.zita-article, 
.woocommerce.contentbox #content.site-content article.zita-article{
    background-color: transparent;
    border-bottom: 1px solid #eee;
    margin: 0;
    padding: 20px;
    position: relative;
}
.woocommerce .page-title,
.woocommerce .woocommerce-result-count,
.woocommerce nav.woocommerce-pagination{
  position:relative;
}
.woocommerce.boxed #content.site-content article.zita-article:before,
.woocommerce.contentbox #content.site-content article.zita-article:before {
    content: '';
    background-color: #fff;
    width: 100%;
    height: 100%;
    position: absolute;
    left: 0;
    top: 0;
    z-index: 0;
    display: block;
}
.woocommerce nav.woocommerce-pagination ul li{
  float:none;
  border-right:0;
}
.woocommerce nav.woocommerce-pagination ul li a:focus,
.woocommerce nav.woocommerce-pagination ul li a:hover,
.woocommerce nav.woocommerce-pagination ul li span.current{
background:transparent;
}
.woocommerce #respond input#submit, 
.woocommerce a.button,
.woocommerce button.button, 
.woocommerce input.button,.woocommerce #respond input#submit.alt,
 .woocommerce a.button.alt,
 .woocommerce button.button.alt,
  .woocommerce input.button.alt{
padding: 8px 25px;
    color: #ffffff;
    border-color: #006799;
    background-color: #006799;
    display: inline-block;
    line-height:normal;
    border-radius:0;
  font-weight: normal;
}
.woocommerce #respond input#submit.alt.disabled, 
.woocommerce #respond input#submit.alt.disabled:hover, 
.woocommerce #respond input#submit.alt:disabled, 
.woocommerce #respond input#submit.alt:disabled:hover, 
.woocommerce #respond input#submit.alt:disabled[disabled], 
.woocommerce #respond input#submit.alt:disabled[disabled]:hover, 
.woocommerce a.button.alt.disabled, 
.woocommerce a.button.alt.disabled:hover, 
.woocommerce a.button.alt:disabled, 
.woocommerce a.button.alt:disabled:hover,
 .woocommerce a.button.alt:disabled[disabled], 
 .woocommerce a.button.alt:disabled[disabled]:hover, 
 .woocommerce button.button.alt.disabled, 
 .woocommerce button.button.alt.disabled:hover, 
 .woocommerce button.button.alt:disabled, 
 .woocommerce button.button.alt:disabled:hover,
  .woocommerce button.button.alt:disabled[disabled], 
  .woocommerce button.button.alt:disabled[disabled]:hover, 
  .woocommerce input.button.alt.disabled, .woocommerce input.button.alt.disabled:hover, 
  .woocommerce input.button.alt:disabled, .woocommerce input.button.alt:disabled:hover, 
.woocommerce input.button.alt:disabled[disabled], 
.woocommerce input.button.alt:disabled[disabled]:hover{

  border-color: #006799;
    background-color: #006799;
}


.woocommerce #respond input#submit.alt:hover, 
.woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover,
 .woocommerce input.button.alt:hover,.woocommerce #respond input#submit:hover,
  .woocommerce a.button:hover,
   .woocommerce button.button:hover, 
   .woocommerce input.button:hover{
border-color: #015782;
    background-color: #015782;
    color:#fff;
  }
.woocommerce div.product form.cart .button {
    padding: 15px 30px;
}
/*on sale badges*/
.woocommerce ul.products li.product .onsale,.woocommerce span.onsale{
height:50px;
width:50px;
line-height: 50px;
padding:0;
text-align: center;
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    -ms-border-radius: 50%;
    border-radius: 50%;
        background-color:#006799;
        z-index:1;
}
.woocommerce ul.products li.product .onsale.square,
.woocommerce span.onsale.square{
border-radius: 0px;
line-height:22px;
    font-weight: 400;
    text-transform: none;
    z-index: 100;
    position: absolute;
    padding: 4px 12px;
    min-height:auto;
    min-width:auto;
    height:auto;
   width:auto;
   margin:0;

}
.single-product.woocommerce span.onsale.square{
  top:0;
}
.woocommerce ul.products li.product .onsale.diamond,.woocommerce span.onsale.diamond{
border-radius:0;
text-align: center;
transform: rotate(45deg);
}
.woocommerce ul.products li.product .onsale.diamond p,.woocommerce span.onsale.diamond p{
transform: rotate(-40deg);
}
/***********************/
/*product image swap*/
/***********************/
.woocommerce ul.products li.product .woocommerce-loop-product__link img,
 .woocommerce-page ul.products li.product .woocommerce-loop-product__link img {
    margin-bottom: 0px;
    backface-visibility: hidden;
    transition: filter 0.6s ease 0s, opacity 0.6s ease 0s, transform 0.6s ease 0s, -webkit-filter 0.6s ease 0s, -webkit-transform 0.6s ease 0s;
}
.woocommerce .show-on-hover {
    position: absolute;
    top: 0;
    left: 0;
    height: 100%;
    right: 0;
    bottom: 0;
    padding: 0;
    margin: 0;
    opacity: 0;
    filter: blur(0);
    transition: all .2s linear;
}
.woocommerce ul.products li.product .woocommerce-loop-product__link,
.woocommerce-page ul.products li.product .woocommerce-loop-product__link {
    margin-bottom: 0.8em;
    overflow: hidden;
}
.woocommerce li.product:hover .show-on-hover{
    opacity: 1;
    transform: scale(1) translateZ(0) translateY(0);
    pointer-events: inherit;
}
.woocommerce ul.products li.product.zita-woo-hover-zoom:hover img,
.woocommerce-page ul.products li.product.zita-woo-hover-zoom:hover img {
 -webkit-transform: scale(1.1);
  -ms-transform: scale(1.1);
  transform: scale(1.1);
}
/************************************/
/*product-structure*/
/***********************************/
.woocommerce ul.products li.product .woocommerce-loop-product__link, .woocommerce-page ul.products li.product .woocommerce-loop-product__link {
    display: block;
}
.woocommerce ul.products li.product .woocommerce-loop-product__title, .woocommerce-page ul.products li.product .woocommerce-loop-product__title {
    margin-bottom: .5em;
    padding: 0;
    font-size: 1em;
}
.woocommerce ul.products li.product .zta-woo-product-category,
.woocommerce-page ul.products li.product .zta-woo-product-category {
    font-size: .85em;
    margin-bottom: .5em;
    display: block;
    line-height: 1.3;
    opacity: .6;
}
.woocommerce ul.products li.product .button, 
.woocommerce-page ul.products li.product .button {
    margin: .5em 0;
    font-size: 13px;
}
/*********************/
/*content-alignment*/
/*********************/
.woocommerce ul.products li.zita-woo-alignment-center{
    text-align:center;
}
.woocommerce ul.products li.product.zita-woo-alignment-center .star-rating {
    margin-left: auto;
    margin-right: auto;
}
.woocommerce ul.products li.zita-woo-alignment-right{
    text-align:right;

}
.woocommerce ul.products li.product.zita-woo-alignment-right .star-rating {
    margin-left: auto;
    margin-right: 0px;
}
.woocommerce ul.products li.zita-single-product-content-center.last, .woocommerce-page ul.products li.zita-single-product-content-center.last{
margin-right:0;
}
/*********************/
/*box-shadow styel*/
/*********************/
.woocommerce-page ul.products li.product.zita-shadow-0,
.woocommerce-page ul.products li.product.zita-shadow-hover-0:hover{
    -webkit-box-shadow:none;
    box-shadow:none;
}
.woocommerce-page ul.products li.product.zita-shadow-1,
.woocommerce-page ul.products li.product.zita-shadow-hover-1:hover{
    -webkit-box-shadow: 0 1px 3px -2px rgba(0,0,0,.12), 0 1px 2px rgba(0,0,0,.1);
    box-shadow: 0 1px 3px -2px rgba(0,0,0,.12), 0 1px 2px rgba(0,0,0,.1);
    -webkit-transition: all .3s ease-in-out;
    transition: all .3s ease-in-out;
}
.woocommerce-page ul.products li.product.zita-shadow-2,
.woocommerce-page ul.products li.product.zita-shadow-hover-2:hover{
-webkit-box-shadow: 0 3px 6px -5px rgba(0,0,0,.1), 0 4px 8px rgba(0,0,0,.1);
box-shadow: 0 3px 6px -5px rgba(0,0,0,.1), 0 4px 8px rgba(0,0,0,.1);
-webkit-transition: all .3s ease-in-out;
transition: all .3s ease-in-out;
}
.woocommerce-page ul.products li.product.zita-shadow-3,
.woocommerce-page ul.products li.product.zita-shadow-hover-3:hover{-webkit-box-shadow: 0 10px 20px rgba(0,0,0,.1), 0 4px 8px rgba(0,0,0,.1);
    box-shadow: 0 10px 20px rgba(0,0,0,.1), 0 4px 8px rgba(0,0,0,.1);
    -webkit-transition: all .3s ease-in-out;
    transition: all .3s ease-in-out;
  }

.woocommerce-page ul.products li.product.zita-shadow-4,
.woocommerce-page ul.products li.product.zita-shadow-hover-4:hover{-webkit-box-shadow: 0 14px 28px rgba(0,0,0,.12), 0 10px 10px rgba(0,0,0,.12);
    box-shadow: 0 14px 28px rgba(0,0,0,.12), 0 10px 10px rgba(0,0,0,.12);
    -webkit-transition: all .3s ease-in-out;
    transition: all .3s ease-in-out;
  }
.woocommerce-page ul.products li.product.zita-shadow-5,
.woocommerce-page ul.products li.product.zita-shadow-hover-5:hover{-webkit-box-shadow: 0 20px 30px 0 rgba(0,0,0,.2);
    box-shadow: 0 20px 30px 0 rgba(0,0,0,.2);
    -webkit-transition: all .3s ease-in-out;
    transition: all .3s ease-in-out;
  }
.woocommerce-page ul.products li.product.zita-shadow-1 .zita-shop-summary-wrap,
.woocommerce-page ul.products li.product.zita-shadow-2 .zita-shop-summary-wrap,
.woocommerce-page ul.products li.product.zita-shadow-3 .zita-shop-summary-wrap,
.woocommerce-page ul.products li.product.zita-shadow-4 .zita-shop-summary-wrap,
.woocommerce-page ul.products li.product.zita-shadow-5 .zita-shop-summary-wrap{
padding:0px 20px;
}
.woocommerce-page ul.products li.product{
padding-bottom:10px;
}
.woocommerce #respond input#submit.added::after, .woocommerce a.button.added::after, .woocommerce button.button.added::after, .woocommerce input.button.added::after {
    vertical-align: middle;
}
.woocommerce a.added_to_cart {
    padding-top:0;
   display: block;
}
.woocommerce nav.woocommerce-pagination ul {
    padding: 0;
    clear: both;
    border: 1px solid #d3ced2;
    border-right: 0;
    margin: 1px;
    display: contents;
    white-space: nowrap;
}
/*********************/
/*Product Single Page*/
/*********************/
.woocommerce div.product #comments,
.woocommerce div.product #comments:before{
padding:0;
background:transparent;
}
.woocommerce div.product #review_form_wrapper{
display:block;
margin-left:50px;
}
/*quantity*/
.zita-quantity {
    margin-right: 20px;
    float: left;
    border: 1px solid #9c9c9c;
    display: flex;
}
div.product form.cart button.plus {
    display: inline-block;
    float: left;
    font-size: 20px;
    font-weight: 100;
    height: 46px;
    line-height: 46px;
    text-align: center;
    width: 40px;
    background: transparent;
    color: #9c9c9c;
    padding: 0;
    margin: 0;
}
.woocommerce div.product form.cart div.quantity {
    margin: 0;
}

screen-reader-text {
    border: 0;
    clip: rect(1px, 1px, 1px, 1px);
    clip-path: inset(50%);
    height: 1px;
    margin: -1px;
    overflow: hidden;
    padding: 0;
    position: absolute !important;
    width: 1px;
    word-wrap: normal !important;
}
div.product form.cart input[type="number"] {
    border-color: #9c9c9c;
    border-width: 0 1px;
    color: #9c9c9c;
    float: left;
    font-size: 18px;
    height: 46px;
    line-height: 46px;
    padding: 0 5px;
    text-align: center;
    width: 40px;
    border-left: 1px solid;
padding: 0;
    margin: 0;
        border-radius: 0;
}
div.product form.cart button.minus {
    display: inline-block;
    float: left;
    font-size: 20px;
    font-weight: 100;
    height: 46px;
    line-height: 46px;
    text-align: center;
    width: 40px;
    background: transparent;
    color: #9c9c9c;
    padding: 0;
    margin: 0;
}
.summary input[type=number]::-webkit-inner-spin-button, 
.summary input[type=number]::-webkit-outer-spin-button { 
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
    margin: 0; 
}
/*quantity*/
/*align-left*/
.woocommerce div.product.zita-single-product-content-left .flex-viewport,
.woocommerce div.product.zita-single-product-content-right .flex-viewport {
    width: 80%;
    float: right;
  }
.woocommerce div.product.zita-single-product-content-left div.images .flex-control-thumbs,
.woocommerce div.product.zita-single-product-content-right div.images .flex-control-thumbs {
    width: 20%;
    width: -webkit-calc(20% - 1em);
    width: calc(20% - 1em);
  }
.woocommerce div.product.zita-single-product-content-left div.images .flex-control-thumbs li,
.woocommerce div.product.zita-single-product-content-right div.images .flex-control-thumbs li {
    width: 100%;
  }

.woocommerce div.product.zita-single-product-content-left div.images .flex-control-thumbs,
.woocommerce div.product.zita-single-product-content-right div.images .flex-control-thumbs {
    width: calc(20% - 1em);
}
.woocommerce div.product.zita-single-product-content-left div.images .flex-control-thumbs li,
.woocommerce div.product.zita-single-product-content-right div.images .flex-control-thumbs li {
margin-right: 1em;
margin-bottom: 1em;
}
.woocommerce div.product.zita-single-product-content-left .onsale{
    left:0;
}

/************************/
/*wishlist icon*/
.summary .yith-wcwl-add-to-wishlist {
    float: left;
    margin: 0 0 17px 0;
}
.summary .yith-wcwl-add-button, .summary .yith-wcwl-wishlistaddedbrowse,
 .summary .yith-wcwl-wishlistexistsbrowse {
    display: inline-block;
    float: left;
    position: relative;
    text-align: center;
    font-size: 0;
}
.summary .yith-wcwl-add-button .show {
    display: block!important;
}
.summary .yith-wcwl-add-button a, .summary .yith-wcwl-wishlistaddedbrowse a, 
.summary .yith-wcwl-wishlistexistsbrowse a {
    border: 1px solid;
    border-radius: 0;
    color: #9c9c9c;
    display: inline-block;
    font-size: 0;
    height: 40px;
    line-height: 40px;
    width: 40px;
    letter-spacing: normal;
}
.summary .yith-wcwl-add-button>a i,
.summary .yith-wcwl-add-to-wishlist .feedback .yith-wcwl-icon{
  margin:0;
}
.summary .yith-wcwl-add-to-wishlist .add_to_wishlist::before, 
.summary .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistaddedbrowse a::before, 
.summary .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistexistsbrowse a::before {
    content: "\f08a";
    font-family:fontawesome;
    font-size: 16px;
}
.summary .yith-wcwl-add-to-wishlist .ajax-loading {
box-shadow: none !important;
    -moz-box-shadow: none !important;
    -webkit-box-shadow: none !important;
    display: inline !important;
    margin-left: 0px;
    vertical-align: middle;
    visibility: hidden;
    width: 16px !important;
    height: 16px !important;
    position: absolute;
    left: 12px;
    top: 12px;
}
.summary .yith-wcwl-add-to-wishlist.show .add_to_wishlist::before, 
.summary .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistaddedbrowse.show a::before, 
.summary .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistexistsbrowse.show a::before{
color:#015782;
content: "\f004";
}
/*compare style*/
.woocommerce .entry-summary a.compare.button{
border: 1px solid;
    border-radius: 0;
    color: #9c9c9c;
    display: inline-block;
    font-size:0;
    height: 40px;
    line-height: 40px;
    width: 40px;
    background:transparent;
    text-align:center;
    margin-left:10px;
    padding: 0;
}
.woocommerce .entry-summary a.compare.button:before{
content: "\f0ec";
    font-family: FontAwesome;
    display: block;
    color: #9c9c9c;
    font-size: 16px;
}

.woocommerce .entry-summary .product_meta{
margin-bottom:20px;
}
.woocommerce .entry-summary a.compare.button.added:before{
color:#015782;
}
.woocommerce .entry-summary .clear{
clear: initial;
}
/*******************/
/*center-align*/
/*******************/
.woocommerce-page #content .product.zita-single-product-content-center .images{
width: 50%;
float: none;
margin-left: auto;
margin-right: auto;
margin-bottom:1em;
}
.woocommerce #content div.product.zita-single-product-content-center div.summary, .woocommerce div.product.zita-single-product-content-center div.summary {
    width: 80%;
    float: none;
    margin-left: auto;
    margin-right: auto;
    text-align: center;
}
.woocommerce div.product.zita-single-product-content-center div.images .flex-control-thumbs{
padding: 10px 0px;
text-align:center;
}
.woocommerce div.product.zita-single-product-content-center div.images .flex-control-thumbs li{
    margin: 0 auto;
    float: none;
    display: inline-block;
    margin-right:10px;
}
.woocommerce div.product.zita-single-product-content-center div.images .flex-control-thumbs li:last-child{
margin-right:0px;
}
.woocommerce .zita-single-product-content-center .woocommerce-product-rating .star-rating {
    float: none;
    margin: .2em auto;
}
.woocommerce div.product.zita-single-product-content-center form.cart div.quantity {
    display: inline-block;
    vertical-align: middle;
}
.woocommerce div.product.zita-single-product-content-center form.cart .zita-quantity{
    display: inline-block;
    vertical-align: middle;
    float: none;
}
.woocommerce div.product.zita-single-product-content-center form.cart .button {
    vertical-align: middle;
    float: none;
    display: inline-block;
    margin: 0 .75em 0 0;
}
.woocommerce div.product.zita-single-product-content-center form.cart{
margin-bottom:20px;
}
.woocommerce div.product.zita-single-product-content-center .woocommerce-product-rating{
margin-bottom:20px;
}
.woocommerce .zita-single-product-content-center .quantity .qty {
    margin-bottom: 0;
}
.woocommerce #content div.product.zita-single-product-content-center .woocommerce-tabs, 
.woocommerce div.product.zita-single-product-content-center .woocommerce-tabs, 
.woocommerce-page #content div.product.zita-single-product-content-center .woocommerce-tabs, 
.woocommerce-page div.product.zita-single-product-content-center .woocommerce-tabs {
    clear: both;
    text-align: center;
        margin-bottom: 40px;

}
.woocommerce .zita-single-product-content-center .up-sells.upsells.products,
.woocommerce .zita-single-product-content-center .related.products{
    text-align: center;
}
.woocommerce.woocommerce-page .zita-single-product-content-center .related ul.products .product ,
.woocommerce.woocommerce-page .zita-single-product-content-center .upsells.products li{
    float: none;
    display: inline-block;
    vertical-align: top;
}
.woocommerce.woocommerce-page .zita-single-product-content-center .related ul.products li.product, 
.woocommerce.woocommerce-page .zita-single-product-content-center .related ul.products li.product {
    margin: 0 2% 2em 0;
}
.woocommerce.woocommerce-page .zita-single-product-content-center .related ul.products li.product.last, 
.woocommerce.woocommerce-page .zita-single-product-content-center .related ul.products li.product.last {
    margin-right: 0;
}
.woocommerce.woocommerce-page .zita-single-product-content-center .upsells ul.products li.product, 
.woocommerce.woocommerce-page .zita-single-product-content-center .upsells ul.products li.product {
    margin: 2% 2em 0;
}
.woocommerce.woocommerce-page .zita-single-product-content-center .upsells ul.products li.product.last, 
.woocommerce.woocommerce-page .zita-single-product-content-center .upsells ul.products li.product.last {
    margin-right: 0;
}

.woocommerce div.product .product_title,
.woocommerce div.product p.price,
.woocommerce-product-details__short-description,
.woocommerce div.product .woocommerce-product-rating {
    margin-bottom: 10px;
}
.woocommerce h1.product_title,
.woocommerce-Tabs-panel h2,.related.products h2,section.up-sells h2,
.cross-sells h2,.cart_totals h2,.woocommerce-billing-fields h3,
.woocommerce-account .addresses .title h3{
font-size: 26px;
margin-bottom: 20px;
line-height: 1.2;
}
.woocommerce .quantity .qty {
    text-align: center;
    margin-bottom: 0;
        height: 48px;
}
.woocommerce div.product form.cart{
margin-bottom:20px;
margin-top: 20px;
}
.woocommerce .zita-single-product-content-center .products .star-rating{
      display: inline-flex;
}
.woocommerce .zita-single-product-content-center #reviews{
  text-align:left;
}
.woocommerce div.product.zita-single-product-content-center .woocommerce-Tabs-panel{
margin:auto;
width:50%;
}
.single-product.woocommerce .zita-single-product-content-center span.onsale{
    top: 0;
    left: 25%;
}
.woocommerce div.product.zita-single-product-content-center div.images .flex-control-thumbs li{
  width:20%;
}
.woocommerce div.product.zita-single-product-content-center.zita-single-product-tab-vertical .woocommerce-Tabs-panel{
width:auto;
text-align:left;
}
.woocommerce div.product form.cart .variations select{
z-index: 1;
    border: none;
    height: 40px;
    line-height: normal;
    margin-bottom: 0;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background: #f3f3f3;
    position: relative;
    border: 1px solid #ddd;
    padding: 0px 10px;
    font-size: 15px;
    width: 50%;
}
.woocommerce div.product form.cart .variations td.label {
    padding-right: 0;
}
.woocommerce div.product form.cart .variations td, .woocommerce div.product form.cart .variations th {
    border: 0;
    vertical-align: middle;
    line-height: 2em;
}
.woocommerce div.product form.cart .variations label{
font-weight:normal;
}
h1.page-title,h1.entry-title {
    font-size: 30px;
    margin-bottom: 10px;
}
.woocommerce #content table.cart td.actions .input-text, 
.woocommerce-page #content table.cart td.actions .input-text {
    width: auto;
        height: 35px;
}
.woocommerce section{
clear:both;
}
table th {
   background-color: #f8f8f8;
}
table, td, th, .woocommerce table.shop_table{
border:0
}
.woocommerce table.shop_table td, .woocommerce-cart .cart-collaterals .cart_totals tr th{
border:0;
}
table.cart .product-thumbnail img {
   margin: 0 auto;
border-radius:3px;
}
table tbody td {
   background-color: #fdfdfd;
}
table.cart tr:first-child td.product-remove {
   border-top-width: 0;
}
table tbody tr:nth-child(2n) td, fieldset, fieldset legend {
   background-color: #fbfbfb;
}
.woocommerce table.shop_table td, .woocommerce table.shop_table th {
 padding: 1em 1.41575em;
text-align: left;
 vertical-align: top;
}
table.cart td.product-remove, table.cart td.actions {
border-top-color: #ffffff!important;
}
.wc-proceed-to-checkout .button.checkout-button {
   font-size: 1.41575em;
}
.wc-proceed-to-checkout .button.alt.wc-forward {
   display: block;
   text-align: center;
   margin-bottom: 1em;
width:100%;
}
.wc-proceed-to-checkout .button.alt.wc-forward{
   border: 0;
   background: 0 0;
   background-color: #43454b;
   border-color: #43454b;
   color: #fff;
   cursor: pointer;
   padding: .6180469716em 1.41575em;
   text-decoration: none;
   text-shadow: none;
   display: inline-block;
   outline: 0;
   -webkit-appearance: none;
}
table.cart td.actions {
   border-top: 1em solid;
   background-color: transparent;
   padding: 0;
}
.woocommerce a.remove:hover{
  background:transparent!important;
  color:red!important;
}
.woocommerce a.remove{
  background:transparent!important;
  color:#bbb!important;
  font-size:1.2em!important;
}
/*cart page*/
.woocommerce #content table.cart [name=coupon_code], 
.woocommerce-page #content table.cart [name=coupon_code]{
 height: 34px;
}
.woocommerce .product-quantity .quantity .qty {
height: 34px;
}
.woocommerce table.shop_table .product-thumbnail img, 
.woocommerce-page table.shop_table .product-thumbnail img {
    width: auto;
    max-width: 3.706325903em;
   height: auto;
 }
.woocommerce #respond input#submit.disabled, .woocommerce #respond input#submit:disabled, .woocommerce #respond input#submit:disabled[disabled], .woocommerce a.button.disabled, .woocommerce a.button:disabled, .woocommerce a.button:disabled[disabled], .woocommerce button.button.disabled, .woocommerce button.button:disabled, .woocommerce button.button:disabled[disabled], .woocommerce input.button.disabled, .woocommerce input.button:disabled, .woocommerce input.button:disabled[disabled] {
    padding: 8px 25px;
}

.woocommerce #content table.cart td.actions, .woocommerce table.cart td.actions, .woocommerce-page #content table.cart td.actions, .woocommerce-page table.cart td.actions { 
    padding: 20px;
}
.woocommerce .onsale p{
    line-height: inherit!important;
}
.woocommerce-cart .hentry li.product,
 .woocommerce-cart ul.products li.product {
    margin-bottom: 0;
}
.woocommerce .selection span {
    line-height: 35px!important;
    height:35px!important;
}
.woocommerce-MyAccount-content fieldset {
    margin: 10px 2px;
  }
/******************/
/*right-align*/
/******************/
.woocommerce #content div.product.zita-single-product-content-right div.images, 
.woocommerce div.product.zita-single-product-content-right div.images, 
.woocommerce-page #content div.product.zita-single-product-content-right div.images, .woocommerce-page div.product.zita-single-product-content-right div.images {
    float: right;
}
.woocommerce #content div.product.zita-single-product-content-right div.summary, 
.woocommerce div.product.zita-single-product-content-right div.summary, 
.woocommerce-page #content div.product.zita-single-product-content-right div.summary, 
.woocommerce-page div.product.zita-single-product-content-right div.summary {
    float: left;
}
.single-product.woocommerce .product.zita-single-product-content-right span.onsale{
    top: 0;
    right: 0;
    left: auto;
}
.woocommerce div.product.zita-single-product-content-right.sale div.images .woocommerce-product-gallery__trigger{
    bottom: 0;
    right: 0;
    top: auto;
}
.woocommerce div.product.zita-single-product-content-center.sale div.images .woocommerce-product-gallery__trigger{
    bottom:auto;
    right: 0;
    top: 0;
}
/**************/
/*Tab style*/
/**************/
.woocommerce #content div.product .woocommerce-tabs ul.tabs li, 
.woocommerce div.product .woocommerce-tabs ul.tabs li,
 .woocommerce-page #content div.product .woocommerce-tabs ul.tabs li,
  .woocommerce-page div.product .woocommerce-tabs ul.tabs li {
    margin: 0;
}
.woocommerce div.product .woocommerce-tabs ul.tabs {
    padding: 1em 0 0;
    margin: 0 0 2em;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li.active {
    background: transparent;
    z-index: 2;
    border-bottom-color: #fff;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li {
    background: none;
    border: none;
    border-radius: 0;
    margin: 0;
    padding: 0;
    position: relative;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li.active a,
.woocommerce div.product .woocommerce-tabs ul.tabs li:hover a {
    border-color: #006799;
    color: #3a3a3a;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li a {
    border: none;
    border-bottom: 2px solid transparent;
    box-shadow: none;
    padding: .7em .8em;
    text-shadow: none;
    text-transform: uppercase;
    font-size: .9em;
    font-weight: 500;
    letter-spacing: 0.05em;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li::after,
 .woocommerce div.product .woocommerce-tabs ul.tabs li::before{
display:none;
}
.woocommerce div.product .woocommerce-tabs ul.tabs::before {
    border-bottom: 1px solid rgba(0,0,0,.1);
  }
/*VERTICAL STYLE*/
.woocommerce div.product.zita-single-product-tab-vertical .woocommerce-tabs ul.tabs {
    width: 200px;
    float: left;
    padding: 0px;
    margin: 0px;
    border-width: initial;
    border-style: none;
    border-color: initial;
    border-image: initial;
}
.woocommerce div.product.zita-single-product-tab-vertical .woocommerce-tabs ul.tabs li.active {
    z-index: 0;
    border-right-color:rgba(0,0,0,.1);
    border-bottom-color:rgba(0,0,0,.1);
}

.woocommerce div.product.zita-single-product-tab-vertical .woocommerce-tabs ul.tabs li {
    width: 100%;
    margin: 0px;
    border-width: 0px 0px 1px;
    border-style: solid;
    border-color:rgba(0,0,0,.1);
}
.woocommerce div.product.zita-single-product-tab-vertical .woocommerce-tabs .panel {
    margin-left: 220px;
    border-style: solid;
    border-color: rgba(0,0,0,.1);
    border-image: initial;
    border-width: 0px 0px 0px 1px;
    padding: 1.5em;
}
.woocommerce div.product.zita-single-product-tab-vertical .woocommerce-tabs ul.tabs li a{
width:100%;
}
.woocommerce #reviews #comments h2 {
    clear: none;
    position: relative;
}
.woocommerce-variation-price{
margin-bottom:20px;
}
/*add to cart loader*/
.woocommerce ul.products li.product .button #respond input#submit.loading:after,
.woocommerce .woocommerce ul.products li.product .button.loading:after,
.woocommerce .woocommerce ul.products li.product .button.loading:after,
.woocommerce ul.products li.product .button.loading:after{
top:0.8em!important;
}
.woocommerce .widget_price_filter .price_slider_wrapper .ui-widget-content {
    border-radius: 1em;
    background-color: #f3f3f3;
    border: 0;
}
/*checkout page*/
.site-content form input[type="text"], 
.site-content form input[type="password"],
.site-content form input[type="email"],
.site-content form input[type="url"],
.site-content form input[type="date"],
.site-content form input[type="month"],
.site-content form input[type="time"],
.site-content form input[type="datetime"],
.site-content form input[type="datetime-local"],
.site-content form input[type="week"],
.site-content form input[type="number"],
.site-content form input[type="search"],
.site-content form input[type="tel"],
.site-content form input[type="color"],
.site-content form select, 
.site-content form textarea{
    display: inline-block;
    min-height: 40px;
    width: 100%;
    font-size: 14px;
    line-height: 1.8;
    padding: 6px 12px;
    vertical-align: middle;
    background-color: transparent;
    color: #333;
    border: 1px solid #ddd;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    border-radius: 3px;
    -webkit-transition: all 0.3s ease;
    -moz-transition: all 0.3s ease;
    -ms-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    transition: all 0.3s ease;
}
.woocommerce .woocommerce-checkout #customer_details h3 {
    font-size: 14px;
    position: relative;
    margin: 0 0 20px;
    padding-bottom: 8px;
    border-bottom-width: 1px;
    border-bottom-style: solid;
    text-transform: uppercase;
    letter-spacing: 0.6px;
    border-color: #eaeaea;
}
.woocommerce .woocommerce-checkout #customer_details p.form-row label {
    margin: 0 0 5px;
    display: block;
}
.woocommerce-checkout>.col2-set>.col-2 {
    float: none;
    width: 100%;
}
.woocommerce-checkout #order_review {
    float: right;
    width: 48%;
}
.woocommerce .woocommerce-checkout h3#order_review_heading {
    font-size: 14px;
    position: relative;
    margin: 0 0 20px;
    padding-bottom: 8px;
    border-bottom-width: 1px;
    border-bottom-style: solid;
    text-transform: uppercase;
    letter-spacing: 0.6px;
    border-color: #eaeaea;
}
.woocommerce-checkout h3#order_review_heading {
    float: right;
    width: 48%;
}
.woocommerce #order_review table.shop_table {
    margin: 0 0 40px;
    border: none;
}
.woocommerce table.shop_table {
    border-width: 1px;
    border-style: solid;
    margin: 0 -1px 24px 0;
    text-align: left;
    width: 100%;
    border-collapse: separate;
    border-color: #eaeaea;
}
.woocommerce-cart-form button.button{
padding: .618em 1em;
}
.woocommerce-checkout>.col2-set {
    float: left;
    width: 48%;
}
.woocommerce-checkout>.col2-set>.col-1 {
    float: none;
    width: 100%;
    margin-bottom: 30px;
}
.woocommerce .form-row-first {
    float: left;
    width: 48%;
    margin-right: 4%;
}
.woocommerce-checkout #payment ul.payment_methods li:hover {
    background-color: #f5f5f5;
}
.woocommerce-checkout #payment ul.payment_methods li {
    background-color: #fafafa;
    text-align: left;
    margin-bottom: 1px;
    -webkit-transition: all 0.3s ease;
    -moz-transition: all 0.3s ease;
    -ms-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    transition: all 0.3s ease;
}
.woocommerce-checkout .woocommerce-info {
    padding: 10px 0;
    text-align: center;
    border-width: 1px 0;
    border-color: #eaeaea;
background:transparent;
}
.woocommerce-info {
    display: inline-block;
    width: 100%;
    font-size: 12px;
    font-weight: 400;
    color: #777;
    border: 1px solid #ddd;
    margin: 0 0 30px;
    padding: 10px 15px;
    text-align: left;
    text-transform: uppercase;
    border-color: #b1befd;
}
.woocommerce table.shop_table thead {
    background-color: #f7f7f7;
}
.woocommerce #order_review table.shop_table thead th {
    font-size: 15px;
    letter-spacing: 1px;
    padding: 20px;
}
.woocommerce #order_review table.shop_table th{
    border: none;
    padding: 16px 20px;
}
.woocommerce table.shop_table thead th{
    color: #444;
    font-weight: 600;
}
.woocommerce table.shop_table th{
    padding: 0.8em;
    vertical-align: middle;
}
table th, table td {
    padding: 10px;
    text-align:center;
    vertical-align: top;
    border-bottom: 1px solid #e9e9e9;
}
.woocommerce #order_review table.shop_table thead th.product-total {
    text-align: right;
}
.woocommerce #order_review table.shop_table tbody td.product-name {
    max-width: 376px;
    text-align: left;
}
.woocommerce #order_review table.shop_table tbody td {
    background-color: #fdfdfd;
}
.woocommerce #order_review table.shop_table td {
    border: none;
    padding: 16px 20px;
    text-align: right;
}
.woocommerce table.shop_table td {
    padding: 0.8em;
    vertical-align: middle;
    text-transform: capitalize;
    border-color: #eaeaea;
}
.woocommerce #order_review table.shop_table tfoot th {
    font-weight: 600;
    color: #444;
}
.woocommerce #order_review table tfoot th {
    text-transform: capitalize;
}
.woocommerce-checkout-review-order-table tfoot th {
    background-color: #f7f7f7;
}
.woocommerce-info:before {
    font-family: 'FontAwesome';
    font-weight: normal;
    font-style: normal;
    letter-spacing: normal;
    text-rendering: auto;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    margin-right: 10px;
    content: '\f129';
    color: #b1befd;
}
.woocommerce-checkout #payment ul.payment_methods li:hover {
    background-color: #f5f5f5;
}
.woocommerce-checkout #payment ul.payment_methods {
    padding-bottom: 20px;
    background-color: #fafafa;
}
.woocommerce-checkout #payment {
    background: transparent;
}
.woocommerce-checkout #place_order {
    width: 100%;
    font-size: 15px;
    line-height: 1.6;
    padding: 16px 20px;
}
.woocommerce-checkout .woocommerce-info:before {
    color: #ddd;
}
.woocommerce-checkout form.checkout_coupon {
    display: block;
    border: 3px dashed rgba(84,84,84,0.15);
    padding: 28px;
    width: 695px;
    margin: 0 auto 30px;
    text-align: center;
}
.woocommerce-checkout form.checkout_coupon .form-row-first {
    float: left;
    width: 74%;
}
.woocommerce-checkout form.checkout_coupon .form-row-last {
    float: right;
    width: 25%;
}
.woocommerce-checkout form ,.woocommerce-checkout textarea {
    line-height: 1.5;
    resize: vertical;
}
.woocommerce-checkout .woocommerce-info a {
    font-size: 12px;
    float: none;
    padding: 0;
    letter-spacing: 0;
    background-color: transparent;
    color: #13aff0;
} 
/*account page*/
form.woocommerce-form.woocommerce-form-login.login {
    border-color: #eaeaea;
}
.woocommerce-MyAccount-navigation ul li a {
   padding: 12px 0;
   display: block;
}
.woocommerce-MyAccount-navigation ul li {
   list-style: none;
   border-bottom: 1px solid #eaeaea;
   position: relative;
}

.woocommerce-MyAccount-navigation ul{
margin:0;
}

.woocommerce-account .woocommerce-MyAccount-content {
    float: right;
    width: 64%;
}
/*woocommerce widget style*/
.woocommerce ul.cart_list li img, .woocommerce ul.product_list_widget li img {
    float: right;
    margin-left: 4px;
    width: auto;
    height: auto;
    box-shadow: none;
    max-width: 3.706325903em;
}
.woocommerce ul.cart_list li a, .woocommerce ul.product_list_widget li a{
  font-weight:normal;
}
.widget.woocommerce .star-rating{
font-size:0.7em;
}
/******************************/
/*woocommerce quick view style*/
/*******************************/
.zita-shop-thumbnail-wrap{
position:relative;
}
.zta-quick-view-text:hover {
    background: #000;
    color: #fff;
}
.zita-shop-thumbnail-wrap:hover .zta-quick-view-text{
    opacity: 1;
}
.zta-quick-view-text{
    position: absolute;
    opacity: 0;
    bottom: 0;
    left: 0;
    width: 100%;
    text-align: center;
    background: rgba(0,0,0,.7);
    color: #fff;
padding: 5PX 0PX;
font-size: 13PX;
}
.zta-quick-view-text span{
    font-size: 16px;
    margin-top: 2px;
    margin-right: 5px;
}
/******************************/
/*woocommerce quick view style*/
/*******************************/
/*/ *****extra css Start*******/
#multi-store.header-category li{
list-style-type: none;
}
#multi-store.header-category .product-categories{
margin:0px;
list-style-type: none;
}
#multi-store.header-category li a{
padding:10px 20px;
display: block;
color:#2d2d2d;
border-bottom: 1px solid #e6e6e6;
}
#multi-store.header-category li:last-child a{
border:none;
}
/*****extra css End*******/
/*****extra css Start*******/
#doctor-booking ::placeholder {
  color: #fff;
}
#doctor-booking .zita-three-column input{
  width: 30%;
  float: left;
margin-right:1.5%;
margin-left:1.5%;
margin-bottom:20px;
box-shadow:none;
}
#doctor-booking .zita-three-column input, .zita-two-column1 input, .zita-two-column2 textarea{
background:none;
border:none;
border-bottom:1px solid #fff;
}
#doctor-booking .zita-two-column2 textarea{
height:25px;
margin-bottom: 0px;
   padding-top: 5px;
    box-shadow:none;
}
#doctor-booking .zita-two-column1 input{
width:30%;
float:left;
margin: 0 1.5%;
}
#doctor-booking .zita-two-column1 [type="date"]{
       color: #fff;
}
#doctor-booking .zita-two-column2{
width:50%;
float:left;
margin: 0 1.5%;
}
#doctor-booking .zita-submit {
  width: 11%;
  float: left;
       margin: 0 1.5%;
}
#doctor-booking .zita-submit [type="submit"]{
   font-size:15px;
   padding:4px 16px;
   background: none;
  border: 1px solid #fff;
  color: #fff;
}
/****************restaurant******************/
#restaurant input[type=text], #restaurant input[type=email]{
width:100%;
font-size:14px;
height:50px;
}
#restaurant textarea{
font-size:14px;
}

#home-consult-form .wpcf7 input, #home-consult-form .wpcf7-textarea {
   font-size: 13px;
   line-height: 24px;
   letter-spacing: 0.025em;
   color: #555555;
   background: #ffffff;
   margin-bottom: 5px;
   padding: 10px 15px;
   border: 1px solid #ffffff;
   -webkit-border-radius: 5px !important;
   -moz-border-radius: 5px !important;
   border-radius: 5px !important;
   width: 100%;
}
#home-consult-form input.wpcf7-form-control.wpcf7-submit{
font-size: 14px;
   color: #fff;
   border: 1px solid #32373c;
   background: #32373c;
   text-transform: uppercase;
   letter-spacing: 2px;
}
#home-consult-form .wpcf7-textarea{
height:70px;
  }
#home-consult-form input[type="text"]:focus, #home-consult-form input[type="email"]:focus, #home-consult-form textarea:focus{
border: 1px solid rgba(57, 188, 221, 0.5);
   -webkit-box-shadow: 0px 0px 5px rgba(57, 188, 221, 0.25);
   -moz-box-shadow: 0px 0px 5px rgba(57, 188, 221, 0.25);
   box-shadow: none;
   outline: none;
}
#home-consult-form input[type="text"]{
margin-right:1%;
}
#home-consult-form input[type="text"], #home-consult-form input[type="email"]{
width:49.5%;
float:left;
}
#home-consult-form  p{
margin-bottom:0;
}
/*****extra css End*******/
/*****extra css Start*******/
#wineshop .woocommerce ul.products li.product .zta-woo-product-category{
color:#8a8787;
opacity:1;
}
#wineshop .woocommerce-loop-product__title{
color:#fff;
}
/*****extra css End*******/
/*****extra css Start*******/
#newsletter .wpcf7-form-control-wrap input{
width:70%;
float:left;
text-indent:11px;
height:50px;
}
#newsletter input.wpcf7-form-control.wpcf7-submit{
width: 29%;
font-weight:bold;
margin-bottom: 0;
margin-left:1%;
height:50px;
}
#newsletter.beautyandspa .wpcf7-form-control-wrap input{
border-radius:50px;
}
/*****extra css Start*******/
/********************************************/
/*404-page-style*/
/********************************************/
.error404.boxed #content.site-content article.zita-article, .error404.contentbox #content.site-content article.zita-article {
background-color: transparent;
border-bottom: 1px solid #eee;
margin: 0;
padding: 20px;
position: relative;
}

.error404.boxed #content.site-content article.zita-article:before, .error404.contentbox #content.site-content article.zita-article:before{
    content: '';
    background-color: #fff;
    width: 100%;
    height: 100%;
    position: absolute;
    left: 0;
    top: 0;
    z-index: 0;
    display: block;
}
.error-404.not-found{
position:relative;
}
/********************************************/
/*search-no-found-style*/
/********************************************/
.search-no-results.boxed #content.site-content article.zita-article, 
.search-no-results.contentbox #content.site-content article.zita-article {
background-color: transparent;
border-bottom: 1px solid #eee;
margin: 0;
padding: 20px;
position: relative;
}

.search-no-results.boxed #content.site-content article.zita-article:before, 
.search-no-results.contentbox #content.site-content article.zita-article:before{
    content: '';
    background-color: #fff;
    width: 100%;
    height: 100%;
    position: absolute;
    left: 0;
    top: 0;
    z-index: 0;
    display: block;
}

.no-results.not-found{
position:relative;
}

.search .main-content-row .page-header{
padding: 0px 10px;
}
.search.search-no-results .main-content-row .page-header{
padding: 0;
}
.search-no-results.boxed .zta-one-colm .main-content-row,
.search-no-results.boxed .zta-two-colm .main-content-row, 
.search-no-results.boxed .zta-three-colm .main-content-row, 
.search-no-results.boxed .zta-four-colm .main-content-row,
.search-no-results.contentbox .zta-one-colm .main-content-row,
.search-no-results.contentbox .zta-two-colm .main-content-row,
.search-no-results.contentbox .zta-three-colm .main-content-row,
.search-no-results.contentbox .zta-four-colm .main-content-row{
margin:0;
}
/* bbPress CSS*/
.single.bbpress .site-content #primary, .single.bbpress .site-content #sidebar-primary {
margin-top:140px!important;
}
.bbpress .site-content #primary {
background:#fff;
padding:20px;
border: 1px solid #e5e5e5;
-webkit-box-shadow: 0 1px 1px rgba(0,0,0,.04);
    -moz-box-shadow: 0 1px 1px rgba(0,0,0,.04);
    box-shadow: 0 1px 1px rgba(0,0,0,.04);
}

#bbpress-forums ul.bbp-forums{
border: 1px solid #fff;
}
#bbpress-forums li.bbp-header, #bbpress-forums li.bbp-footer, #bbpress-forums ul.odd, #bbpress-forums ul.bbp-topics{
background:none;
border:none;
}
.bbp-topics-front ul.super-sticky, .bbp-topics ul.super-sticky, .bbp-topics ul.sticky, .bbp-forum-content ul.sticky {
    background-color: #00bcd417 !important;
}
.bbp-topic-title, .bbp-forum-info{
font-size:15px;
}
.bbp-pagination-links .page-numbers {
    line-height: 34px;
}
.bbp-pagination-links .next.page-numbers{
    line-height: 16px;
}
.bbp-pagination-links a:hover, .bbp-pagination-links span.current {
    background: #f5f5f5;
    color: #8e8e8e;
    opacity: 0.8;
    border: 1px solid #ddd;
}
/***Login Form CSS***/
.bbp-username label.hide{
margin-bottom:10px;
}
.bbp-submit-wrapper [type='submit'], #bbp-search-form .button, #bbpress-forums #bbp-your-profile fieldset.submit button{
font-weight:600;
font-size:16px;
}
.bbp-logged-in .button.logout-link {
    color: red;
    font-weight: 400;
    top: -18px;
    position: relative;
    text-decoration: underline!important;
}
.bbp-logged-in{
margin-top:20px;
}
.bbp-login-form .bbp-remember-me label{
font-size:14px;
}
.bbp-login-form .bbp-remember-me {
margin-bottom:0px;
}
.bbp-login-form .bbp-submit-wrapper{
float:none;
}
.bbp-login-form .bbp-submit-wrapper button, #bbp-search-form .button, .bbp-topic-form .bbp-submit-wrapper button, .bbp-reply-form .bbp-submit-wrapper button {
border:1px solid;
}
#bbp-search-form{
text-align:left;
margin-top: 24px;
}
.bbp-login-form .bbp-submit-wrapper {
text-align: center;
margin-bottom:10px;
} 
/***Forum Single Page**/

.bbp-login-form .bbp-form .bbp-username .hide {
width:100%;
}
.bbp-reply-form label{
font-size:14px;
}

.bbp-author-role {
    position: relative;
    top: -18px;
}
.single.bbpress .site-content #primary, .single.bbpress .site-content  #sidebar-primary{
margin-top:150px;
}
.single.bbpress header.zta-transparent-header{
background:#fff;
}
/* BBP CSS END*/

/*WPL plugin*/
.wpl_mcalc_container label{
width: 150px;
text-align:left;
}
.site-content .wpl_mcalc_container form input[type="text"]{
width:100px;
}
#wpl_addon_membership_container label {
  font-size: 15px;
}
.wpl_property_manager .chosen-container {
    max-width: 80%;
}
.thunk-comment-paginate{
  position: relative;
  margin: 10px 0;
}
.thunk-comment-paginate .next.page-numbers{
  float: initial;
}
/*=================================
*  Learnpress Css
==================================*/
.course-detail{
  background: #FFF;
  padding: 15px;

}
.course-title{
  color: #5c666d;
  font-weight:bold;
    letter-spacing:1.2px;
  font-size: 18px;
  line-height: 25px;
  margin-bottom: 10px;

}
.course-meta-field{
   color: #279a13;
  font-size: 15px;
  padding:4px;
  line-height: 23px;
   display:inline-block;
  margin-bottom: 10px;
}
.course-description{
  color: #a2aeb1;
  font-size: 16px;
  letter-spacing:1.2px;
  padding:4px;
  line-height: 23px;
    margin-bottom: 10px;
}
.course-student-number.course-meta-field,.course-lesson-number.course-meta-field {
    color: #a2aeb1;
}
.course-meta-field > a {
    color: #555;
    font-size: 14px;
     padding: 1px 7px;
    background: #ffe799;
    border-radius: 4px;
}

.course-cover img{
  display: block;
}

.archive-course-widget-outer .widget-footer{
  text-align: center;
  margin-top: 40px;
}
.archive-course-widget-outer .pull-right{
    width: auto;    
    padding: 15px 24px;
    border-radius: 3px;
    color: #fff;
    background: #ffb606;
    font-weight: 400;
    line-height: 1;
    transition: all 0.3s;
    display: block;
    float: initial;
    width: auto;
    position: relative;
    display: inline-block;
}

/*=================================
*  Learnpress 4 Column
==================================*/
.archive-course-widget-outer.four-colum-grid .widget-body{
  display: flex;
  flex-wrap: wrap;
}
.archive-course-widget-outer.four-colum-grid .course-entry{
  width: 23.5%;
  margin-right: 2%;
  margin-bottom: 2%;
}
.archive-course-widget-outer.four-colum-grid .course-entry:nth-of-type(4n+4){
  margin-right: 0;
}

/*=================================
*  Learnpress 3 Column
==================================*/

.archive-course-widget-outer.three-colum-grid .widget-body{
  display: flex;
  flex-wrap: wrap;
}
.archive-course-widget-outer.three-colum-grid .course-entry{
  width: 32%;
  margin-right: 2%;
  margin-bottom: 2%;
}
.archive-course-widget-outer.three-colum-grid .course-entry:nth-of-type(3n+3){
  margin-right: 0;
}

/*=================================
*  Learnpress List View Css
==================================*/
.learnpress-list-view .course-entry{
  background: #FFF;
  border-radius: 4px;
  border: 1px solid rgba(204, 204, 204, 0.3);
  display: flex;
  flex-wrap: wrap;
  margin-bottom: 20px;
  padding: 20px;
}
.learnpress-list-view .course-cover{
  width: 35%;
  position: relative;
  overflow: hidden;
}

.learnpress-list-view .course-detail{
  width: 65%;
  position: relative;
  padding: 15px 30px!important;
}
.learnpress-list-view .course-cover img{
  transition: all 0.5s ease;
}
.learnpress-list-view .course-cover:hover img{
  transform: scale(1.2);
}
@media screen and (max-width:1024px){
.pan-content::-webkit-scrollbar-thumb{
visibility:visible;
}
.mhdrleftpan .sider.left{
border-right:0px;
}
.mhdrrightpan .sider.right{
border-left:0px;
}
.menu-custom-widget{
text-align:left;
}
.zita-site .mhdrleftpan .sider-inner ul#zita-menu,
.zita-site .mhdrrightpan .sider-inner ul#zita-menu,
.zita-site .mhdrrightpan .sider-inner ul#zita-menu.zita-menu > li > a:hover,
.zita-site .mhdrleftpan .sider-inner ul#zita-menu.zita-menu > li > a:hover,
.zita-site .mhdrrightpan .zita-menu li ul.sub-menu,
.zita-site .mhdrleftpan .zita-menu li ul.sub-menu,
.sider #zita-above-menu.zita-menu li ul.sub-menu,
.sider #zita-above-menu.zita-menu li ul.sub-menu li:hover,
.main-header .sider-inner ul.zita-menu li ul.sub-menu,
.main-header .sider-inner ul.zita-menu li ul.sub-menu li:hover{
background:transparent!important;
}
.zita-site .mhdrleftpan .sider.left,
.zita-site .mhdrleftpan .sider.right,
.zita-site .mhdrrightpan .sider.left,
.zita-site .mhdrrightpan .sider.right{
 background:transparent; 
 padding:0;
 overflow-x: inherit;
 overflow-y: inherit;
}
.zita-menu li a{
  text-align:left;
}
.main-header-col2{display: -webkit-flex;
    display: flex;
}
.main-header-col2 nav{order:2;}
.zita_woo_cart{order:1;}
.main-header .main-header-col2 .cart-contents{
margin-right: 10px;
margin-left:0;
}
}
@media only screen and (max-width: 959px){
.woocommerce-checkout>.col2-set {
   float: none;
   width: 100%;
}
.woocommerce-checkout form.checkout {
   margin-top: 10px;
}
.woocommerce-checkout #order_review {
   float: none;
   width: 100%;
}
}
@media (min-width: 768px){
table.cart td, table.cart th {
   padding: 1.618em;
}
table.shop_table_responsive tbody tr td, table.shop_table_responsive tbody tr th {
   text-align: left;
}
table.cart td.product-remove {
   display: table-cell;
   padding: 1.618em;
   border: 0;
}
table.cart td.actions .coupon {
   padding-bottom: 0;
   margin-bottom: 0;
   border-bottom: none;
   display: inline-block;
   float: left;
}
.cart-collaterals h2 {
   font-size: 1.618em;
}
.woocommerce-MyAccount-content{
   width: 76.4705882353%;
   float: right;
   margin-right: 0;
}
.woocommerce-MyAccount-navigation{
   width: 17.6470588235%;
   float: left;
   margin-right: 5.8823529412%;
}
}
@media screen and (max-width:768px){
body.mobile-pan-active {
    overflow-x: hidden;
    overflow-y: hidden;
}
body.mobile-pan-active #page.zita-site{
display: contents;
}
.woocommerce.woocommerce-page .zita-single-product-content-center .related ul.products li.product, 
.woocommerce.woocommerce-page .zita-single-product-content-center .related ul.products li.product {
    margin: 0 1% 2em 0;
  }
.woocommerce.woocommerce-page .zita-single-product-content-center .upsells ul.products li.product, 
.woocommerce.woocommerce-page .zita-single-product-content-center .upsells ul.products li.product {
    margin: 1% 2em 0;
  }
  .woocommerce-account .woocommerce-MyAccount-content{
    float: left;
    width: 100%;
    margin-top: 30px;
}
.woocommerce #content div.product div.images, 
.woocommerce #content div.product div.summary, 
.woocommerce div.product div.images, 
.woocommerce div.product div.summary, 
.woocommerce-page #content div.product div.images, 
.woocommerce-page #content div.product div.summary, 
.woocommerce-page div.product div.images, 
.woocommerce-page div.product div.summary{
    width: 100%;
    float: left;
}
.woocommerce #content div.product.zita-single-product-content-center div.summary,
.woocommerce div.product.zita-single-product-content-center div.summary,
.woocommerce-page #content .product.zita-single-product-content-center .images{
    width:100%;
}
}
@media screen and (max-width:767px){
img.alignright, div.alignright, figure.alignright, img.alignleft, div.alignleft, figure.alignleft, img.wp-post-image.attachment-thumb {display:block; margin:1em auto; float:none;}
.gallery.gallery-columns-4 figure, .gallery.gallery-columns-5 figure, .gallery.gallery-columns-6 figure, .gallery.gallery-columns-7 figure, .gallery.gallery-columns-8 figure, .gallery.gallery-columns-9 figure {width:100%; margin:0 0 1em 0; float:none;}
.site-content #primary {
    width:100%!important;
    margin-bottom: 20px;
}
.site-content #sidebar-primary{
   width:100%!important;
   padding:0!important;
   margin-top: 20px;
   margin-bottom: 20px;
   max-width: 330px;
  float: none;
}
#content .zta-two-colm article.zita-article,
#content .zta-three-colm article.zita-article,
#content .zta-four-colm article.zita-article{
  width:100%;
 }
#content .entry-content-outer-wrapper.zta-blog-layout-2{
 display:block; 
}
#content .zta-blog-layout-2 article.zita-article .entry-content-outer-wrapper,
#content .zta-blog-layout-3 article.zita-article .entry-content-outer-wrapper,
#content .zta-blog-layout-4 article.zita-article .entry-content-outer-wrapper{
display:block;
}
#content article.zita-article .zta-blog-layout-2 .post-img-wrapper,
#content article.zita-article .zta-blog-layout-2 .entry-content-wrapper,
#content article.zita-article .zta-blog-layout-3 .post-img-wrapper,
#content article.zita-article .zta-blog-layout-3 .entry-content-wrapper,
#content article.zita-article:nth-child(even) .zta-blog-layout-4 .post-img-wrapper,
#content article.zita-article:nth-child(even) .zta-blog-layout-4 .entry-content-wrapper,
#content article.zita-article:nth-child(odd) .zta-blog-layout-4 .post-img-wrapper,
#content article.zita-article:nth-child(odd) .zta-blog-layout-4 .entry-content-wrapper{
width:100%;
float:none;
padding: 0;
}
#content article.zita-article .zta-blog-layout-2 .post-img-wrapper .post-img,
.zta-blog-layout-3 .post-img-wrapper .post-img,
#content .entry-content-outer-wrapper.zta-blog-layout-4 .post-img-wrapper .post-img{
    margin-bottom: 20px;
  }
.fullwidthstrechched #container {
    padding-left: 20px;
    padding-right: 20px;
}
.fullwidthstrechched #content article.zita-article {
    margin-bottom: 20px;
  }
.site-content .site-container.right #primary{
    border-right:0;
    padding:0px;
  }
.abv-three .top-header-container,
.btm-three .bottom-header-container,
.ft-abv-three .top-footer-container,
.ft-btm-three .bottom-footer-container,
.ft-wgt-five .widget-footer-container,
.ft-wgt-six .widget-footer-container,
.ft-wgt-seven .widget-footer-container,
.ft-wgt-eight .widget-footer-container{
  display:block;
}
.abv-two .top-header-col1,
.top-header .abv-two .top-header-col2,
.top-header .abv-three .top-header-col1,
.top-header .abv-three .top-header-col2,
.top-header .abv-three .top-header-col3,
.btm-two .bottom-header-col1,
.btm-two .bottom-header-col2,
.bottom-header .btm-three .bottom-header-col1,
.bottom-header .btm-three .bottom-header-col2,
.bottom-header .btm-three .bottom-header-col3,
.ft-abv-two .top-footer-col1,
.ft-abv-two .top-footer-col2,
.ft-abv-three .top-footer-col1,
.ft-abv-three .top-footer-col2,
.ft-abv-three .top-footer-col3,
.ft-btm-two .bottom-footer-col1,
.ft-btm-two .bottom-footer-col2,
.ft-btm-three .bottom-footer-col1,
.ft-btm-three .bottom-footer-col2,
.ft-btm-three .bottom-footer-col3{
width:100%;
justify-content: center;
text-align:center;
}
.ft-wgt-two .widget-footer-col1, 
.ft-wgt-two .widget-footer-col2,
.ft-wgt-three .widget-footer-col1, 
.ft-wgt-three .widget-footer-col2,
.ft-wgt-three .widget-footer-col3,
.ft-wgt-four .widget-footer-col1, 
.ft-wgt-four .widget-footer-col2, 
.ft-wgt-four .widget-footer-col3, 
.ft-wgt-four .widget-footer-col4,
.ft-wgt-five .widget-footer-container .widget-footer-col1,
.ft-wgt-five .widget-footer-container .widget-footer-col2,
.ft-wgt-five .widget-footer-container .widget-footer-col3,
.ft-wgt-six .widget-footer-container .widget-footer-col1,
.ft-wgt-six .widget-footer-container .widget-footer-col2,
.ft-wgt-six .widget-footer-container .widget-footer-col3,
.ft-wgt-seven .widget-footer-container .widget-footer-col1,
.ft-wgt-seven .widget-footer-container .widget-footer-col2,
.ft-wgt-eight .widget-footer-container .widget-footer-col1,
.ft-wgt-eight .widget-footer-container .widget-footer-col2{
    width: 100%;
}
#content article.zita-article .entery-header {
    margin-bottom: 10px;
}
article.zita-article h2.entry-title {
    font-size: 22px;
    line-height: 1.3;
}
.zita-site #content .entry-meta{
 font-size:12px; 
}
.entry-header h1.entry-title{
font-size:26px;
line-height:1.6;  
}
.page-numbers {
    margin: 0 3px;
    padding: 8px 0;
    font-size: 13px;
    line-height: 13px;
}
.next.page-numbers, .prev.page-numbers {
    padding: 8px 18px;
  }
  .post-navigation, nav.pagination {
    padding: 10px 0px;
}
.content-social .social-icon a {
    font-size: 12px;
    width: 1.1em;
    height: 1.1em;
    line-height: 1.1em;
}
#content .zta-blog-highlight.zta-three-colm article.zita-article:first-child,
#content .zta-blog-highlight.zta-four-colm article.zita-article:first-child{
  width:100%;
}

/*top-header*/
.top-header .top-header-bar .top-header-col1 .menu-toggle .menu-btn,
.top-header .top-header-bar .top-header-col1 .menu-toggle .menu-btn{
float:none;
margin: 0 auto;
}
.top-header-container,.top-footer-container{
line-height:normal!important;  
}
.top-header .top-header-bar .top-header-col1,
.top-header .top-header-bar .top-header-col2,
.top-header .top-header-bar .top-header-col3{
  padding:10px 0px;
}
/*bottom-header*/
.bottom-header .bottom-header-bar .bottom-header-col1 .menu-toggle .menu-btn,
.bottom-header .bottom-header-bar .bottom-header-col1 .menu-toggle .menu-btn{
float:none;
margin: 0 auto;
}
.bottom-header-container,.bottom-footer-container{
line-height:normal!important;  
}
.bottom-header .bottom-header-bar .bottom-header-col1,
.bottom-header .bottom-header-bar .bottom-header-col2,
.bottom-header .bottom-header-bar .bottom-header-col3{
  padding:10px 0px;
}
.mhdrleft .zita-cart,
.mhdrright .zita-cart,
.mhdrcenter .zita-cart{
  display:none;
}

/*min bar header responsive style*/
.mhdminbarleft #page.zita-site{
margin-left:0px!important;
left:auto;
}
header.mhdminbarleft .min-bar-header{
padding:0;
}
header.mhdminbarleft .min-bar-header.leftminbar{
height:auto;
width: 100%;
z-index: 0;
}
header.mhdminbarleft .min-bar-container{
text-align: inherit;
-js-display: flex;
    display: -webkit-box;
    display: -webkit-flex;
    display: -moz-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -webkit-align-items: center;
    -moz-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    -webkit-flex-wrap: wrap;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -webkit-align-content: center;
    -ms-flex-line-pack: center;
    align-content: center;
}
header.mhdminbarleft .min-bar-col2 {
    -webkit-transform: inherit;
    -moz-transform: inherit;
    transform: inherit;
    -webkit-transform-origin: 0 0;
    -moz-transform-origin: 0 0;
    transform-origin: 0 0;
   position: relative;
   top: 0;
   left: 0;
       width: 75%!important;
}
header.mhdminbarleft .container{
max-width: 1200px;
padding-left: 20px;
padding-right: 20px;
}
header.mhdminbarleft .min-bar-col1{
order:2;
    order: 2;
    -webkit-box-pack: end;
    -webkit-justify-content: flex-end;
    -moz-box-pack: end;
    -ms-flex-pack: end;
    justify-content: flex-end;
    -webkit-box-pack: start;
    -webkit-justify-content: flex-start;
    -moz-box-pack: start;
    -ms-flex-pack: start;
    justify-content: flex-start;
    -webkit-box-flex: 1;
    -webkit-flex: 1;
    -moz-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
}
header.mhdminbarleft .min-bar-col2{
order:1;
padding-top: 10px;
    padding-bottom: 10px;
}
.mobile-pan-active header.mhdminbarleft {
    left: 0px!important;
}
.mhdminbarleft .pan-content{
padding:0;
position: relative;
background: #fff;
}

/*right-minbar*/
.mhdminbarright #page.zita-site {
    margin-right:0px;
}
header.mhdminbarright .min-bar-header{
padding:0;
}
header.mhdminbarright .min-bar-header.rightminbar{
height:auto;
width: 100%;
z-index: 0;
}
header.mhdminbarright .min-bar-container{
text-align:inherit;
-js-display: flex;
    display: -webkit-box;
    display: -webkit-flex;
    display: -moz-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -webkit-align-items: center;
    -moz-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    -webkit-flex-wrap: wrap;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -webkit-align-content: center;
    -ms-flex-line-pack: center;
    align-content: center;
}
header.mhdminbarright .min-bar-col2 {
    -webkit-transform: inherit;
    -moz-transform: inherit;
    transform: inherit;
    -webkit-transform-origin: 0 0;
    -moz-transform-origin: 0 0;
    transform-origin: 0 0;
   position: relative;
   top: 0;
   left: 0;
}
header.mhdminbarright .container{
max-width: 1200px;
padding-left: 20px;
padding-right: 20px;
}
header.mhdminbarright .min-bar-col1{
order:2;
    order: 2;
    -webkit-box-pack: end;
    -webkit-justify-content: flex-end;
    -moz-box-pack: end;
    -ms-flex-pack: end;
    justify-content: flex-end;
    -webkit-box-pack: start;
    -webkit-justify-content: flex-start;
    -moz-box-pack: start;
    -ms-flex-pack: start;
    justify-content: flex-start;
    -webkit-box-flex: 1;
    -webkit-flex: 1;
    -moz-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
}
header.mhdminbarright .min-bar-col2{
order:1;
width: 75%!important;
padding-top: 10px;
    padding-bottom: 10px;
}
.mobile-pan-active header.mhdminbarright {
right:auto!important;
left:0px!important;
  -webkit-transition: left .2s ease-in-out;
    -moz-transition: left .2s ease-in-out;
    transition:left .2s ease-in-out;
}
.mhdminbarright .pan-content{
padding:0;
position: relative;
background: #fff;
}
header.mhdminbarright {
    left: -270px!important;
    right: auto;
    -webkit-transition: left .2s ease-in-out;
    -moz-transition: left .2s ease-in-out;
    transition:left .2s ease-in-out;
}
.mobile-pan-active.mhdminbarright #page.zita-site{
    right: 0px!important;
    -webkit-transition: left .2s ease-in-out;
    -moz-transition: left .2s ease-in-out;
    transition: left .2s ease-in-out;
    left: 0!important;
}
header.mhdminbarleft .min-bar-col1,
header.mhdminbarright .min-bar-col1{
  -js-display: flex;
    display: -webkit-box;
    display: -webkit-flex;
    display: -moz-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -webkit-align-items: center;
    -moz-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    -webkit-flex-wrap: wrap;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -webkit-align-content: center;
    -ms-flex-line-pack: center;
    align-content: center;
flex:1;
justify-content: flex-end;
}
.cart-pan-active header.mhdminbarleft .zita-cart{
left:0;
}
.cart-pan-active header.mhdminbarright .zita-cart{
right:0;
}
.mhdminbarright #content.site-content,.mhdminbarleft #content.site-content {
    display: block;
    margin-top: 30px;
}
/*=================================
*  Learnpress 4 Column Responsive
==================================*/
.archive-course-widget-outer.four-colum-grid .course-entry{
  width: 49%;
}
.archive-course-widget-outer.four-colum-grid .course-entry:nth-of-type(4n+4),
.archive-course-widget-outer.four-colum-grid .course-entry:nth-of-type(2n+2){
  margin-right: 0;
}
.archive-course-widget-outer.four-colum-grid .course-entry:nth-of-type(2n+1){
  margin-right: 2%;
}

/*=================================
*  Learnpress 3 Column Responsive
==================================*/
.archive-course-widget-outer.three-colum-grid .course-entry{
  width: 49%;
}
.archive-course-widget-outer.three-colum-grid .course-entry:nth-of-type(3n+3),
.archive-course-widget-outer.three-colum-grid .course-entry:nth-of-type(2n+2){
  margin-right: 0;
}
.archive-course-widget-outer.three-colum-grid .course-entry:nth-of-type(2n+1){
  margin-right: 2%;
}

/*=================================
*  Learnpress List View Responsive
==================================*/
.learnpress-list-view{
  max-width: 350px;
  margin: 0 auto;
}
.learnpress-list-view .course-cover,
.learnpress-list-view .course-detail{
  width: 100%;
}
.learnpress-list-view .course-cover{
  margin-bottom: 20px;
}
.learnpress-list-view .course-detail{
  padding: 0!important;
}
}
@media screen and (max-width: 600px){
.logged-in #page.zita-site{
    display: contents;
}

.woocommerce div.product.zita-single-product-tab-vertical .woocommerce-tabs .panel{
margin-left:0;
border:0px;
}
.woocommerce div.product.zita-single-product-tab-vertical .woocommerce-tabs ul.tabs{
    width: 100%;
    float: none;

}
.mobile-menu-active .sider.overcenter .menu-close-btn, 
.mobile-above-menu-active .sider.overcenter .menu-close-btn,
 .mobile-bottom-menu-active .sider.overcenter .menu-close-btn {
    margin-left: 10px;
}
}
@media screen and (max-width: 480px){
#content.blog-single .zita-related-post ul li{
    width: 100%;
    float: left;
    padding: 0px 10px;
margin-bottom:10px;
}
.page-numbers {
    margin: 0 1px;
    font-size: 11px;
    line-height: 11px;
  }
.next.page-numbers, .prev.page-numbers{
    padding: 8px 14px;
  }
}

.zita-pageheader{
  width: 100%;
  height: 400px;
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  z-index: 1;
}
.zita-pageheader-content *{
  color: #FFF;
  z-index: 9;
}
.zita-pageheader:after{
  background: #111;
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0;
  top: 0;
  opacity: 0.7;
  content: ' ';
}
.zita-pageheader-img{
    position: absolute;
    width: 100%;
    height: 100%;
    left: 0;
    top: 0;
    background-attachment: scroll;
    background-size: cover;
    background-repeat: no-repeat;
    background-position: center;
}